@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -491,12 +491,12 @@ AcpiDmDumpAsf (
     UINT8                   Type;
 
 
-    /* No main table, only subtables */
+    /* No main table, only sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_ASF_INFO, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
                     SubTable->Header.Length, AcpiDmTableInfoAsfHdr);
@@ -551,7 +551,7 @@ AcpiDmDumpAsf (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown ASF subtable type 0x%X\n", SubTable->Header.Type);
+            AcpiOsPrintf ("\n**** Unknown ASF sub-table type 0x%X\n", SubTable->Header.Type);
             return;
         }
 
@@ -613,7 +613,7 @@ AcpiDmDumpAsf (
 
         AcpiOsPrintf ("\n");
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         if (!SubTable->Header.Length)
         {
@@ -658,7 +658,7 @@ AcpiDmDumpCpep (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_CPEP_POLLING, Table, Offset);
     while (Offset < Table->Length)
@@ -671,7 +671,7 @@ AcpiDmDumpCpep (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Header.Length;
         SubTable = ACPI_ADD_PTR (ACPI_CPEP_POLLING, SubTable,
@@ -710,7 +710,7 @@ AcpiDmDumpCsrt (
 
     /* The main table only contains the ACPI header, thus already handled */
 
-    /* Subtables (Resource Groups) */
+    /* Sub-tables (Resource Groups) */
 
     SubTable = ACPI_ADD_PTR (ACPI_CSRT_GROUP, Table, Offset);
     while (Offset < Table->Length)
@@ -774,7 +774,7 @@ AcpiDmDumpCsrt (
                         SubSubTable->Length);
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_CSRT_GROUP, SubTable,
@@ -818,7 +818,7 @@ AcpiDmDumpDbg2 (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_DBG2_DEVICE, Table, Offset);
     while (Offset < Table->Length)
@@ -881,13 +881,10 @@ AcpiDmDumpDbg2 (
 
         /* Dump the OemData (optional) */
 
-        if (SubTable->OemDataOffset)
-        {
-            AcpiDmDumpBuffer (SubTable, SubTable->OemDataOffset, SubTable->OemDataLength,
-                Offset + SubTable->OemDataOffset, "OEM Data");
-        }
+        AcpiDmDumpBuffer (SubTable, SubTable->OemDataOffset, SubTable->OemDataLength,
+            Offset + SubTable->OemDataOffset, "OEM Data");
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_DBG2_DEVICE, SubTable,
@@ -933,12 +930,12 @@ AcpiDmDumpDmar (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_DMAR_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -947,7 +944,6 @@ AcpiDmDumpDmar (
         {
             return;
         }
-        AcpiOsPrintf ("\n");
 
         switch (SubTable->Type)
         {
@@ -977,7 +973,7 @@ AcpiDmDumpDmar (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown DMAR subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown DMAR sub-table type 0x%X\n\n", SubTable->Type);
             return;
         }
 
@@ -1000,7 +996,6 @@ AcpiDmDumpDmar (
             {
                 return;
             }
-            AcpiOsPrintf ("\n");
 
             /* Dump the PCI Path entries for this device scope */
 
@@ -1018,7 +1013,6 @@ AcpiDmDumpDmar (
 
                 PathOffset += 2;
                 PciPath += 2;
-                AcpiOsPrintf ("\n");
             }
 
             /* Point to next device scope entry */
@@ -1028,7 +1022,7 @@ AcpiDmDumpDmar (
                 ScopeTable, ScopeTable->Length);
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_DMAR_HEADER, SubTable, SubTable->Length);
@@ -1067,7 +1061,7 @@ AcpiDmDumpEinj (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1080,7 +1074,7 @@ AcpiDmDumpEinj (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_WHEA_HEADER);
         SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, SubTable,
@@ -1120,7 +1114,7 @@ AcpiDmDumpErst (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1133,7 +1127,7 @@ AcpiDmDumpErst (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_WHEA_HEADER);
         SubTable = ACPI_ADD_PTR (ACPI_WHEA_HEADER, SubTable,
@@ -1168,12 +1162,12 @@ AcpiDmDumpFpdt (
 
     /* There is no main table (other than the standard ACPI header) */
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_FPDT_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -1197,7 +1191,7 @@ AcpiDmDumpFpdt (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown FPDT subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown FPDT sub-table type 0x%X\n\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -1217,7 +1211,7 @@ AcpiDmDumpFpdt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_FPDT_HEADER, SubTable, SubTable->Length);
@@ -1260,7 +1254,7 @@ AcpiDmDumpHest (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_HEST_HEADER, Table, Offset);
     while (Offset < Table->Length)
@@ -1318,7 +1312,7 @@ AcpiDmDumpHest (
 
             /* Cannot continue on unknown type - no length */
 
-            AcpiOsPrintf ("\n**** Unknown HEST subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown HEST sub-table type 0x%X\n", SubTable->Type);
             return;
         }
 
@@ -1356,7 +1350,7 @@ AcpiDmDumpHest (
             }
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         SubTable = ACPI_ADD_PTR (ACPI_HEST_HEADER, SubTable, SubTableLength);
     }
@@ -1399,12 +1393,12 @@ AcpiDmDumpIvrs (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_IVRS_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -1430,7 +1424,7 @@ AcpiDmDumpIvrs (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown IVRS subtable type 0x%X\n",
+            AcpiOsPrintf ("\n**** Unknown IVRS sub-table type 0x%X\n",
                 SubTable->Type);
 
             /* Attempt to continue */
@@ -1533,7 +1527,7 @@ AcpiDmDumpIvrs (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_IVRS_HEADER, SubTable, SubTable->Length);
@@ -1541,85 +1535,6 @@ NextSubTable:
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmDumpLpit
- *
- * PARAMETERS:  Table               - A LPIT table
- *
- * RETURN:      None
- *
- * DESCRIPTION: Format the contents of a LPIT. This table type consists
- *              of an open-ended number of subtables. Note: There are no
- *              entries in the main table. An LPIT consists of the table
- *              header and then subtables only.
- *
- ******************************************************************************/
-
-void
-AcpiDmDumpLpit (
-    ACPI_TABLE_HEADER       *Table)
-{
-    ACPI_STATUS             Status;
-    ACPI_LPIT_HEADER        *SubTable;
-    UINT32                  Length = Table->Length;
-    UINT32                  Offset = sizeof (ACPI_TABLE_LPIT);
-    ACPI_DMTABLE_INFO       *InfoTable;
-    UINT32                  SubTableLength;
-
-
-    /* Subtables */
-
-    SubTable = ACPI_ADD_PTR (ACPI_LPIT_HEADER, Table, Offset);
-    while (Offset < Table->Length)
-    {
-        /* Common subtable header */
-
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    sizeof (ACPI_LPIT_HEADER), AcpiDmTableInfoLpitHdr);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        switch (SubTable->Type)
-        {
-        case ACPI_LPIT_TYPE_NATIVE_CSTATE:
-
-            InfoTable = AcpiDmTableInfoLpit0;
-            SubTableLength = sizeof (ACPI_LPIT_NATIVE);
-            break;
-
-        case ACPI_LPIT_TYPE_SIMPLE_IO:
-
-            InfoTable = AcpiDmTableInfoLpit1;
-            SubTableLength = sizeof (ACPI_LPIT_IO);
-            break;
-
-        default:
-
-            /* Cannot continue on unknown type - no length */
-
-            AcpiOsPrintf ("\n**** Unknown LPIT subtable type 0x%X\n", SubTable->Type);
-            return;
-        }
-
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTableLength, InfoTable);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-        AcpiOsPrintf ("\n");
-
-        /* Point to next subtable */
-
-        Offset += SubTableLength;
-        SubTable = ACPI_ADD_PTR (ACPI_LPIT_HEADER, SubTable, SubTableLength);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmDumpMadt
@@ -1652,12 +1567,12 @@ AcpiDmDumpMadt (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
@@ -1736,7 +1651,7 @@ AcpiDmDumpMadt (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown MADT subtable type 0x%X\n\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown MADT sub-table type 0x%X\n\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -1756,7 +1671,7 @@ AcpiDmDumpMadt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, SubTable, SubTable->Length);
@@ -1793,7 +1708,7 @@ AcpiDmDumpMcfg (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MCFG_ALLOCATION, Table, Offset);
     while (Offset < Table->Length)
@@ -1813,7 +1728,7 @@ AcpiDmDumpMcfg (
             return;
         }
 
-        /* Point to next subtable (each subtable is of fixed length) */
+        /* Point to next sub-table (each subtable is of fixed length) */
 
         Offset += sizeof (ACPI_MCFG_ALLOCATION);
         SubTable = ACPI_ADD_PTR (ACPI_MCFG_ALLOCATION, SubTable,
@@ -1995,12 +1910,12 @@ AcpiDmDumpMsct (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MSCT_PROXIMITY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2010,7 +1925,7 @@ AcpiDmDumpMsct (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_MSCT_PROXIMITY);
         SubTable = ACPI_ADD_PTR (ACPI_MSCT_PROXIMITY, SubTable, sizeof (ACPI_MSCT_PROXIMITY));
@@ -2047,12 +1962,12 @@ AcpiDmDumpMtmr (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_MTMR_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2062,7 +1977,7 @@ AcpiDmDumpMtmr (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_MTMR_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_MTMR_ENTRY, SubTable, sizeof (ACPI_MTMR_ENTRY));
@@ -2101,31 +2016,11 @@ AcpiDmDumpPcct (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_PCCT_SUBSPACE, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
-
-        AcpiOsPrintf ("\n");
-        Status = AcpiDmDumpTable (Length, Offset, SubTable,
-                    SubTable->Header.Length, AcpiDmTableInfoPcctHdr);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        /* ACPI 5.0: Only one type of PCCT subtable is supported */
-
-        if (SubTable->Header.Type != ACPI_PCCT_TYPE_GENERIC_SUBSPACE)
-        {
-            AcpiOsPrintf (
-                "\n**** Unexpected or unknown PCCT subtable type 0x%X\n\n",
-                SubTable->Header.Type);
-            return;
-        }
-
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Length, Offset, SubTable,
                     SubTable->Header.Length, AcpiDmTableInfoPcct0);
@@ -2134,7 +2029,7 @@ AcpiDmDumpPcct (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Header.Length;
         SubTable = ACPI_ADD_PTR (ACPI_PCCT_SUBSPACE, SubTable,
@@ -2383,7 +2278,7 @@ AcpiDmDumpS3pt (
     SubTable = ACPI_ADD_PTR (ACPI_S3PT_HEADER, S3ptTable, Offset);
     while (Offset < S3ptTable->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (S3ptTable->Length, Offset, SubTable,
@@ -2407,7 +2302,7 @@ AcpiDmDumpS3pt (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown S3PT subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown S3PT sub-table type 0x%X\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -2428,7 +2323,7 @@ AcpiDmDumpS3pt (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_S3PT_HEADER, SubTable, SubTable->Length);
@@ -2465,7 +2360,7 @@ AcpiDmDumpSlic (
     SubTable = ACPI_ADD_PTR (ACPI_SLIC_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2489,7 +2384,7 @@ AcpiDmDumpSlic (
 
         default:
 
-            AcpiOsPrintf ("\n**** Unknown SLIC subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown SLIC sub-table type 0x%X\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -2510,7 +2405,7 @@ AcpiDmDumpSlic (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_SLIC_HEADER, SubTable, SubTable->Length);
@@ -2626,12 +2521,12 @@ AcpiDmDumpSrat (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2659,7 +2554,7 @@ AcpiDmDumpSrat (
             break;
 
         default:
-            AcpiOsPrintf ("\n**** Unknown SRAT subtable type 0x%X\n", SubTable->Type);
+            AcpiOsPrintf ("\n**** Unknown SRAT sub-table type 0x%X\n", SubTable->Type);
 
             /* Attempt to continue */
 
@@ -2680,7 +2575,7 @@ AcpiDmDumpSrat (
         }
 
 NextSubTable:
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += SubTable->Length;
         SubTable = ACPI_ADD_PTR (ACPI_SUBTABLE_HEADER, SubTable, SubTable->Length);
@@ -2717,12 +2612,12 @@ AcpiDmDumpVrtc (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_VRTC_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2732,7 +2627,7 @@ AcpiDmDumpVrtc (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_VRTC_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_VRTC_ENTRY, SubTable, sizeof (ACPI_VRTC_ENTRY));
@@ -2769,12 +2664,12 @@ AcpiDmDumpWdat (
         return;
     }
 
-    /* Subtables */
+    /* Sub-tables */
 
     SubTable = ACPI_ADD_PTR (ACPI_WDAT_ENTRY, Table, Offset);
     while (Offset < Table->Length)
     {
-        /* Common subtable header */
+        /* Common sub-table header */
 
         AcpiOsPrintf ("\n");
         Status = AcpiDmDumpTable (Table->Length, Offset, SubTable,
@@ -2784,7 +2679,7 @@ AcpiDmDumpWdat (
             return;
         }
 
-        /* Point to next subtable */
+        /* Point to next sub-table */
 
         Offset += sizeof (ACPI_WDAT_ENTRY);
         SubTable = ACPI_ADD_PTR (ACPI_WDAT_ENTRY, SubTable, sizeof (ACPI_WDAT_ENTRY));
