@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #include "aslcompiler.h"
 #include "aslcompiler.y.h"
 #include "acapps.h"
@@ -127,28 +128,9 @@ static ACPI_PARSE_OBJECT *
 TrGetNextNode (
     void);
 
-
-/*******************************************************************************
- *
- * FUNCTION:    TrSetParent
- *
- * PARAMETERS:  Op                  - To be set to new parent
- *              ParentOp            - The parent
- *
- * RETURN:      None, sets Op parent directly
- *
- * DESCRIPTION: Change the parent of a parse op.
- *
- ******************************************************************************/
-
-void
-TrSetParent (
-    ACPI_PARSE_OBJECT       *Op,
-    ACPI_PARSE_OBJECT       *ParentOp)
-{
-
-    Op->Asl.Parent = ParentOp;
-}
+static char *
+TrGetNodeFlagName (
+    UINT32                  Flags);
 
 
 /*******************************************************************************
@@ -169,29 +151,15 @@ static ACPI_PARSE_OBJECT *
 TrGetNextNode (
     void)
 {
-    ASL_CACHE_INFO          *Cache;
 
-
-    if (Gbl_ParseOpCacheNext >= Gbl_ParseOpCacheLast)
+    if (Gbl_NodeCacheNext >= Gbl_NodeCacheLast)
     {
-        /* Allocate a new buffer */
-
-        Cache = UtLocalCalloc (sizeof (Cache->Next) +
-            (sizeof (ACPI_PARSE_OBJECT) * ASL_PARSEOP_CACHE_SIZE));
-
-        /* Link new cache buffer to head of list */
-
-        Cache->Next = Gbl_ParseOpCacheList;
-        Gbl_ParseOpCacheList = Cache;
-
-        /* Setup cache management pointers */
-
-        Gbl_ParseOpCacheNext = ACPI_CAST_PTR (ACPI_PARSE_OBJECT, Cache->Buffer);
-        Gbl_ParseOpCacheLast = Gbl_ParseOpCacheNext + ASL_PARSEOP_CACHE_SIZE;
+        Gbl_NodeCacheNext = UtLocalCalloc (sizeof (ACPI_PARSE_OBJECT) *
+                                ASL_NODE_CACHE_SIZE);
+        Gbl_NodeCacheLast = Gbl_NodeCacheNext + ASL_NODE_CACHE_SIZE;
     }
 
-    Gbl_ParseOpCount++;
-    return (Gbl_ParseOpCacheNext++);
+    return (Gbl_NodeCacheNext++);
 }
 
 
@@ -250,32 +218,12 @@ TrReleaseNode (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrSetCurrentFilename
- *
- * PARAMETERS:  Op                  - An existing parse node
- *
- * RETURN:      None
- *
- * DESCRIPTION: Save the include file filename. Used for debug output only.
- *
- ******************************************************************************/
-
-void
-TrSetCurrentFilename (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    Op->Asl.Filename = Gbl_PreviousIncludeFilename;
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrUpdateNode
  *
  * PARAMETERS:  ParseOpcode         - New opcode to be assigned to the node
- *              Op                  - An existing parse node
+ *              Op                - An existing parse node
  *
  * RETURN:      The updated node
  *
@@ -298,7 +246,7 @@ TrUpdateNode (
     }
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nUpdateNode: Old - %s, New - %s\n",
+        "\nUpdateNode: Old - %s, New - %s\n\n",
         UtGetOpName (Op->Asl.ParseOpcode),
         UtGetOpName (ParseOpcode));
 
@@ -372,145 +320,90 @@ TrUpdateNode (
 
 /*******************************************************************************
  *
- * FUNCTION:    TrPrintNodeCompileFlags
+ * FUNCTION:    TrGetNodeFlagName
  *
  * PARAMETERS:  Flags               - Flags word to be decoded
  *
- * RETURN:      None
+ * RETURN:      Name string. Always returns a valid string pointer.
  *
- * DESCRIPTION: Decode a flags word to text. Displays all flags that are set.
+ * DESCRIPTION: Decode a flags word
  *
  ******************************************************************************/
 
-void
-TrPrintNodeCompileFlags (
+static char *
+TrGetNodeFlagName (
     UINT32                  Flags)
 {
-    UINT32                  i;
-    UINT32                  FlagBit = 1;
-    char                    *FlagName = NULL;
 
-
-    for (i = 0; i < 32; i++)
+    switch (Flags)
     {
-        switch (Flags & FlagBit)
-        {
-        case NODE_VISITED:
+    case NODE_VISITED:
 
-            FlagName = "NODE_VISITED";
-            break;
+        return ("NODE_VISITED");
 
-        case NODE_AML_PACKAGE:
+    case NODE_AML_PACKAGE:
 
-            FlagName = "NODE_AML_PACKAGE";
-            break;
+        return ("NODE_AML_PACKAGE");
 
-        case NODE_IS_TARGET:
+    case NODE_IS_TARGET:
 
-            FlagName = "NODE_IS_TARGET";
-            break;
+        return ("NODE_IS_TARGET");
 
-        case NODE_IS_RESOURCE_DESC:
+    case NODE_IS_RESOURCE_DESC:
 
-            FlagName = "NODE_IS_RESOURCE_DESC";
-            break;
+        return ("NODE_IS_RESOURCE_DESC");
 
-        case NODE_IS_RESOURCE_FIELD:
+    case NODE_IS_RESOURCE_FIELD:
 
-            FlagName = "NODE_IS_RESOURCE_FIELD";
-            break;
+        return ("NODE_IS_RESOURCE_FIELD");
 
-        case NODE_HAS_NO_EXIT:
+    case NODE_HAS_NO_EXIT:
 
-            FlagName = "NODE_HAS_NO_EXIT";
-            break;
+        return ("NODE_HAS_NO_EXIT");
 
-        case NODE_IF_HAS_NO_EXIT:
+    case NODE_IF_HAS_NO_EXIT:
 
-            FlagName = "NODE_IF_HAS_NO_EXIT";
-            break;
+        return ("NODE_IF_HAS_NO_EXIT");
 
-        case NODE_NAME_INTERNALIZED:
+    case NODE_NAME_INTERNALIZED:
 
-            FlagName = "NODE_NAME_INTERNALIZED";
-            break;
+        return ("NODE_NAME_INTERNALIZED");
 
-        case NODE_METHOD_NO_RETVAL:
+    case NODE_METHOD_NO_RETVAL:
 
-            FlagName = "NODE_METHOD_NO_RETVAL";
-            break;
+        return ("NODE_METHOD_NO_RETVAL");
 
-        case NODE_METHOD_SOME_NO_RETVAL:
+    case NODE_METHOD_SOME_NO_RETVAL:
 
-            FlagName = "NODE_METHOD_SOME_NO_RETVAL";
-            break;
+        return ("NODE_METHOD_SOME_NO_RETVAL");
 
-        case NODE_RESULT_NOT_USED:
+    case NODE_RESULT_NOT_USED:
 
-            FlagName = "NODE_RESULT_NOT_USED";
-            break;
+        return ("NODE_RESULT_NOT_USED");
 
-        case NODE_METHOD_TYPED:
+    case NODE_METHOD_TYPED:
 
-            FlagName = "NODE_METHOD_TYPED";
-            break;
+        return ("NODE_METHOD_TYPED");
 
-        case NODE_COULD_NOT_REDUCE:
+    case NODE_COMPILE_TIME_CONST:
 
-            FlagName = "NODE_COULD_NOT_REDUCE";
-            break;
+        return ("NODE_COMPILE_TIME_CONST");
 
-        case NODE_COMPILE_TIME_CONST:
+    case NODE_IS_TERM_ARG:
 
-            FlagName = "NODE_COMPILE_TIME_CONST";
-            break;
+        return ("NODE_IS_TERM_ARG");
 
-        case NODE_IS_TERM_ARG:
+    case NODE_WAS_ONES_OP:
 
-            FlagName = "NODE_IS_TERM_ARG";
-            break;
+        return ("NODE_WAS_ONES_OP");
 
-        case NODE_WAS_ONES_OP:
+    case NODE_IS_NAME_DECLARATION:
 
-            FlagName = "NODE_WAS_ONES_OP";
-            break;
+        return ("NODE_IS_NAME_DECLARATION");
 
-        case NODE_IS_NAME_DECLARATION:
+    default:
 
-            FlagName = "NODE_IS_NAME_DECLARATION";
-            break;
-
-        case NODE_COMPILER_EMITTED:
-
-            FlagName = "NODE_COMPILER_EMITTED";
-            break;
-
-        case NODE_IS_DUPLICATE:
-
-            FlagName = "NODE_IS_DUPLICATE";
-            break;
-
-        case NODE_IS_RESOURCE_DATA:
-
-            FlagName = "NODE_IS_RESOURCE_DATA";
-            break;
-
-        case NODE_IS_NULL_RETURN:
-
-            FlagName = "NODE_IS_NULL_RETURN";
-            break;
-
-        default:
-            break;
-        }
-
-        if (FlagName)
-        {
-            DbgPrint (ASL_PARSE_OUTPUT, " %s", FlagName);
-            FlagName = NULL;
-        }
-
-        FlagBit <<= 1;
+        return ("Multiple Flags (or unknown flag) set");
     }
 }
 
@@ -534,17 +427,15 @@ TrSetNodeFlags (
     UINT32                  Flags)
 {
 
+    DbgPrint (ASL_PARSE_OUTPUT,
+        "\nSetNodeFlags: Op %p, %8.8X %s\n\n", Op, Flags,
+        TrGetNodeFlagName (Flags));
+
     if (!Op)
     {
         return (NULL);
     }
 
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nSetNodeFlags: %s Op %p, %8.8X", Op->Asl.ParseOpName, Op, Flags);
-
-    TrPrintNodeCompileFlags (Flags);
-    DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
-
     Op->Asl.CompileFlags |= Flags;
     return (Op);
 }
@@ -609,130 +500,11 @@ TrSetEndLineNumber (
         return;
     }
 
-    Op->Asl.EndLine = Gbl_CurrentLineNumber;
+    Op->Asl.EndLine        = Gbl_CurrentLineNumber;
     Op->Asl.EndLogicalLine = Gbl_LogicalLineNumber;
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateAssignmentNode
- *
- * PARAMETERS:  Target              - Assignment target
- *              Source              - Assignment source
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Implements the C-style '=' operator. It changes the parse
- *              tree if possible to utilize the last argument of the math
- *              operators which is a target operand -- thus saving invocation
- *              of and additional Store() operator. An optimization.
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateAssignmentNode (
-    ACPI_PARSE_OBJECT       *Target,
-    ACPI_PARSE_OBJECT       *Source)
-{
-    ACPI_PARSE_OBJECT       *TargetOp;
-    ACPI_PARSE_OBJECT       *SourceOp1;
-    ACPI_PARSE_OBJECT       *SourceOp2;
-    ACPI_PARSE_OBJECT       *Operator;
-
-
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nTrCreateAssignmentNode  Line [%u to %u] Source %s Target %s\n",
-        Source->Asl.LineNumber, Source->Asl.EndLine,
-        UtGetOpName (Source->Asl.ParseOpcode),
-        UtGetOpName (Target->Asl.ParseOpcode));
-
-    TrSetNodeFlags (Target, NODE_IS_TARGET);
-
-    switch (Source->Asl.ParseOpcode)
-    {
-    /*
-     * Only these operators can be optimized because they have
-     * a target operand
-     */
-    case PARSEOP_ADD:
-    case PARSEOP_AND:
-    case PARSEOP_DIVIDE:
-    case PARSEOP_INDEX:
-    case PARSEOP_MOD:
-    case PARSEOP_MULTIPLY:
-    case PARSEOP_NOT:
-    case PARSEOP_OR:
-    case PARSEOP_SHIFTLEFT:
-    case PARSEOP_SHIFTRIGHT:
-    case PARSEOP_SUBTRACT:
-    case PARSEOP_XOR:
-
-        break;
-
-    /* Otherwise, just create a normal Store operator */
-
-    default:
-
-        goto CannotOptimize;
-    }
-
-    /*
-     * Transform the parse tree such that the target is moved to the
-     * last operand of the operator
-     */
-    SourceOp1 = Source->Asl.Child;
-    SourceOp2 = SourceOp1->Asl.Next;
-
-    /* NOT only has one operand, but has a target */
-
-    if (Source->Asl.ParseOpcode == PARSEOP_NOT)
-    {
-        SourceOp2 = SourceOp1;
-    }
-
-    /* DIVIDE has an extra target operand (remainder) */
-
-    if (Source->Asl.ParseOpcode == PARSEOP_DIVIDE)
-    {
-        SourceOp2 = SourceOp2->Asl.Next;
-    }
-
-    TargetOp = SourceOp2->Asl.Next;
-
-    /*
-     * Can't perform this optimization if there already is a target
-     * for the operator (ZERO is a "no target" placeholder).
-     */
-    if (TargetOp->Asl.ParseOpcode != PARSEOP_ZERO)
-    {
-        goto CannotOptimize;
-    }
-
-    /* Link in the target as the final operand */
-
-    SourceOp2->Asl.Next = Target;
-    Target->Asl.Parent = Source;
-
-    return (Source);
-
-
-CannotOptimize:
-
-    Operator = TrAllocateNode (PARSEOP_STORE);
-    TrLinkChildren (Operator, 2, Source, Target);
-
-    /* Set the appropriate line numbers for the new node */
-
-    Operator->Asl.LineNumber        = Target->Asl.LineNumber;
-    Operator->Asl.LogicalLineNumber = Target->Asl.LogicalLineNumber;
-    Operator->Asl.LogicalByteOffset = Target->Asl.LogicalByteOffset;
-    Operator->Asl.Column            = Target->Asl.Column;
-
-    return (Operator);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrCreateLeafNode
@@ -757,40 +529,7 @@ TrCreateLeafNode (
 
     DbgPrint (ASL_PARSE_OUTPUT,
         "\nCreateLeafNode  Ln/Col %u/%u NewNode %p  Op %s\n\n",
-        Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName (ParseOpcode));
-
-    return (Op);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateNullTarget
- *
- * PARAMETERS:  None
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Create a "null" target node. This is defined by the ACPI
- *              specification to be a zero AML opcode, and indicates that
- *              no target has been specified for the parent operation
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateNullTarget (
-    void)
-{
-    ACPI_PARSE_OBJECT       *Op;
-
-
-    Op = TrAllocateNode (PARSEOP_ZERO);
-    Op->Asl.CompileFlags |= (NODE_IS_TARGET | NODE_COMPILE_TIME_CONST);
-
-    DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateNullTarget  Ln/Col %u/%u NewNode %p  Op %s\n",
-        Op->Asl.LineNumber, Op->Asl.Column, Op,
-        UtGetOpName (Op->Asl.ParseOpcode));
+        Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName(ParseOpcode));
 
     return (Op);
 }
@@ -822,6 +561,7 @@ TrCreateConstantLeafNode (
     time_t                  CurrentTime;
     char                    *StaticTimeString;
     char                    *TimeString;
+    char                    *Path;
     char                    *Filename;
 
 
@@ -848,7 +588,8 @@ TrCreateConstantLeafNode (
 
         /* Get the simple filename from the full path */
 
-        FlSplitInputPathname (Op->Asl.Filename, NULL, &Filename);
+        FlSplitInputPathname (Op->Asl.Filename, &Path, &Filename);
+        ACPI_FREE (Path);
         Op->Asl.Value.String = Filename;
         break;
 
@@ -873,89 +614,13 @@ TrCreateConstantLeafNode (
     }
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateConstantLeafNode  Ln/Col %u/%u NewNode %p  "
-        "Op %s  Value %8.8X%8.8X  \n",
+        "\nCreateConstantLeafNode  Ln/Col %u/%u NewNode %p  Op %s  Value %8.8X%8.8X  ",
         Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName (ParseOpcode),
         ACPI_FORMAT_UINT64 (Op->Asl.Value.Integer));
     return (Op);
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    TrCreateTargetOperand
- *
- * PARAMETERS:  OriginalOp          - Op to be copied
- *
- * RETURN:      Pointer to the new node. Aborts on allocation failure
- *
- * DESCRIPTION: Copy an existing node (and subtree). Used in ASL+ (C-style)
- *              expressions where the target is the same as one of the
- *              operands. A new node and subtree must be created from the
- *              original so that the parse tree can be linked properly.
- *
- * NOTE:        This code is specific to target operands that are the last
- *              operand in an ASL/AML operator. Meaning that the top-level
- *              parse Op in a possible subtree has a NULL Next pointer.
- *              This simplifies the recursion.
- *
- *              Subtree example:
- *                  DeRefOf (Local1) += 32
- *
- *              This gets converted to:
- *                  Add (DeRefOf (Local1), 32, DeRefOf (Local1))
- *
- *              Each DeRefOf has a single child, Local1. Even more complex
- *              subtrees can be created via the Index and DeRefOf operators.
- *
- ******************************************************************************/
-
-ACPI_PARSE_OBJECT *
-TrCreateTargetOperand (
-    ACPI_PARSE_OBJECT       *OriginalOp,
-    ACPI_PARSE_OBJECT       *ParentOp)
-{
-    ACPI_PARSE_OBJECT       *Op;
-
-
-    if (!OriginalOp)
-    {
-        return (NULL);
-    }
-
-    Op = TrGetNextNode ();
-
-    /* Copy the pertinent values (omit link pointer fields) */
-
-    Op->Asl.Value               = OriginalOp->Asl.Value;
-    Op->Asl.Filename            = OriginalOp->Asl.Filename;
-    Op->Asl.LineNumber          = OriginalOp->Asl.LineNumber;
-    Op->Asl.LogicalLineNumber   = OriginalOp->Asl.LogicalLineNumber;
-    Op->Asl.LogicalByteOffset   = OriginalOp->Asl.LogicalByteOffset;
-    Op->Asl.Column              = OriginalOp->Asl.Column;
-    Op->Asl.Flags               = OriginalOp->Asl.Flags;
-    Op->Asl.CompileFlags        = OriginalOp->Asl.CompileFlags;
-    Op->Asl.AmlOpcode           = OriginalOp->Asl.AmlOpcode;
-    Op->Asl.ParseOpcode         = OriginalOp->Asl.ParseOpcode;
-    Op->Asl.Parent              = ParentOp;
-    UtSetParseOpName (Op);
-
-    /* Copy a possible subtree below this node */
-
-    if (OriginalOp->Asl.Child)
-    {
-        Op->Asl.Child = TrCreateTargetOperand (OriginalOp->Asl.Child, Op);
-    }
-
-    if (OriginalOp->Asl.Next) /* Null for top-level node */
-    {
-        Op->Asl.Next = TrCreateTargetOperand (OriginalOp->Asl.Next, ParentOp);
-    }
-
-    return (Op);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    TrCreateValuedLeafNode
@@ -981,8 +646,7 @@ TrCreateValuedLeafNode (
     Op = TrAllocateNode (ParseOpcode);
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nCreateValuedLeafNode  Ln/Col %u/%u NewNode %p  "
-        "Op %s  Value %8.8X%8.8X  ",
+        "\nCreateValuedLeafNode  Ln/Col %u/%u NewNode %p  Op %s  Value %8.8X%8.8X  ",
         Op->Asl.LineNumber, Op->Asl.Column, Op, UtGetOpName(ParseOpcode),
         ACPI_FORMAT_UINT64 (Value));
     Op->Asl.Value.Integer = Value;
@@ -1016,8 +680,7 @@ TrCreateValuedLeafNode (
 
     case PARSEOP_INTEGER:
 
-        DbgPrint (ASL_PARSE_OUTPUT, "INTEGER->%8.8X%8.8X",
-            ACPI_FORMAT_UINT64 (Value));
+        DbgPrint (ASL_PARSE_OUTPUT, "INTEGER");
         break;
 
     default:
@@ -1068,22 +731,15 @@ TrCreateNode (
 
     DbgPrint (ASL_PARSE_OUTPUT,
         "\nCreateNode  Ln/Col %u/%u NewParent %p Child %u Op %s  ",
-        Op->Asl.LineNumber, Op->Asl.Column, Op,
-        NumChildren, UtGetOpName(ParseOpcode));
+        Op->Asl.LineNumber, Op->Asl.Column, Op, NumChildren, UtGetOpName(ParseOpcode));
 
     /* Some extra debug output based on the parse opcode */
 
     switch (ParseOpcode)
     {
-    case PARSEOP_ASL_CODE:
-
-        Gbl_ParseTreeRoot = Op;
-        Op->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
-        DbgPrint (ASL_PARSE_OUTPUT, "ASLCODE (Tree Completed)->");
-        break;
-
-    case PARSEOP_DEFINITION_BLOCK:
+    case PARSEOP_DEFINITIONBLOCK:
 
+        RootNode = Op;
         DbgPrint (ASL_PARSE_OUTPUT, "DEFINITION_BLOCK (Tree Completed)->");
         break;
 
@@ -1159,7 +815,7 @@ TrCreateNode (
     }
     va_end(ap);
 
-    DbgPrint (ASL_PARSE_OUTPUT, "\n");
+    DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
     return (Op);
 }
 
@@ -1204,15 +860,9 @@ TrLinkChildren (
 
     switch (Op->Asl.ParseOpcode)
     {
-    case PARSEOP_ASL_CODE:
-
-        Gbl_ParseTreeRoot = Op;
-        Op->Asl.ParseOpcode = PARSEOP_DEFAULT_ARG;
-        DbgPrint (ASL_PARSE_OUTPUT, "ASLCODE (Tree Completed)->");
-        break;
-
-    case PARSEOP_DEFINITION_BLOCK:
+    case PARSEOP_DEFINITIONBLOCK:
 
+        RootNode = Op;
         DbgPrint (ASL_PARSE_OUTPUT, "DEFINITION_BLOCK (Tree Completed)->");
         break;
 
@@ -1245,7 +895,6 @@ TrLinkChildren (
         {
             AslError (ASL_WARNING, ASL_MSG_COMPILER_INTERNAL, Child,
                 "Child node list invalid");
-            va_end(ap);
             return (Op);
         }
 
@@ -1290,11 +939,10 @@ TrLinkChildren (
             Child = Child->Asl.Next;
             Child->Asl.Parent = Op;
         }
-
         PrevChild = Child;
     }
-
     va_end(ap);
+
     DbgPrint (ASL_PARSE_OUTPUT, "\n\n");
     return (Op);
 }
@@ -1322,7 +970,7 @@ TrLinkPeerNode (
 
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nLinkPeerNode: 1=%p (%s), 2=%p (%s)\n",
+        "\nLinkPeerNode: 1=%p (%s), 2=%p (%s)\n\n",
         Op1, Op1 ? UtGetOpName(Op1->Asl.ParseOpcode) : NULL,
         Op2, Op2 ? UtGetOpName(Op2->Asl.ParseOpcode) : NULL);
 
@@ -1348,7 +996,7 @@ TrLinkPeerNode (
     if (Op1 == Op2)
     {
         DbgPrint (ASL_DEBUG_OUTPUT,
-            "\n************* Internal error, linking node to itself %p\n",
+            "\n\n************* Internal error, linking node to itself %p\n\n\n",
             Op1);
         AslError (ASL_WARNING, ASL_MSG_COMPILER_INTERNAL, Op1,
             "Linking node to itself");
@@ -1432,7 +1080,7 @@ TrLinkPeerNodes (
     }
     va_end (ap);
 
-    DbgPrint (ASL_PARSE_OUTPUT,"\n");
+    DbgPrint (ASL_PARSE_OUTPUT,"\n\n");
     return (Start);
 }
 
@@ -1459,7 +1107,7 @@ TrLinkChildNode (
 
 
     DbgPrint (ASL_PARSE_OUTPUT,
-        "\nLinkChildNode: Parent=%p (%s), Child=%p (%s)\n",
+        "\nLinkChildNode: Parent=%p (%s), Child=%p (%s)\n\n",
         Op1, Op1 ? UtGetOpName(Op1->Asl.ParseOpcode): NULL,
         Op2, Op2 ? UtGetOpName(Op2->Asl.ParseOpcode): NULL);
 
@@ -1512,7 +1160,7 @@ TrWalkParseTree (
     ACPI_STATUS             Status;
 
 
-    if (!Gbl_ParseTreeRoot)
+    if (!RootNode)
     {
         return (AE_OK);
     }
