@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,45 +111,12 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+#define __DTFIELD_C__
+
 #include "aslcompiler.h"
+#include "dtcompiler.h"
 
 #define _COMPONENT          DT_COMPILER
         ACPI_MODULE_NAME    ("dtfield")
@@ -206,7 +173,6 @@ DtCompileOneField (
 {
     ACPI_STATUS             Status;
 
-
     switch (Type)
     {
     case DT_FIELD_TYPE_INTEGER:
@@ -274,18 +240,18 @@ DtCompileString (
     UINT32                  Length;
 
 
-    Length = strlen (Field->Value);
+    Length = ACPI_STRLEN (Field->Value);
 
     /* Check if the string is too long for the field */
 
     if (Length > ByteLength)
     {
-        sprintf (AslGbl_MsgBuffer, "Maximum %u characters", ByteLength);
-        DtError (ASL_ERROR, ASL_MSG_STRING_LENGTH, Field, AslGbl_MsgBuffer);
+        sprintf (MsgBuffer, "Maximum %u characters", ByteLength);
+        DtError (ASL_ERROR, ASL_MSG_STRING_LENGTH, Field, MsgBuffer);
         Length = ByteLength;
     }
 
-    memcpy (Buffer, Field->Value, Length);
+    ACPI_MEMCPY (Buffer, Field->Value, Length);
 }
 
 
@@ -320,7 +286,7 @@ DtCompileUnicode (
 
     AsciiString = Field->Value;
     UnicodeString = (UINT16 *) Buffer;
-    Count = strlen (AsciiString) + 1;
+    Count = ACPI_STRLEN (AsciiString) + 1;
 
     /* Convert to Unicode string (including null terminator) */
 
@@ -360,12 +326,12 @@ DtCompileUuid (
     Status = AuValidateUuid (InString);
     if (ACPI_FAILURE (Status))
     {
-        sprintf (AslGbl_MsgBuffer, "%s", Field->Value);
-        DtNameError (ASL_ERROR, ASL_MSG_INVALID_UUID, Field, AslGbl_MsgBuffer);
+        sprintf (MsgBuffer, "%s", Field->Value);
+        DtNameError (ASL_ERROR, ASL_MSG_INVALID_UUID, Field, MsgBuffer);
     }
     else
     {
-        AcpiUtConvertStringToUuid (InString, Buffer);
+        Status = AuConvertStringToUuid (InString, (char *) Buffer);
     }
 
     return (Status);
@@ -417,37 +383,21 @@ DtCompileInteger (
         return;
     }
 
-    /*
-     * Ensure that reserved fields are set properly. Note: uses
-     * the DT_NON_ZERO flag to indicate that the reserved value
-     * must be exactly one. Otherwise, the value must be zero.
-     * This is sufficient for now.
-     */
+    /* Ensure that reserved fields are set to zero */
+    /* TBD: should we set to zero, or just make this an ERROR? */
+    /* TBD: Probably better to use a flag */
 
-    /* TBD: Should use a flag rather than compare "Reserved" */
-
-    if (!strcmp (Field->Name, "Reserved"))
+    if (!ACPI_STRCMP (Field->Name, "Reserved") &&
+        (Value != 0))
     {
-        if (Flags & DT_NON_ZERO)
-        {
-            if (Value != 1)
-            {
-                DtError (ASL_WARNING, ASL_MSG_RESERVED_VALUE, Field,
-                    "Must be one, setting to one");
-                Value = 1;
-            }
-        }
-        else if (Value != 0)
-        {
-            DtError (ASL_WARNING, ASL_MSG_RESERVED_VALUE, Field,
-                "Must be zero, setting to zero");
-            Value = 0;
-        }
+        DtError (ASL_WARNING, ASL_MSG_RESERVED_VALUE, Field,
+            "Setting to zero");
+        Value = 0;
     }
 
     /* Check if the value must be non-zero */
 
-    else if ((Flags & DT_NON_ZERO) && (Value == 0))
+    if ((Value == 0) && (Flags & DT_NON_ZERO))
     {
         DtError (ASL_ERROR, ASL_MSG_ZERO_VALUE, Field, NULL);
     }
@@ -462,12 +412,11 @@ DtCompileInteger (
 
     if (Value > MaxValue)
     {
-        sprintf (AslGbl_MsgBuffer, "%8.8X%8.8X - max %u bytes",
-            ACPI_FORMAT_UINT64 (Value), ByteLength);
-        DtError (ASL_ERROR, ASL_MSG_INTEGER_SIZE, Field, AslGbl_MsgBuffer);
+        sprintf (MsgBuffer, "%8.8X%8.8X", ACPI_FORMAT_UINT64 (Value));
+        DtError (ASL_ERROR, ASL_MSG_INTEGER_SIZE, Field, MsgBuffer);
     }
 
-    memcpy (Buffer, &Value, ByteLength);
+    ACPI_MEMCPY (Buffer, &Value, ByteLength);
     return;
 }
 
@@ -477,10 +426,10 @@ DtCompileInteger (
  * FUNCTION:    DtNormalizeBuffer
  *
  * PARAMETERS:  Buffer              - Input buffer
- *              Count               - Output the count of hex numbers in
+ *              Count               - Output the count of hex number in
  *                                    the Buffer
  *
- * RETURN:      The normalized buffer, must be freed by caller
+ * RETURN:      The normalized buffer, freed by caller
  *
  * DESCRIPTION: [1A,2B,3C,4D] or 1A, 2B, 3C, 4D will be normalized
  *              to 1A 2B 3C 4D
@@ -499,7 +448,7 @@ DtNormalizeBuffer (
     char                    c;
 
 
-    NewBuffer = UtLocalCalloc (strlen (Buffer) + 1);
+    NewBuffer = UtLocalCalloc (ACPI_STRLEN (Buffer) + 1);
     TmpBuffer = NewBuffer;
 
     while ((c = *Buffer++))
@@ -564,41 +513,38 @@ DtCompileBuffer (
     DT_FIELD                *Field,
     UINT32                  ByteLength)
 {
-    char                    *Substring;
     ACPI_STATUS             Status;
-    UINT32                  Count;
+    char                    Hex[3];
+    UINT64                  Value;
     UINT32                  i;
+    UINT32                  Count;
 
 
     /* Allow several different types of value separators */
 
     StringValue = DtNormalizeBuffer (StringValue, &Count);
-    Substring = StringValue;
 
-    /* Each element of StringValue is now three chars (2 hex + 1 space) */
-
-    for (i = 0; i < Count; i++, Substring += 3)
+    Hex[2] = 0;
+    for (i = 0; i < Count; i++)
     {
-        /* Check for byte value too long */
+        /* Each element of StringValue is three chars */
 
-        if (*(&Substring[2]) &&
-           (*(&Substring[2]) != ' '))
-        {
-            DtError (ASL_ERROR, ASL_MSG_BUFFER_ELEMENT, Field, Substring);
-            goto Exit;
-        }
+        Hex[0] = StringValue[(3 * i)];
+        Hex[1] = StringValue[(3 * i) + 1];
 
-        /* Convert two ASCII characters to one hex byte */
+        /* Convert one hex byte */
 
-        Status = AcpiUtAsciiToHexByte (Substring, &Buffer[i]);
+        Value = 0;
+        Status = DtStrtoul64 (Hex, &Value);
         if (ACPI_FAILURE (Status))
         {
-            DtError (ASL_ERROR, ASL_MSG_BUFFER_ELEMENT, Field, Substring);
-            goto Exit;
+            DtError (ASL_ERROR, ASL_MSG_BUFFER_ELEMENT, Field, MsgBuffer);
+            return (ByteLength - Count);
         }
+
+        Buffer[i] = (UINT8) Value;
     }
 
-Exit:
     ACPI_FREE (StringValue);
     return (ByteLength - Count);
 }
@@ -608,13 +554,13 @@ Exit:
  *
  * FUNCTION:    DtCompileFlag
  *
- * PARAMETERS:  Buffer                      - Output buffer
- *              Field                       - Field to be compiled
- *              Info                        - Flag info
+ * PARAMETERS:  Buffer              - Output buffer
+ *              Field               - Field to be compiled
+ *              Info                - Flag info
  *
- * RETURN:      None
+ * RETURN:
  *
- * DESCRIPTION: Compile a flag field. Handles flags up to 64 bits.
+ * DESCRIPTION: Compile a flag
  *
  *****************************************************************************/
 
@@ -627,9 +573,14 @@ DtCompileFlag (
     UINT64                  Value = 0;
     UINT32                  BitLength = 1;
     UINT8                   BitPosition = 0;
+    ACPI_STATUS             Status;
 
 
-    Value = AcpiUtImplicitStrtoul64 (Field->Value);
+    Status = DtStrtoul64 (Field->Value, &Value);
+    if (ACPI_FAILURE (Status))
+    {
+        DtError (ASL_ERROR, ASL_MSG_INVALID_HEX_INTEGER, Field, NULL);
+    }
 
     switch (Info->Opcode)
     {
@@ -672,36 +623,6 @@ DtCompileFlag (
         BitLength = 2;
         break;
 
-    case ACPI_DMT_FLAGS4_0:
-
-        BitPosition = 0;
-        BitLength = 4;
-        break;
-
-    case ACPI_DMT_FLAGS4_4:
-
-        BitPosition = 4;
-        BitLength = 4;
-        break;
-
-    case ACPI_DMT_FLAGS4_8:
-
-        BitPosition = 8;
-        BitLength = 4;
-        break;
-
-    case ACPI_DMT_FLAGS4_12:
-
-        BitPosition = 12;
-        BitLength = 4;
-        break;
-
-    case ACPI_DMT_FLAGS16_16:
-
-        BitPosition = 16;
-        BitLength = 16;
-        break;
-
     default:
 
         DtFatal (ASL_MSG_COMPILER_INTERNAL, Field, "Invalid flag opcode");
@@ -712,8 +633,8 @@ DtCompileFlag (
 
     if (Value >= ((UINT64) 1 << BitLength))
     {
-        sprintf (AslGbl_MsgBuffer, "Maximum %u bit", BitLength);
-        DtError (ASL_ERROR, ASL_MSG_FLAG_VALUE, Field, AslGbl_MsgBuffer);
+        sprintf (MsgBuffer, "Maximum %u bit", BitLength);
+        DtError (ASL_ERROR, ASL_MSG_FLAG_VALUE, Field, MsgBuffer);
         Value = 0;
     }
 
