@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,9 +113,10 @@
  *
  *****************************************************************************/
 
+#define __DTIO_C__
+
 #include "aslcompiler.h"
 #include "dtcompiler.h"
-#include "acapps.h"
 
 #define _COMPONENT          DT_COMPILER
         ACPI_MODULE_NAME    ("dtio")
@@ -203,7 +204,7 @@ DtTrim (
 
     if (!ACPI_STRCMP (String, " "))
     {
-        ReturnString = UtStringCacheCalloc (1);
+        ReturnString = UtLocalCalloc (1);
         return (ReturnString);
     }
 
@@ -251,7 +252,7 @@ DtTrim (
     /* Create the trimmed return string */
 
     Length = ACPI_PTR_DIFF (End, Start) + 1;
-    ReturnString = UtStringCacheCalloc (Length + 1);
+    ReturnString = UtLocalCalloc (Length + 1);
     if (ACPI_STRLEN (Start))
     {
         ACPI_STRNCPY (ReturnString, Start, Length);
@@ -358,21 +359,31 @@ DtParseLine (
 
     while (Start < Colon)
     {
+        if (*Start == ' ')
+        {
+            Start++;
+            continue;
+        }
+
+        /* Found left bracket, go to the right bracket */
+
         if (*Start == '[')
         {
-            /* Found left bracket, go to the right bracket */
-
             while (Start < Colon && *Start != ']')
             {
                 Start++;
             }
-        }
-        else if (*Start != ' ')
-        {
-            break;
+
+            if (Start == Colon)
+            {
+                break;
+            }
+
+            Start++;
+            continue;
         }
 
-        Start++;
+        break;
     }
 
     /*
@@ -440,18 +451,21 @@ DtParseLine (
 
     if ((Value && *Value) || IsNullString)
     {
-        Field = UtFieldCacheCalloc ();
+        Field = UtLocalCalloc (sizeof (DT_FIELD));
         Field->Name = Name;
         Field->Value = Value;
         Field->Line = Line;
         Field->ByteOffset = Offset;
         Field->NameColumn = NameColumn;
         Field->Column = Column;
-        Field->StringLength = Length;
 
         DtLinkField (Field);
     }
-    /* Else -- Ignore this field, it has no valid data */
+    else /* Ignore this field, it has no valid data */
+    {
+        ACPI_FREE (Name);
+        ACPI_FREE (Value);
+    }
 
     return (AE_OK);
 }
@@ -487,7 +501,6 @@ DtGetNextLine (
     int                     c;
 
 
-    ACPI_MEMSET (Gbl_CurrentLineBuffer, 0, Gbl_LineBufferSize);
     for (i = 0; ;)
     {
         /*
@@ -806,11 +819,7 @@ DtScanFile (
 
     /* Get the file size */
 
-    Gbl_InputByteCount = CmGetFileSize (Handle);
-    if (Gbl_InputByteCount == ACPI_UINT32_MAX)
-    {
-        AslAbort ();
-    }
+    Gbl_InputByteCount = DtGetFileSize (Handle);
 
     Gbl_CurrentLineNumber = 0;
     Gbl_CurrentLineOffset = 0;
@@ -889,12 +898,7 @@ DtOutputBinary (
     /* Walk the entire parse tree, emitting the binary data */
 
     DtWalkTableTree (RootTable, DtWriteBinary, NULL, NULL);
-
-    Gbl_TableLength = CmGetFileSize (Gbl_Files[ASL_FILE_AML_OUTPUT].Handle);
-    if (Gbl_TableLength == ACPI_UINT32_MAX)
-    {
-        AslAbort ();
-    }
+    Gbl_TableLength = DtGetFileSize (Gbl_Files[ASL_FILE_AML_OUTPUT].Handle);
 }
 
 
@@ -1013,11 +1017,11 @@ DtDumpFieldList (
 
     DbgPrint (ASL_DEBUG_OUTPUT,  "\nField List:\n"
         "LineNo   ByteOff  NameCol  Column   TableOff "
-        "Flags %32s : %s\n\n", "Name", "Value");
+        "Flags    %32s : %s\n\n", "Name", "Value");
     while (Field)
     {
         DbgPrint (ASL_DEBUG_OUTPUT,
-            "%.08X %.08X %.08X %.08X %.08X %2.2X    %32s : %s\n",
+            "%.08X %.08X %.08X %.08X %.08X %.08X %32s : %s\n",
             Field->Line, Field->ByteOffset, Field->NameColumn,
             Field->Column, Field->TableOffset, Field->Flags,
             Field->Name, Field->Value);
@@ -1050,8 +1054,8 @@ DtDumpSubtableInfo (
 {
 
     DbgPrint (ASL_DEBUG_OUTPUT,
-        "[%.04X] %24s %.08X %.08X %.08X %.08X %.08X %p %p %p\n",
-        Subtable->Depth, Subtable->Name, Subtable->Length, Subtable->TotalLength,
+        "[%.04X] %.08X %.08X %.08X %.08X %.08X %p %p %p\n",
+        Subtable->Depth, Subtable->Length, Subtable->TotalLength,
         Subtable->SizeOfLengthField, Subtable->Flags, Subtable,
         Subtable->Parent, Subtable->Child, Subtable->Peer);
 }
@@ -1064,8 +1068,8 @@ DtDumpSubtableTree (
 {
 
     DbgPrint (ASL_DEBUG_OUTPUT,
-        "[%.04X] %24s %*s%08X (%.02X) - (%.02X)\n",
-        Subtable->Depth, Subtable->Name, (4 * Subtable->Depth), " ",
+        "[%.04X] %*s%08X (%.02X) - (%.02X)\n",
+        Subtable->Depth, (4 * Subtable->Depth), " ",
         Subtable, Subtable->Length, Subtable->TotalLength);
 }
 
@@ -1096,15 +1100,13 @@ DtDumpSubtableList (
 
     DbgPrint (ASL_DEBUG_OUTPUT,
         "Subtable Info:\n"
-        "Depth                      Name Length   TotalLen LenSize  Flags    "
+        "Depth  Length   TotalLen LenSize  Flags    "
         "This     Parent   Child    Peer\n\n");
     DtWalkTableTree (Gbl_RootTable, DtDumpSubtableInfo, NULL, NULL);
 
     DbgPrint (ASL_DEBUG_OUTPUT,
-        "\nSubtable Tree: (Depth, Name, Subtable, Length, TotalLength)\n\n");
+        "\nSubtable Tree: (Depth, Subtable, Length, TotalLength)\n\n");
     DtWalkTableTree (Gbl_RootTable, DtDumpSubtableTree, NULL, NULL);
-
-    DbgPrint (ASL_DEBUG_OUTPUT, "\n");
 }
 
 
@@ -1208,5 +1210,4 @@ DtWriteTableToListing (
     AcpiUtDumpBuffer (Buffer, Gbl_TableLength, DB_BYTE_DISPLAY, 0);
 
     AcpiOsRedirectOutput (stdout);
-    ACPI_FREE (Buffer);
 }
