@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,8 @@
  *
  *****************************************************************************/
 
+#define __DTUTILS_C__
+
 #include "aslcompiler.h"
 #include "dtcompiler.h"
 #include "actables.h"
@@ -147,7 +149,7 @@ DtSum (
 void
 DtError (
     UINT8                   Level,
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     DT_FIELD                *FieldObject,
     char                    *ExtraMessage)
 {
@@ -194,7 +196,7 @@ DtError (
 void
 DtNameError (
     UINT8                   Level,
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     DT_FIELD                *FieldObject,
     char                    *ExtraMessage)
 {
@@ -247,7 +249,7 @@ DtNameError (
 
 void
 DtFatal (
-    UINT16                  MessageId,
+    UINT8                   MessageId,
     DT_FIELD                *FieldObject,
     char                    *ExtraMessage)
 {
@@ -354,6 +356,36 @@ DtStrtoul64 (
 }
 
 
+/******************************************************************************
+ *
+ * FUNCTION:    DtGetFileSize
+ *
+ * PARAMETERS:  Handle              - Open file handler
+ *
+ * RETURN:      Current file size
+ *
+ * DESCRIPTION: Get the current size of a file. Seek to the EOF and get the
+ *              offset. Seek back to the original location.
+ *
+ *****************************************************************************/
+
+UINT32
+DtGetFileSize (
+    FILE                    *Handle)
+{
+    int                     CurrentOffset;
+    int                     LastOffset;
+
+
+    CurrentOffset = ftell (Handle);
+    fseek (Handle, 0, SEEK_END);
+    LastOffset = ftell (Handle);
+    fseek (Handle, CurrentOffset, SEEK_SET);
+
+    return ((UINT32) LastOffset);
+}
+
+
 /******************************************************************************
  *
  * FUNCTION:    DtGetFieldValue
@@ -436,9 +468,7 @@ DtGetFieldType (
         break;
 
     case ACPI_DMT_BUFFER:
-    case ACPI_DMT_RAW_BUFFER:
     case ACPI_DMT_BUF7:
-    case ACPI_DMT_BUF10:
     case ACPI_DMT_BUF16:
     case ACPI_DMT_BUF128:
     case ACPI_DMT_PCI_PATH:
@@ -448,7 +478,6 @@ DtGetFieldType (
 
     case ACPI_DMT_GAS:
     case ACPI_DMT_HESTNTFY:
-    case ACPI_DMT_IORTMEM:
 
         Type = DT_FIELD_TYPE_INLINE_SUBTABLE;
         break;
@@ -573,9 +602,7 @@ DtGetFieldLength (
     case ACPI_DMT_SPACEID:
     case ACPI_DMT_ACCWIDTH:
     case ACPI_DMT_IVRS:
-    case ACPI_DMT_GTDT:
     case ACPI_DMT_MADT:
-    case ACPI_DMT_PCCT:
     case ACPI_DMT_PMTT:
     case ACPI_DMT_SRAT:
     case ACPI_DMT_ASF:
@@ -585,7 +612,6 @@ DtGetFieldLength (
     case ACPI_DMT_EINJINST:
     case ACPI_DMT_ERSTACT:
     case ACPI_DMT_ERSTINST:
-    case ACPI_DMT_DMAR_SCOPE:
 
         ByteLength = 1;
         break;
@@ -593,7 +619,6 @@ DtGetFieldLength (
     case ACPI_DMT_UINT16:
     case ACPI_DMT_DMAR:
     case ACPI_DMT_HEST:
-    case ACPI_DMT_NFIT:
     case ACPI_DMT_PCI_PATH:
 
         ByteLength = 2;
@@ -606,8 +631,8 @@ DtGetFieldLength (
 
     case ACPI_DMT_UINT32:
     case ACPI_DMT_NAME4:
+    case ACPI_DMT_SLIC:
     case ACPI_DMT_SIG:
-    case ACPI_DMT_LPIT:
 
         ByteLength = 4;
         break;
@@ -661,13 +686,7 @@ DtGetFieldLength (
         ByteLength = sizeof (ACPI_HEST_NOTIFY);
         break;
 
-    case ACPI_DMT_IORTMEM:
-
-        ByteLength = sizeof (ACPI_IORT_MEMORY_ACCESS);
-        break;
-
     case ACPI_DMT_BUFFER:
-    case ACPI_DMT_RAW_BUFFER:
 
         Value = DtGetFieldValue (Field);
         if (Value)
@@ -683,11 +702,6 @@ DtGetFieldLength (
         }
         break;
 
-    case ACPI_DMT_BUF10:
-
-        ByteLength = 10;
-        break;
-
     case ACPI_DMT_BUF16:
     case ACPI_DMT_UUID:
 
@@ -923,151 +937,39 @@ DtWalkTableTree (
 }
 
 
-/*******************************************************************************
+/******************************************************************************
  *
- * FUNCTION:    UtSubtableCacheCalloc
- *
- * PARAMETERS:  None
- *
- * RETURN:      Pointer to the buffer. Aborts on allocation failure
- *
- * DESCRIPTION: Allocate a subtable object buffer. Bypass the local
- *              dynamic memory manager for performance reasons (This has a
- *              major impact on the speed of the compiler.)
- *
- ******************************************************************************/
-
-DT_SUBTABLE *
-UtSubtableCacheCalloc (
-    void)
-{
-    ASL_CACHE_INFO          *Cache;
-
-
-    if (Gbl_SubtableCacheNext >= Gbl_SubtableCacheLast)
-    {
-        /* Allocate a new buffer */
-
-        Cache = UtLocalCalloc (sizeof (Cache->Next) +
-            (sizeof (DT_SUBTABLE) * ASL_SUBTABLE_CACHE_SIZE));
-
-        /* Link new cache buffer to head of list */
-
-        Cache->Next = Gbl_SubtableCacheList;
-        Gbl_SubtableCacheList = Cache;
-
-        /* Setup cache management pointers */
-
-        Gbl_SubtableCacheNext = ACPI_CAST_PTR (DT_SUBTABLE, Cache->Buffer);
-        Gbl_SubtableCacheLast = Gbl_SubtableCacheNext + ASL_SUBTABLE_CACHE_SIZE;
-    }
-
-    Gbl_SubtableCount++;
-    return (Gbl_SubtableCacheNext++);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    UtFieldCacheCalloc
- *
- * PARAMETERS:  None
- *
- * RETURN:      Pointer to the buffer. Aborts on allocation failure
- *
- * DESCRIPTION: Allocate a field object buffer. Bypass the local
- *              dynamic memory manager for performance reasons (This has a
- *              major impact on the speed of the compiler.)
- *
- ******************************************************************************/
-
-DT_FIELD *
-UtFieldCacheCalloc (
-    void)
-{
-    ASL_CACHE_INFO          *Cache;
-
-
-    if (Gbl_FieldCacheNext >= Gbl_FieldCacheLast)
-    {
-        /* Allocate a new buffer */
-
-        Cache = UtLocalCalloc (sizeof (Cache->Next) +
-            (sizeof (DT_FIELD) * ASL_FIELD_CACHE_SIZE));
-
-        /* Link new cache buffer to head of list */
-
-        Cache->Next = Gbl_FieldCacheList;
-        Gbl_FieldCacheList = Cache;
-
-        /* Setup cache management pointers */
-
-        Gbl_FieldCacheNext = ACPI_CAST_PTR (DT_FIELD, Cache->Buffer);
-        Gbl_FieldCacheLast = Gbl_FieldCacheNext + ASL_FIELD_CACHE_SIZE;
-    }
-
-    Gbl_FieldCount++;
-    return (Gbl_FieldCacheNext++);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    DtDeleteCaches
+ * FUNCTION:    DtFreeFieldList
  *
  * PARAMETERS:  None
  *
  * RETURN:      None
  *
- * DESCRIPTION: Delete all local cache buffer blocks
+ * DESCRIPTION: Free the field list
  *
- ******************************************************************************/
+ *****************************************************************************/
 
 void
-DtDeleteCaches (
+DtFreeFieldList (
     void)
 {
-    UINT32                  BufferCount;
-    ASL_CACHE_INFO          *Next;
+    DT_FIELD                *Field = Gbl_FieldList;
+    DT_FIELD                *NextField;
 
 
-    /* Field cache */
+    /* Walk and free entire field list */
 
-    BufferCount = 0;
-    while (Gbl_FieldCacheList)
+    while (Field)
     {
-        Next = Gbl_FieldCacheList->Next;
-        ACPI_FREE (Gbl_FieldCacheList);
-        Gbl_FieldCacheList = Next;
-        BufferCount++;
+        NextField = Field->Next; /* Save link */
+
+        if (!(Field->Flags & DT_FIELD_NOT_ALLOCATED))
+        {
+            ACPI_FREE (Field->Name);
+            ACPI_FREE (Field->Value);
+        }
+
+        ACPI_FREE (Field);
+        Field = NextField;
     }
-
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "%u Fields, Buffer size: %u fields (%u bytes), %u Buffers\n",
-        Gbl_FieldCount, ASL_FIELD_CACHE_SIZE,
-        (sizeof (DT_FIELD) * ASL_FIELD_CACHE_SIZE), BufferCount);
-
-    Gbl_FieldCount = 0;
-    Gbl_FieldCacheNext = NULL;
-    Gbl_FieldCacheLast = NULL;
-
-    /* Subtable cache */
-
-    BufferCount = 0;
-    while (Gbl_SubtableCacheList)
-    {
-        Next = Gbl_SubtableCacheList->Next;
-        ACPI_FREE (Gbl_SubtableCacheList);
-        Gbl_SubtableCacheList = Next;
-        BufferCount++;
-    }
-
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "%u Subtables, Buffer size: %u subtables (%u bytes), %u Buffers\n",
-        Gbl_SubtableCount, ASL_SUBTABLE_CACHE_SIZE,
-        (sizeof (DT_SUBTABLE) * ASL_SUBTABLE_CACHE_SIZE), BufferCount);
-
-    Gbl_SubtableCount = 0;
-    Gbl_SubtableCacheNext = NULL;
-    Gbl_SubtableCacheLast = NULL;
 }
