@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -137,62 +137,34 @@ PrPreprocessInputFile (
 static void
 PrDoDirective (
     char                    *DirectiveToken,
-    char                    **Next);
+    char                    **Next,
+    BOOLEAN                 *IgnoringThisCodeBlock);
 
 static int
 PrMatchDirective (
     char                    *Directive);
 
-static void
-PrPushDirective (
-    int                     Directive,
-    char                    *Argument);
-
-static ACPI_STATUS
-PrPopDirective (
-    void);
-
-static void
-PrDbgPrint (
-    char                    *Action,
-    char                    *DirectiveName);
-
-static void
-PrDoIncludeBuffer (
-    char                    *Pathname,
-    char                    *BufferName);
-
-static void
-PrDoIncludeFile (
-    char                    *Pathname);
-
-
 /*
  * Supported preprocessor directives
- * Each entry is of the form "Name, ArgumentCount"
  */
 static const PR_DIRECTIVE_INFO      Gbl_DirectiveInfo[] =
 {
-    {"define",          1},
-    {"elif",            0}, /* Converted to #else..#if internally */
-    {"else",            0},
-    {"endif",           0},
-    {"error",           1},
-    {"if",              1},
-    {"ifdef",           1},
-    {"ifndef",          1},
-    {"include",         0}, /* Argument is not standard format, so just use 0 here */
-    {"includebuffer",   0}, /* Argument is not standard format, so just use 0 here */
-    {"line",            1},
-    {"loadbuffer",      0},
-    {"pragma",          1},
-    {"undef",           1},
-    {"warning",         1},
-    {NULL,              0}
+    {"define",  1},
+    {"elif",    0}, /* Converted to #else..#if internally */
+    {"else",    0},
+    {"endif",   0},
+    {"error",   1},
+    {"if",      1},
+    {"ifdef",   1},
+    {"ifndef",  1},
+    {"include", 0}, /* Argument is not standard format, so 0 */
+    {"line",    1},
+    {"pragma",  1},
+    {"undef",   1},
+    {"warning", 1},
+    {NULL,      0}
 };
 
-/* This table must match ordering of above table exactly */
-
 enum Gbl_DirectiveIndexes
 {
     PR_DIRECTIVE_DEFINE = 0,
@@ -204,7 +176,6 @@ enum Gbl_DirectiveIndexes
     PR_DIRECTIVE_IFDEF,
     PR_DIRECTIVE_IFNDEF,
     PR_DIRECTIVE_INCLUDE,
-    PR_DIRECTIVE_INCLUDEBUFFER,
     PR_DIRECTIVE_LINE,
     PR_DIRECTIVE_PRAGMA,
     PR_DIRECTIVE_UNDEF,
@@ -257,16 +228,11 @@ PrInitializeGlobals (
 {
     /* Init globals */
 
+    Gbl_IfDepth = 0;
     Gbl_InputFileList = NULL;
     Gbl_CurrentLineNumber = 0;
     Gbl_PreprocessorLineNumber = 1;
     Gbl_PreprocessorError = FALSE;
-
-    /* These are used to track #if/#else blocks (possibly nested) */
-
-    Gbl_IfDepth = 0;
-    Gbl_IgnoringThisCodeBlock = FALSE;
-    Gbl_DirectiveStack = NULL;
 }
 
 
@@ -313,7 +279,7 @@ PrTerminatePreprocessor (
  *
  * PARAMETERS:  None
  *
- * RETURN:      None
+ * RETURN:      Error Status. TRUE if error, FALSE if OK.
  *
  * DESCRIPTION: Main entry point for the iASL Preprocessor. Input file must
  *              be already open. Handles multiple input files via the
@@ -321,7 +287,7 @@ PrTerminatePreprocessor (
  *
  ******************************************************************************/
 
-void
+BOOLEAN
 PrDoPreprocess (
     void)
 {
@@ -343,7 +309,20 @@ PrDoPreprocess (
 
     } while (MoreInputFiles);
 
-    /* Point compiler input to the new preprocessor output file (.i) */
+
+    /*
+     * TBD: is this necessary? (Do we abort on any preprocessing errors?)
+     */
+    if (Gbl_PreprocessorError)
+    {
+        /* TBD: can't use source_output file for preprocessor error reporting */
+
+        Gbl_Files[ASL_FILE_SOURCE_OUTPUT].Handle = NULL;
+        PrTerminatePreprocessor ();
+        return (TRUE);
+    }
+
+    /* Point compiler input to the new preprocessor file (.i) */
 
     FlCloseFile (ASL_FILE_INPUT);
     Gbl_Files[ASL_FILE_INPUT].Handle = Gbl_Files[ASL_FILE_PREPROCESSOR].Handle;
@@ -355,6 +334,7 @@ PrDoPreprocess (
     Gbl_CurrentLineNumber = 1;
 
     DbgPrint (ASL_DEBUG_OUTPUT, "Preprocessing phase complete \n\n");
+    return (FALSE);
 }
 
 
@@ -382,6 +362,7 @@ PrPreprocessInputFile (
     char                    *ReplaceString;
     PR_DEFINE_INFO          *DefineInfo;
     ACPI_SIZE               TokenOffset;
+    BOOLEAN                 IgnoringThisCodeBlock = FALSE;
     char                    *Next;
     int                     OffsetAdjust;
 
@@ -411,7 +392,7 @@ PrPreprocessInputFile (
 
             /* Execute the directive, do not write line to output file */
 
-            PrDoDirective (Token, &Next);
+            PrDoDirective (Token, &Next, &IgnoringThisCodeBlock);
             continue;
         }
 
@@ -420,7 +401,7 @@ PrPreprocessInputFile (
          * FALSE, ignore the line and do not write it to the output file.
          * This continues until an #else or #endif is encountered.
          */
-        if (Gbl_IgnoringThisCodeBlock)
+        if (IgnoringThisCodeBlock == TRUE)
         {
             continue;
         }
@@ -469,6 +450,13 @@ PrPreprocessInputFile (
             Token = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, &Next);
         }
 
+#if 0
+/* Line prefix */
+        FlPrintFile (ASL_FILE_PREPROCESSOR, "/* %14s  %.5u  i:%.5u */ ",
+            Gbl_Files[ASL_FILE_INPUT].Filename,
+            Gbl_CurrentLineNumber, Gbl_PreprocessorLineNumber);
+#endif
+
         /*
          * Emit a #line directive if necessary, to keep the line numbers in
          * the (.i) file synchronized with the original source code file, so
@@ -500,8 +488,12 @@ PrPreprocessInputFile (
  *
  * PARAMETERS:  Directive               - Pointer to directive name token
  *              Next                    - "Next" buffer from GetNextToken
+ *              IgnoringThisCodeBlock   - Where the "ignore code" flag is
+ *                                        returned.
  *
- * RETURN:      None.
+ * RETURN:      IgnoringThisCodeBlock: Set to TRUE if we are skipping the FALSE
+ *              part of an #if or #else block. Set to FALSE when the
+ *              corresponding #else or #endif is encountered.
  *
  * DESCRIPTION: Main processing for all preprocessor directives
  *
@@ -510,10 +502,11 @@ PrPreprocessInputFile (
 static void
 PrDoDirective (
     char                    *DirectiveToken,
-    char                    **Next)
+    char                    **Next,
+    BOOLEAN                 *IgnoringThisCodeBlock)
 {
     char                    *Token = Gbl_MainTokenBuffer;
-    char                    *Token2 = NULL;
+    char                    *Token2;
     char                    *End;
     UINT64                  Value;
     ACPI_SIZE               TokenOffset;
@@ -532,34 +525,20 @@ PrDoDirective (
         PrError (ASL_ERROR, ASL_MSG_UNKNOWN_DIRECTIVE,
             THIS_TOKEN_OFFSET (DirectiveToken));
 
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
             "#%s: Unknown directive\n",
             Gbl_CurrentLineNumber, DirectiveToken);
         return;
     }
 
-    /*
-     * If we are currently ignoring this block and we encounter a #else or
-     * #elif, we must ignore their blocks also if the parent block is also
-     * being ignored.
-     */
-    if (Gbl_IgnoringThisCodeBlock)
+    /* TBD: Need a faster way to do this: */
+
+    if ((Directive == PR_DIRECTIVE_ELIF) ||
+        (Directive == PR_DIRECTIVE_ELSE) ||
+        (Directive == PR_DIRECTIVE_ENDIF))
     {
-        switch (Directive)
-        {
-        case PR_DIRECTIVE_ELSE:
-        case PR_DIRECTIVE_ELIF:
-
-            if (Gbl_DirectiveStack && Gbl_DirectiveStack->IgnoringThisCodeBlock)
-            {
-                PrDbgPrint ("Ignoring", Gbl_DirectiveInfo[Directive].Name);
-                return;
-            }
-            break;
-
-        default:
-            break;
-        }
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID "Begin #%s\n",
+            Gbl_CurrentLineNumber, Gbl_DirectiveInfo[Directive].Name);
     }
 
     /*
@@ -569,57 +548,60 @@ PrDoDirective (
      */
     switch (Directive)
     {
-    case PR_DIRECTIVE_ELSE:
-
-        Gbl_IgnoringThisCodeBlock = !(Gbl_IgnoringThisCodeBlock);
-        PrDbgPrint ("Executing", "else block");
-        return;
-
     case PR_DIRECTIVE_ELIF:
 
-        Gbl_IgnoringThisCodeBlock = !(Gbl_IgnoringThisCodeBlock);
-        Directive = PR_DIRECTIVE_IF;
-
-        if (Gbl_IgnoringThisCodeBlock == TRUE)
+        *IgnoringThisCodeBlock = !(*IgnoringThisCodeBlock);
+        if (*IgnoringThisCodeBlock == TRUE)
         {
             /* Not executing the ELSE part -- all done here */
-            PrDbgPrint ("Ignoring", "elif block");
             return;
         }
 
-        /*
-         * After this, we will execute the IF part further below.
-         * First, however, pop off the original #if directive.
-         */
-        if (ACPI_FAILURE (PrPopDirective ()))
-        {
-            PrError (ASL_ERROR, ASL_MSG_COMPILER_INTERNAL,
-                THIS_TOKEN_OFFSET (DirectiveToken));
-        }
+        /* Will execute the ELSE..IF part */
 
-        PrDbgPrint ("Executing", "elif block");
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
+            "#elif - Executing else block\n",
+            Gbl_CurrentLineNumber);
+        Directive = PR_DIRECTIVE_IF;
         break;
 
+    case PR_DIRECTIVE_ELSE:
+
+        *IgnoringThisCodeBlock = !(*IgnoringThisCodeBlock);
+        return;
+
     case PR_DIRECTIVE_ENDIF:
 
-        PrDbgPrint ("Executing", "endif");
-
-        /* Pop the owning #if/#ifdef/#ifndef */
-
-        if (ACPI_FAILURE (PrPopDirective ()))
+        *IgnoringThisCodeBlock = FALSE;
+        Gbl_IfDepth--;
+        if (Gbl_IfDepth < 0)
         {
             PrError (ASL_ERROR, ASL_MSG_ENDIF_MISMATCH,
                 THIS_TOKEN_OFFSET (DirectiveToken));
+            Gbl_IfDepth = 0;
         }
         return;
 
     default:
+
         break;
     }
 
+    /*
+     * At this point, if we are ignoring the current code block,
+     * do not process any more directives (i.e., ignore them also.)
+     */
+    if (*IgnoringThisCodeBlock == TRUE)
+    {
+        return;
+    }
+
+    DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID "Begin #%s\n",
+        Gbl_CurrentLineNumber, Gbl_DirectiveInfo[Directive].Name);
+
     /* Most directives have at least one argument */
 
-    if (Gbl_DirectiveInfo[Directive].ArgCount >= 1)
+    if (Gbl_DirectiveInfo[Directive].ArgCount == 1)
     {
         Token = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, Next);
         if (!Token)
@@ -628,94 +610,8 @@ PrDoDirective (
         }
     }
 
-    if (Gbl_DirectiveInfo[Directive].ArgCount >= 2)
-    {
-        Token2 = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, Next);
-        if (!Token2)
-        {
-            goto SyntaxError;
-        }
-    }
-
-    /*
-     * At this point, if we are ignoring the current code block,
-     * do not process any more directives (i.e., ignore them also.)
-     * For "if" style directives, open/push a new block anyway. We
-     * must do this to keep track of #endif directives
-     */
-    if (Gbl_IgnoringThisCodeBlock)
-    {
-        switch (Directive)
-        {
-        case PR_DIRECTIVE_IF:
-        case PR_DIRECTIVE_IFDEF:
-        case PR_DIRECTIVE_IFNDEF:
-
-            PrPushDirective (Directive, Token);
-            PrDbgPrint ("Ignoring", Gbl_DirectiveInfo[Directive].Name);
-            break;
-
-        default:
-            break;
-        }
-
-        return;
-    }
-
-    /*
-     * Execute the directive
-     */
-    PrDbgPrint ("Begin execution", Gbl_DirectiveInfo[Directive].Name);
-
     switch (Directive)
     {
-    case PR_DIRECTIVE_IF:
-
-        TokenOffset = Token - Gbl_MainTokenBuffer;
-
-        /* Need to expand #define macros in the expression string first */
-
-        Status = PrResolveIntegerExpression (
-            &Gbl_CurrentLineBuffer[TokenOffset-1], &Value);
-        if (ACPI_FAILURE (Status))
-        {
-            return;
-        }
-
-        PrPushDirective (Directive, Token);
-        if (!Value)
-        {
-            Gbl_IgnoringThisCodeBlock = TRUE;
-        }
-
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-            "Resolved #if: %8.8X%8.8X %s\n",
-            Gbl_CurrentLineNumber, ACPI_FORMAT_UINT64 (Value),
-            Gbl_IgnoringThisCodeBlock ? "<Skipping Block>" : "<Executing Block>");
-        break;
-
-    case PR_DIRECTIVE_IFDEF:
-
-        PrPushDirective (Directive, Token);
-        if (!PrMatchDefine (Token))
-        {
-            Gbl_IgnoringThisCodeBlock = TRUE;
-        }
-
-        PrDbgPrint ("Evaluated", "ifdef");
-        break;
-
-    case PR_DIRECTIVE_IFNDEF:
-
-        PrPushDirective (Directive, Token);
-        if (PrMatchDefine (Token))
-        {
-            Gbl_IgnoringThisCodeBlock = TRUE;
-        }
-
-        PrDbgPrint ("Evaluated", "ifndef");
-        break;
-
     case PR_DIRECTIVE_DEFINE:
         /*
          * By definition, if first char after the name is a paren,
@@ -761,7 +657,7 @@ PrDoDirective (
                 Token2 = "";
             }
 #endif
-            DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+            DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
                 "New #define: %s->%s\n",
                 Gbl_CurrentLineNumber, Token, Token2);
 
@@ -771,15 +667,64 @@ PrDoDirective (
 
     case PR_DIRECTIVE_ERROR:
 
+        /* TBD compiler should abort */
         /* Note: No macro expansion */
 
         PrError (ASL_ERROR, ASL_MSG_ERROR_DIRECTIVE,
             THIS_TOKEN_OFFSET (Token));
+        break;
 
-        Gbl_SourceLine = 0;
-        Gbl_NextError = Gbl_ErrorLog;
-        CmCleanupAndExit ();
-        exit(1);
+    case PR_DIRECTIVE_IF:
+
+        TokenOffset = Token - Gbl_MainTokenBuffer;
+
+        /* Need to expand #define macros in the expression string first */
+
+        Status = PrResolveIntegerExpression (
+            &Gbl_CurrentLineBuffer[TokenOffset-1], &Value);
+        if (ACPI_FAILURE (Status))
+        {
+            return;
+        }
+
+        if (!Value)
+        {
+            *IgnoringThisCodeBlock = TRUE;
+        }
+
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
+            "Resolved #if: %8.8X%8.8X %s\n",
+            Gbl_CurrentLineNumber, ACPI_FORMAT_UINT64 (Value),
+            *IgnoringThisCodeBlock ? "<Skipping Block>" : "<Executing Block>");
+
+        Gbl_IfDepth++;
+        break;
+
+    case PR_DIRECTIVE_IFDEF:
+
+        if (!PrMatchDefine (Token))
+        {
+            *IgnoringThisCodeBlock = TRUE;
+        }
+
+        Gbl_IfDepth++;
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
+            "Start #ifdef %s\n", Gbl_CurrentLineNumber,
+            *IgnoringThisCodeBlock ? "<Skipping Block>" : "<Executing Block>");
+        break;
+
+    case PR_DIRECTIVE_IFNDEF:
+
+        if (PrMatchDefine (Token))
+        {
+            *IgnoringThisCodeBlock = TRUE;
+        }
+
+        Gbl_IfDepth++;
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
+            "Start #ifndef %2.2X\n", Gbl_CurrentLineNumber,
+            *IgnoringThisCodeBlock, Gbl_CurrentLineNumber);
+        break;
 
     case PR_DIRECTIVE_INCLUDE:
 
@@ -789,32 +734,11 @@ PrDoDirective (
             goto SyntaxError;
         }
 
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
             "Start #include file \"%s\"\n", Gbl_CurrentLineNumber,
             Token, Gbl_CurrentLineNumber);
 
-        PrDoIncludeFile (Token);
-        break;
-
-    case PR_DIRECTIVE_INCLUDEBUFFER:
-
-        Token = PrGetNextToken (NULL, " \"<>", Next);
-        if (!Token)
-        {
-            goto SyntaxError;
-        }
-
-        Token2 = PrGetNextToken (NULL, PR_TOKEN_SEPARATORS, Next);
-        if (!Token2)
-        {
-            goto SyntaxError;
-        }
-
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-            "Start #includebuffer input from file \"%s\", buffer name %s\n",
-            Gbl_CurrentLineNumber, Token, Token2);
-
-        PrDoIncludeBuffer (Token, Token2);
+        PrOpenIncludeFile (Token);
         break;
 
     case PR_DIRECTIVE_LINE:
@@ -828,7 +752,7 @@ PrDoDirective (
             return;
         }
 
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
             "User #line invocation %s\n", Gbl_CurrentLineNumber,
             Token);
 
@@ -878,7 +802,7 @@ PrDoDirective (
 
     case PR_DIRECTIVE_UNDEF:
 
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
             "#undef: %s\n", Gbl_CurrentLineNumber, Token);
 
         PrRemoveDefine (Token);
@@ -886,14 +810,14 @@ PrDoDirective (
 
     case PR_DIRECTIVE_WARNING:
 
-        PrError (ASL_WARNING, ASL_MSG_WARNING_DIRECTIVE,
+        PrError (ASL_WARNING, ASL_MSG_ERROR_DIRECTIVE,
             THIS_TOKEN_OFFSET (Token));
         break;
 
     default:
 
         /* Should never get here */
-        DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
+        DbgPrint (ASL_DEBUG_OUTPUT, PR_PREFIX_ID
             "Unrecognized directive: %u\n",
             Gbl_CurrentLineNumber, Directive);
         break;
@@ -901,6 +825,7 @@ PrDoDirective (
 
     return;
 
+
 SyntaxError:
 
     PrError (ASL_ERROR, ASL_MSG_DIRECTIVE_SYNTAX,
@@ -943,213 +868,3 @@ PrMatchDirective (
 
     return (ASL_DIRECTIVE_NOT_FOUND);    /* Command not recognized */
 }
-
-
-/*******************************************************************************
- *
- * FUNCTION:    PrPushDirective
- *
- * PARAMETERS:  Directive           - Encoded directive ID
- *              Argument            - String containing argument to the
- *                                    directive
- *
- * RETURN:      None
- *
- * DESCRIPTION: Push an item onto the directive stack. Used for processing
- *              nested #if/#else type conditional compilation directives.
- *              Specifically: Used on detection of #if/#ifdef/#ifndef to open
- *              a block.
- *
- ******************************************************************************/
-
-static void
-PrPushDirective (
-    int                     Directive,
-    char                    *Argument)
-{
-    DIRECTIVE_INFO          *Info;
-
-
-    /* Allocate and populate a stack info item */
-
-    Info = ACPI_ALLOCATE (sizeof (DIRECTIVE_INFO));
-
-    Info->Next = Gbl_DirectiveStack;
-    Info->Directive = Directive;
-    Info->IgnoringThisCodeBlock = Gbl_IgnoringThisCodeBlock;
-    strncpy (Info->Argument, Argument, MAX_ARGUMENT_LENGTH);
-
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "Pr(%.4u) - [%u %s] %*s Pushed [#%s %s]: IgnoreFlag = %s\n",
-        Gbl_CurrentLineNumber, Gbl_IfDepth,
-        Gbl_IgnoringThisCodeBlock ? "I" : "E",
-        Gbl_IfDepth * 4, " ",
-        Gbl_DirectiveInfo[Directive].Name,
-        Argument, Gbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
-
-    /* Push new item */
-
-    Gbl_DirectiveStack = Info;
-    Gbl_IfDepth++;
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    PrPopDirective
- *
- * PARAMETERS:  None
- *
- * RETURN:      Status. Error if the stack is empty.
- *
- * DESCRIPTION: Pop an item off the directive stack. Used for processing
- *              nested #if/#else type conditional compilation directives.
- *              Specifically: Used on detection of #elif and #endif to remove
- *              the original #if/#ifdef/#ifndef from the stack and close
- *              the block.
- *
- ******************************************************************************/
-
-static ACPI_STATUS
-PrPopDirective (
-    void)
-{
-    DIRECTIVE_INFO          *Info;
-
-
-    /* Check for empty stack */
-
-    Info = Gbl_DirectiveStack;
-    if (!Info)
-    {
-        return (AE_ERROR);
-    }
-
-    /* Pop one item, keep globals up-to-date */
-
-    Gbl_IfDepth--;
-    Gbl_IgnoringThisCodeBlock = Info->IgnoringThisCodeBlock;
-    Gbl_DirectiveStack = Info->Next;
-
-    DbgPrint (ASL_DEBUG_OUTPUT,
-        "Pr(%.4u) - [%u %s] %*s Popped [#%s %s]: IgnoreFlag now = %s\n",
-        Gbl_CurrentLineNumber, Gbl_IfDepth,
-        Gbl_IgnoringThisCodeBlock ? "I" : "E",
-        Gbl_IfDepth * 4, " ",
-        Gbl_DirectiveInfo[Info->Directive].Name,
-        Info->Argument, Gbl_IgnoringThisCodeBlock ? "TRUE" : "FALSE");
-
-    ACPI_FREE (Info);
-    return (AE_OK);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    PrDbgPrint
- *
- * PARAMETERS:  Action              - Action being performed
- *              DirectiveName       - Directive being processed
- *
- * RETURN:      None
- *
- * DESCRIPTION: Special debug print for directive processing.
- *
- ******************************************************************************/
-
-static void
-PrDbgPrint (
-    char                    *Action,
-    char                    *DirectiveName)
-{
-
-    DbgPrint (ASL_DEBUG_OUTPUT, "Pr(%.4u) - [%u %s] "
-        "%*s %s #%s, IfDepth %u\n",
-        Gbl_CurrentLineNumber, Gbl_IfDepth,
-        Gbl_IgnoringThisCodeBlock ? "I" : "E",
-        Gbl_IfDepth * 4, " ",
-        Action, DirectiveName, Gbl_IfDepth);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    PrDoIncludeFile
- *
- * PARAMETERS:  Pathname                - Name of the input file
- *
- * RETURN:      None.
- *
- * DESCRIPTION: Open an include file, from #include.
- *
- ******************************************************************************/
-
-static void
-PrDoIncludeFile (
-    char                    *Pathname)
-{
-    char                    *FullPathname;
-
-
-    (void) PrOpenIncludeFile (Pathname, "r", &FullPathname);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    PrDoIncludeBuffer
- *
- * PARAMETERS:  Pathname                - Name of the input binary file
- *              BufferName              - ACPI namepath of the buffer
- *
- * RETURN:      None.
- *
- * DESCRIPTION: Create an ACPI buffer object from a binary file. The contents
- *              of the file are emitted into the buffer object as ascii
- *              hex data. From #includebuffer.
- *
- ******************************************************************************/
-
-static void
-PrDoIncludeBuffer (
-    char                    *Pathname,
-    char                    *BufferName)
-{
-    char                    *FullPathname;
-    FILE                    *BinaryBufferFile;
-    UINT32                  i = 0;
-    UINT8                   c;
-
-
-    BinaryBufferFile = PrOpenIncludeFile (Pathname, "rb", &FullPathname);
-    if (!BinaryBufferFile)
-    {
-        return;
-    }
-
-    /* Emit "Name (XXXX, Buffer() {" header */
-
-    FlPrintFile (ASL_FILE_PREPROCESSOR, "Name (%s, Buffer()\n{", BufferName);
-
-    /* Dump the entire file in ascii hex format */
-
-    while (fread (&c, 1, 1, BinaryBufferFile))
-    {
-        if (!(i % 8))
-        {
-            FlPrintFile (ASL_FILE_PREPROCESSOR, "\n   ", c);
-        }
-
-        FlPrintFile (ASL_FILE_PREPROCESSOR, " 0x%2.2X,", c);
-        i++;
-    }
-
-    DbgPrint (ASL_PARSE_OUTPUT, PR_PREFIX_ID
-        "#includebuffer: read %u bytes from %s\n",
-        Gbl_CurrentLineNumber, i, FullPathname);
-
-    /* Close the Name() operator */
-
-    FlPrintFile (ASL_FILE_PREPROCESSOR, "\n})\n", BufferName);
-    fclose (BinaryBufferFile);
-}
