@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -177,18 +177,16 @@ AcpiDbConvertToNode (
     char                    *InString)
 {
     ACPI_NAMESPACE_NODE     *Node;
-    ACPI_SIZE               Address;
 
 
     if ((*InString >= 0x30) && (*InString <= 0x39))
     {
         /* Numeric argument, convert */
 
-        Address = ACPI_STRTOUL (InString, NULL, 16);
-        Node = ACPI_TO_POINTER (Address);
+        Node = ACPI_TO_POINTER (ACPI_STRTOUL (InString, NULL, 16));
         if (!AcpiOsReadable (Node, sizeof (ACPI_NAMESPACE_NODE)))
         {
-            AcpiOsPrintf ("Address %p is invalid",
+            AcpiOsPrintf ("Address %p is invalid in this address space\n",
                 Node);
             return (NULL);
         }
@@ -197,7 +195,7 @@ AcpiDbConvertToNode (
 
         if (ACPI_GET_DESCRIPTOR_TYPE (Node) != ACPI_DESC_TYPE_NAMED)
         {
-            AcpiOsPrintf ("Address %p is not a valid namespace node [%s]\n",
+            AcpiOsPrintf ("Address %p is not a valid NS node [%s]\n",
                     Node, AcpiUtGetDescriptorName (Node));
             return (NULL);
         }
@@ -211,8 +209,6 @@ AcpiDbConvertToNode (
         Node = AcpiDbLocalNsLookup (InString);
         if (!Node)
         {
-            AcpiOsPrintf ("Could not find [%s] in namespace, defaulting to root node\n",
-                InString);
             Node = AcpiGbl_RootNode;
         }
     }
@@ -411,7 +407,7 @@ AcpiDbDisplayTableInfo (
 
     /* Header */
 
-    AcpiOsPrintf ("Idx ID    Status Type              TableHeader (Sig, Address, Length)\n");
+    AcpiOsPrintf ("Idx ID Status    Type            Sig  Address  Len   Header\n");
 
     /* Walk the entire root table list */
 
@@ -436,30 +432,35 @@ AcpiDbDisplayTableInfo (
 
         switch (TableDesc->Flags & ACPI_TABLE_ORIGIN_MASK)
         {
-        case ACPI_TABLE_ORIGIN_EXTERNAL_VIRTUAL:
+        case ACPI_TABLE_ORIGIN_UNKNOWN:
 
-            AcpiOsPrintf ("External/virtual  ");
+            AcpiOsPrintf ("Unknown   ");
             break;
 
-        case ACPI_TABLE_ORIGIN_INTERNAL_PHYSICAL:
+        case ACPI_TABLE_ORIGIN_MAPPED:
 
-            AcpiOsPrintf ("Internal/physical ");
+            AcpiOsPrintf ("Mapped    ");
             break;
 
-        case ACPI_TABLE_ORIGIN_INTERNAL_VIRTUAL:
+        case ACPI_TABLE_ORIGIN_ALLOCATED:
 
-            AcpiOsPrintf ("Internal/virtual  ");
+            AcpiOsPrintf ("Allocated ");
+            break;
+
+        case ACPI_TABLE_ORIGIN_OVERRIDE:
+
+            AcpiOsPrintf ("Override  ");
             break;
 
         default:
 
-            AcpiOsPrintf ("INVALID TYPE      ");
+            AcpiOsPrintf ("INVALID   ");
             break;
         }
 
         /* Make sure that the table is mapped */
 
-        Status = AcpiTbValidateTable (TableDesc);
+        Status = AcpiTbVerifyTable (TableDesc);
         if (ACPI_FAILURE (Status))
         {
             return;
@@ -509,6 +510,8 @@ AcpiDbUnloadAcpiTable (
     Node = AcpiDbConvertToNode (ObjectName);
     if (!Node)
     {
+        AcpiOsPrintf ("Could not find [%s] in namespace\n",
+            ObjectName);
         return;
     }
 
@@ -897,7 +900,7 @@ AcpiDmTestResourceConversion (
 
     /* Convert internal resource list to external AML resource template */
 
-    Status = AcpiRsCreateAmlResources (&ResourceBuffer, &NewAml);
+    Status = AcpiRsCreateAmlResources (ResourceBuffer.Pointer, &NewAml);
     if (ACPI_FAILURE (Status))
     {
         AcpiOsPrintf ("AcpiRsCreateAmlResources failed: %s\n",
@@ -909,8 +912,8 @@ AcpiDmTestResourceConversion (
 
     OriginalAml = ReturnBuffer.Pointer;
 
-    AcpiDmCompareAmlResources (OriginalAml->Buffer.Pointer,
-        (ACPI_RSDESC_SIZE) OriginalAml->Buffer.Length,
+    AcpiDmCompareAmlResources (
+        OriginalAml->Buffer.Pointer, (ACPI_RSDESC_SIZE) OriginalAml->Buffer.Length,
         NewAml.Pointer, (ACPI_RSDESC_SIZE) NewAml.Length);
 
     /* Cleanup and exit */
@@ -1109,7 +1112,7 @@ GetCrs:
         }
 
 EndCrs:
-        ACPI_FREE (ReturnBuffer.Pointer);
+        ACPI_FREE_BUFFER (ReturnBuffer);
     }
 
 
@@ -1259,25 +1262,14 @@ AcpiDbGenerateGpe (
     char                    *GpeArg,
     char                    *BlockArg)
 {
-    UINT32                  BlockNumber = 0;
+    UINT32                  BlockNumber;
     UINT32                  GpeNumber;
     ACPI_GPE_EVENT_INFO     *GpeEventInfo;
 
 
-    GpeNumber = ACPI_STRTOUL (GpeArg, NULL, 0);
+    GpeNumber   = ACPI_STRTOUL (GpeArg, NULL, 0);
+    BlockNumber = ACPI_STRTOUL (BlockArg, NULL, 0);
 
-    /*
-     * If no block arg, or block arg == 0 or 1, use the FADT-defined
-     * GPE blocks.
-     */
-    if (BlockArg)
-    {
-        BlockNumber = ACPI_STRTOUL (BlockArg, NULL, 0);
-        if (BlockNumber == 1)
-        {
-            BlockNumber = 0;
-        }
-    }
 
     GpeEventInfo = AcpiEvGetGpeEventInfo (ACPI_TO_POINTER (BlockNumber),
         GpeNumber);
@@ -1289,14 +1281,6 @@ AcpiDbGenerateGpe (
 
     (void) AcpiEvGpeDispatch (NULL, GpeEventInfo, GpeNumber);
 }
-
-void
-AcpiDbGenerateSci (
-    void)
-{
-    AcpiEvSciDispatch ();
-}
-
 #endif /* !ACPI_REDUCED_HARDWARE */
 
 #endif /* ACPI_DEBUGGER */
