@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acdebug.h"
@@ -164,6 +165,7 @@ enum AcpiExDebuggerCommands
     CMD_ALLOCATIONS,
     CMD_ARGS,
     CMD_ARGUMENTS,
+    CMD_BATCH,
     CMD_BREAKPOINT,
     CMD_BUSINFO,
     CMD_CALL,
@@ -198,18 +200,16 @@ enum AcpiExDebuggerCommands
     CMD_METHODS,
     CMD_NAMESPACE,
     CMD_NOTIFY,
-    CMD_OBJECTS,
+    CMD_OBJECT,
     CMD_OPEN,
     CMD_OSI,
     CMD_OWNER,
-    CMD_PATHS,
     CMD_PREDEFINED,
     CMD_PREFIX,
     CMD_QUIT,
     CMD_REFERENCES,
     CMD_RESOURCES,
     CMD_RESULTS,
-    CMD_SCI,
     CMD_SET,
     CMD_SLEEP,
     CMD_STATS,
@@ -217,7 +217,6 @@ enum AcpiExDebuggerCommands
     CMD_TABLES,
     CMD_TEMPLATE,
     CMD_TERMINATE,
-    CMD_TEST,
     CMD_THREADS,
     CMD_TRACE,
     CMD_TREE,
@@ -237,6 +236,7 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"ALLOCATIONS",  0},
     {"ARGS",         0},
     {"ARGUMENTS",    0},
+    {"BATCH",        0},
     {"BREAKPOINT",   1},
     {"BUSINFO",      0},
     {"CALL",         0},
@@ -252,7 +252,7 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"EXIT",         0},
     {"FIND",         1},
     {"GO",           0},
-    {"GPE",          1},
+    {"GPE",          2},
     {"GPES",         0},
     {"HANDLERS",     0},
     {"HELP",         0},
@@ -271,18 +271,16 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"METHODS",      0},
     {"NAMESPACE",    0},
     {"NOTIFY",       2},
-    {"OBJECTS",      1},
+    {"OBJECT",       1},
     {"OPEN",         1},
     {"OSI",          0},
     {"OWNER",        1},
-    {"PATHS",        0},
     {"PREDEFINED",   0},
     {"PREFIX",       0},
     {"QUIT",         0},
     {"REFERENCES",   1},
     {"RESOURCES",    0},
     {"RESULTS",      0},
-    {"SCI",          0},
     {"SET",          3},
     {"SLEEP",        0},
     {"STATS",        1},
@@ -290,7 +288,6 @@ static const ACPI_DB_COMMAND_INFO   AcpiGbl_DbCommands[] =
     {"TABLES",       0},
     {"TEMPLATE",     1},
     {"TERMINATE",    0},
-    {"TEST",        1},
     {"THREADS",      3},
     {"TRACE",        1},
     {"TREE",         0},
@@ -317,7 +314,8 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Locks",                             "Current status of internal mutexes\n"},
     {1, "  Osi [Install|Remove <name>]",       "Display or modify global _OSI list\n"},
     {1, "  Quit or Exit",                      "Exit this command\n"},
-    {8, "  Stats <SubCommand>",                "Display namespace and memory statistics\n"},
+    {9, "  Stats [Allocations|Memory|Misc|",   "\n"},
+    {1, "      Objects|Sizes|Stack|Tables]",   "Display namespace and memory statistics\n"},
     {1, "     Allocations",                    "Display list of current memory allocations\n"},
     {1, "     Memory",                         "Dump internal memory lists\n"},
     {1, "     Misc",                           "Namespace search and mutex stats\n"},
@@ -333,19 +331,22 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {0, "\nNamespace Access Commands:",        "\n"},
     {1, "  Businfo",                           "Display system bus info\n"},
     {1, "  Disassemble <Method>",              "Disassemble a control method\n"},
+    {1, "  Event <F|G> <Value>",               "Generate AcpiEvent (Fixed/GPE)\n"},
     {1, "  Find <AcpiName> (? is wildcard)",   "Find ACPI name(s) with wildcards\n"},
+    {1, "  Gpe <GpeNum> <GpeBlock>",           "Simulate a GPE\n"},
+    {1, "  Gpes",                              "Display info on all GPEs\n"},
     {1, "  Integrity",                         "Validate namespace integrity\n"},
     {1, "  Methods",                           "Display list of loaded control methods\n"},
     {1, "  Namespace [Object] [Depth]",        "Display loaded namespace tree/subtree\n"},
     {1, "  Notify <Object> <Value>",           "Send a notification on Object\n"},
     {1, "  Objects <ObjectType>",              "Display all objects of the given type\n"},
     {1, "  Owner <OwnerId> [Depth]",           "Display loaded namespace by object owner\n"},
-    {1, "  Paths",                             "Display full pathnames of namespace objects\n"},
     {1, "  Predefined",                        "Check all predefined names\n"},
     {1, "  Prefix [<NamePath>]",               "Set or Get current execution prefix\n"},
     {1, "  References <Addr>",                 "Find all references to object at addr\n"},
     {1, "  Resources [DeviceName]",            "Display Device resources (no arg = all devices)\n"},
     {1, "  Set N <NamedObject> <Value>",       "Set value for named integer\n"},
+    {1, "  Sleep [SleepState]",                "Simulate sleep/wake sequence(s) (0-5)\n"},
     {1, "  Template <Object>",                 "Format/dump a Buffer/ResourceTemplate\n"},
     {1, "  Terminate",                         "Delete namespace and all internal objects\n"},
     {1, "  Type <Object>",                     "Display object type\n"},
@@ -359,7 +360,7 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {5, "  Execute <Namepath> [Arguments]",    "Execute control method\n"},
     {1, "     Hex Integer",                    "Integer method argument\n"},
     {1, "     \"Ascii String\"",               "String method argument\n"},
-    {1, "     (Hex Byte List)",                "Buffer method argument\n"},
+    {1, "     (Byte List)",                    "Buffer method argument\n"},
     {1, "     [Package Element List]",         "Package method argument\n"},
     {1, "  Go",                                "Allow method to run to completion\n"},
     {1, "  Information",                       "Display info about the current method\n"},
@@ -374,22 +375,10 @@ static const ACPI_DB_COMMAND_HELP   AcpiGbl_DbCommandHelp[] =
     {1, "  Tree",                              "Display control method calling tree\n"},
     {1, "  <Enter>",                           "Single step next AML opcode (over calls)\n"},
 
-    {0, "\nHardware Related Commands:",         "\n"},
-    {1, "  Event <F|G> <Value>",               "Generate AcpiEvent (Fixed/GPE)\n"},
-    {1, "  Gpe <GpeNum> [GpeBlockDevice]",     "Simulate a GPE\n"},
-    {1, "  Gpes",                              "Display info on all GPEs\n"},
-    {1, "  Sci",                               "Generate an SCI\n"},
-    {1, "  Sleep [SleepState]",                "Simulate sleep/wake sequence(s) (0-5)\n"},
-
     {0, "\nFile I/O Commands:",                "\n"},
     {1, "  Close",                             "Close debug output file\n"},
     {1, "  Load <Input Filename>",             "Load ACPI table from a file\n"},
     {1, "  Open <Output Filename>",            "Open a file for debug output\n"},
-
-    {0, "\nDebug Test Commands:",              "\n"},
-    {3, "  Test <TestName>",                   "Invoke a debug test\n"},
-    {1, "     Objects",                        "Read/write/compare all namespace data objects\n"},
-    {1, "     Predefined",                     "Execute all ACPI predefined names (_STA, etc.)\n"},
     {0, NULL, NULL}
 };
 
@@ -710,13 +699,7 @@ AcpiDbGetLine (
     char                    *This;
 
 
-    if (AcpiUtSafeStrcpy (AcpiGbl_DbParsedBuf, sizeof (AcpiGbl_DbParsedBuf),
-        InputBuffer))
-    {
-        AcpiOsPrintf ("Buffer overflow while parsing input line (max %u characters)\n",
-            sizeof (AcpiGbl_DbParsedBuf));
-        return (0);
-    }
+    ACPI_STRCPY (AcpiGbl_DbParsedBuf, InputBuffer);
 
     This = AcpiGbl_DbParsedBuf;
     for (i = 0; i < ACPI_DEBUGGER_MAX_ARGS; i++)
@@ -821,11 +804,6 @@ AcpiDbCommandDispatch (
         return (AE_CTRL_TERMINATE);
     }
 
-
-    /* Add all commands that come here to the history buffer */
-
-    AcpiDbAddToHistory (InputBuffer);
-
     ParamCount = AcpiDbGetLine (InputBuffer);
     CommandIndex = AcpiDbMatchCommand (AcpiGbl_DbArgs[0]);
     Temp = 0;
@@ -867,6 +845,11 @@ AcpiDbCommandDispatch (
         AcpiDbDisplayArguments ();
         break;
 
+    case CMD_BATCH:
+
+        AcpiDbBatchExecute (AcpiGbl_DbArgs[1]);
+        break;
+
     case CMD_BREAKPOINT:
 
         AcpiDbSetMethodBreakpoint (AcpiGbl_DbArgs[1], WalkState, Op);
@@ -918,7 +901,7 @@ AcpiDbCommandDispatch (
         break;
 
     case CMD_EVENT:
-
+        
         AcpiOsPrintf ("Event command not implemented\n");
         break;
 
@@ -977,7 +960,7 @@ AcpiDbCommandDispatch (
         return (Status);
 
     case CMD_HISTORY_LAST: /* !! command */
-
+        
         CommandLine = AcpiDbGetFromHistory (NULL);
         if (!CommandLine)
         {
@@ -988,12 +971,12 @@ AcpiDbCommandDispatch (
         return (Status);
 
     case CMD_INFORMATION:
-
+        
         AcpiDbDisplayMethodInfo (Op);
         break;
 
     case CMD_INTEGRITY:
-
+        
         AcpiDbCheckIntegrity ();
         break;
 
@@ -1041,7 +1024,7 @@ AcpiDbCommandDispatch (
 
     case CMD_LOAD:
 
-        Status = AcpiDbGetTableFromFile (AcpiGbl_DbArgs[1], NULL, FALSE);
+        Status = AcpiDbGetTableFromFile (AcpiGbl_DbArgs[1], NULL);
         break;
 
     case CMD_LOCKS:
@@ -1070,7 +1053,7 @@ AcpiDbCommandDispatch (
         AcpiDbSendNotify (AcpiGbl_DbArgs[1], Temp);
         break;
 
-    case CMD_OBJECTS:
+    case CMD_OBJECT:
 
         AcpiUtStrupr (AcpiGbl_DbArgs[1]);
         Status = AcpiDbDisplayObjects (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
@@ -1087,15 +1070,10 @@ AcpiDbCommandDispatch (
         break;
 
     case CMD_OWNER:
-
+        
         AcpiDbDumpNamespaceByOwner (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2]);
         break;
 
-    case CMD_PATHS:
-
-        AcpiDbDumpNamespacePaths ();
-        break;
-
     case CMD_PREDEFINED:
 
         AcpiDbCheckPredefinedNames ();
@@ -1121,11 +1099,6 @@ AcpiDbCommandDispatch (
         AcpiDbDisplayResults ();
         break;
 
-    case CMD_SCI:
-
-        AcpiDbGenerateSci ();
-        break;
-
     case CMD_SET:
 
         AcpiDbSetMethodData (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2],
@@ -1169,11 +1142,6 @@ AcpiDbCommandDispatch (
         /*  AcpiInitialize (NULL);  */
         break;
 
-    case CMD_TEST:
-
-        AcpiDbExecuteTest (AcpiGbl_DbArgs[1]);
-        break;
-
     case CMD_THREADS:
 
         AcpiDbCreateExecutionThreads (AcpiGbl_DbArgs[1], AcpiGbl_DbArgs[2],
@@ -1221,7 +1189,7 @@ AcpiDbCommandDispatch (
     case CMD_NOT_FOUND:
     default:
 
-        AcpiOsPrintf ("%s: unknown command\n", AcpiGbl_DbArgs[0]);
+        AcpiOsPrintf ("Unknown Command\n");
         return (AE_CTRL_TRUE);
     }
 
@@ -1230,6 +1198,9 @@ AcpiDbCommandDispatch (
         Status = AE_CTRL_TRUE;
     }
 
+    /* Add all commands that come here to the history buffer */
+
+    AcpiDbAddToHistory (InputBuffer);
     return (Status);
 }
 
