@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,68 +111,29 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
+
 #include "acpi.h"
 #include "accommon.h"
-#include "acutils.h"
 #include "acdisasm.h"
 #include "acparser.h"
 #include "amlcode.h"
-#include "acinterp.h"
 
 
+#ifdef ACPI_DISASSEMBLER
+
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dmbuffer")
 
 /* Local prototypes */
 
-static void
-AcpiDmUuid (
-    ACPI_PARSE_OBJECT       *Op);
-
 static void
 AcpiDmUnicode (
     ACPI_PARSE_OBJECT       *Op);
 
 static void
-AcpiDmGetHardwareIdType (
+AcpiDmIsEisaIdElement (
     ACPI_PARSE_OBJECT       *Op);
 
 static void
@@ -181,14 +142,6 @@ AcpiDmPldBuffer (
     UINT8                   *ByteData,
     UINT32                  ByteCount);
 
-static const char *
-AcpiDmFindNameByIndex (
-    UINT64                  Index,
-    const char              **List);
-
-
-#define ACPI_BUFFER_BYTES_PER_LINE      8
-
 
 /*******************************************************************************
  *
@@ -212,9 +165,6 @@ AcpiDmDisasmByteList (
     UINT32                  ByteCount)
 {
     UINT32                  i;
-    UINT32                  j;
-    UINT32                  CurrentIndex;
-    UINT8                   BufChar;
 
 
     if (!ByteCount)
@@ -222,67 +172,38 @@ AcpiDmDisasmByteList (
         return;
     }
 
-    for (i = 0; i < ByteCount; i += ACPI_BUFFER_BYTES_PER_LINE)
+    /* Dump the byte list */
+
+    for (i = 0; i < ByteCount; i++)
     {
-        /* Line indent and offset prefix for each new line */
+        /* New line every 8 bytes */
 
-        AcpiDmIndent (Level);
-        if (ByteCount > ACPI_BUFFER_BYTES_PER_LINE)
+        if (((i % 8) == 0) && (i < ByteCount))
         {
-            AcpiOsPrintf ("/* %04X */ ", i);
-        }
-
-        /* Dump the actual hex values */
-
-        for (j = 0; j < ACPI_BUFFER_BYTES_PER_LINE; j++)
-        {
-            CurrentIndex = i + j;
-            if (CurrentIndex >= ByteCount)
+            if (i > 0)
             {
-                /* Dump fill spaces */
-
-                AcpiOsPrintf ("      ");
-                continue;
+                AcpiOsPrintf ("\n");
             }
 
-            AcpiOsPrintf (" 0x%2.2X", ByteData[CurrentIndex]);
-
-            /* Add comma if there are more bytes to display */
-
-            if (CurrentIndex < (ByteCount - 1))
+            AcpiDmIndent (Level);
+            if (ByteCount > 8)
             {
-                AcpiOsPrintf (",");
-            }
-            else
-            {
-                AcpiOsPrintf (" ");
+                AcpiOsPrintf ("/* %04X */  ", i);
             }
         }
 
-        /* Dump the ASCII equivalents within a comment */
+        AcpiOsPrintf (" 0x%2.2X", (UINT32) ByteData[i]);
 
-        AcpiOsPrintf ("  // ");
-        for (j = 0; j < ACPI_BUFFER_BYTES_PER_LINE; j++)
+        /* Add comma if there are more bytes to display */
+
+        if (i < (ByteCount -1))
         {
-            CurrentIndex = i + j;
-            if (CurrentIndex >= ByteCount)
-            {
-                break;
-            }
-
-            BufChar = ByteData[CurrentIndex];
-            if (isprint (BufChar))
-            {
-                AcpiOsPrintf ("%c", BufChar);
-            }
-            else
-            {
-                AcpiOsPrintf (".");
-            }
+            AcpiOsPrintf (",");
         }
+    }
 
-        /* Finished with this line */
-
+    if (Level)
+    {
         AcpiOsPrintf ("\n");
     }
 }
@@ -322,31 +243,24 @@ AcpiDmByteList (
     {
     case ACPI_DASM_RESOURCE:
 
-        AcpiDmResourceTemplate (
-            Info, Op->Common.Parent, ByteData, ByteCount);
+        AcpiDmResourceTemplate (Info, Op->Common.Parent, ByteData, ByteCount);
         break;
 
     case ACPI_DASM_STRING:
 
         AcpiDmIndent (Info->Level);
-        AcpiUtPrintString ((char *) ByteData, ACPI_UINT16_MAX);
+        AcpiUtPrintString ((char *) ByteData, ACPI_UINT8_MAX);
         AcpiOsPrintf ("\n");
         break;
 
-    case ACPI_DASM_UUID:
-
-        AcpiDmUuid (Op);
-        break;
-
     case ACPI_DASM_UNICODE:
 
         AcpiDmUnicode (Op);
         break;
 
     case ACPI_DASM_PLD_METHOD:
-#if 0
+
         AcpiDmDisasmByteList (Info->Level, ByteData, ByteCount);
-#endif
         AcpiDmPldBuffer (Info->Level, ByteData, ByteCount);
         break;
 
@@ -362,141 +276,6 @@ AcpiDmByteList (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmIsUuidBuffer
- *
- * PARAMETERS:  Op              - Buffer Object to be examined
- *
- * RETURN:      TRUE if buffer contains a UUID
- *
- * DESCRIPTION: Determine if a buffer Op contains a UUID
- *
- * To help determine whether the buffer is a UUID versus a raw data buffer,
- * there a are a couple bytes we can look at:
- *
- *    xxxxxxxx-xxxx-Mxxx-Nxxx-xxxxxxxxxxxx
- *
- * The variant covered by the UUID specification is indicated by the two most
- * significant bits of N being 1 0 (i.e., the hexadecimal N will always be
- * 8, 9, A, or B).
- *
- * The variant covered by the UUID specification has five versions. For this
- * variant, the four bits of M indicates the UUID version (i.e., the
- * hexadecimal M will be either 1, 2, 3, 4, or 5).
- *
- ******************************************************************************/
-
-BOOLEAN
-AcpiDmIsUuidBuffer (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    UINT8                   *ByteData;
-    UINT32                  ByteCount;
-    ACPI_PARSE_OBJECT       *SizeOp;
-    ACPI_PARSE_OBJECT       *NextOp;
-
-
-    /* Buffer size is the buffer argument */
-
-    SizeOp = Op->Common.Value.Arg;
-    if (!SizeOp)
-    {
-        return (FALSE);
-    }
-
-    /* Next, the initializer byte list to examine */
-
-    NextOp = SizeOp->Common.Next;
-    if (!NextOp)
-    {
-        return (FALSE);
-    }
-
-    /* Extract the byte list info */
-
-    ByteData = NextOp->Named.Data;
-    ByteCount = (UINT32) NextOp->Common.Value.Integer;
-
-    /* Byte count must be exactly 16 */
-
-    if (ByteCount != UUID_BUFFER_LENGTH)
-    {
-        return (FALSE);
-    }
-
-    /* Check for valid "M" and "N" values (see function header above) */
-
-    if (((ByteData[7] & 0xF0) == 0x00) || /* M={1,2,3,4,5} */
-        ((ByteData[7] & 0xF0) > 0x50)  ||
-        ((ByteData[8] & 0xF0) < 0x80)  || /* N={8,9,A,B} */
-        ((ByteData[8] & 0xF0) > 0xB0))
-    {
-        return (FALSE);
-    }
-
-    /* Ignore the Size argument in the disassembly of this buffer op */
-
-    SizeOp->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
-    return (TRUE);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmUuid
- *
- * PARAMETERS:  Op              - Byte List op containing a UUID
- *
- * RETURN:      None
- *
- * DESCRIPTION: Dump a buffer containing a UUID as a standard ASCII string.
- *
- * Output Format:
- * In its canonical form, the UUID is represented by a string containing 32
- * lowercase hexadecimal digits, displayed in 5 groups separated by hyphens.
- * The complete form is 8-4-4-4-12 for a total of 36 characters (32
- * alphanumeric characters representing hex digits and 4 hyphens). In bytes,
- * 4-2-2-2-6. Example:
- *
- *    ToUUID ("107ededd-d381-4fd7-8da9-08e9a6c79644")
- *
- ******************************************************************************/
-
-static void
-AcpiDmUuid (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    UINT8                   *Data;
-    const char              *Description;
-
-
-    Data = ACPI_CAST_PTR (UINT8, Op->Named.Data);
-
-    /* Emit the 36-byte UUID string in the proper format/order */
-
-    AcpiOsPrintf (
-        "\"%2.2x%2.2x%2.2x%2.2x-"
-        "%2.2x%2.2x-"
-        "%2.2x%2.2x-"
-        "%2.2x%2.2x-"
-        "%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x\")",
-        Data[3], Data[2], Data[1], Data[0],
-        Data[5], Data[4],
-        Data[7], Data[6],
-        Data[8], Data[9],
-        Data[10], Data[11], Data[12], Data[13], Data[14], Data[15]);
-
-    /* Dump the UUID description string if available */
-
-    Description = AcpiAhMatchUuid (Data);
-    if (Description)
-    {
-        AcpiOsPrintf (" /* %s */", Description);
-    }
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmIsUnicodeBuffer
@@ -524,10 +303,6 @@ AcpiDmIsUnicodeBuffer (
     /* Buffer size is the buffer argument */
 
     SizeOp = Op->Common.Value.Arg;
-    if (!SizeOp)
-    {
-        return (FALSE);
-    }
 
     /* Next, the initializer byte list to examine */
 
@@ -555,16 +330,11 @@ AcpiDmIsUnicodeBuffer (
         return (FALSE);
     }
 
-    /*
-     * For each word, 1st byte must be printable ascii, and the
-     * 2nd byte must be zero. This does not allow for escape
-     * sequences, but it is the most secure way to detect a
-     * unicode string.
-     */
+    /* For each word, 1st byte must be ascii, 2nd byte must be zero */
+
     for (i = 0; i < (ByteCount - 2); i += 2)
     {
-        if ((ByteData[i] == 0) ||
-            !(isprint (ByteData[i])) ||
+        if ((!ACPI_IS_PRINT (ByteData[i])) ||
             (ByteData[(ACPI_SIZE) i + 1] != 0))
         {
             return (FALSE);
@@ -604,10 +374,6 @@ AcpiDmIsStringBuffer (
     /* Buffer size is the buffer argument */
 
     SizeOp = Op->Common.Value.Arg;
-    if (!SizeOp)
-    {
-        return (FALSE);
-    }
 
     /* Next, the initializer byte list to examine */
 
@@ -631,28 +397,13 @@ AcpiDmIsStringBuffer (
         return (FALSE);
     }
 
-    /*
-     * Check for a possible standalone resource EndTag, ignore it
-     * here. However, this sequence is also the string "Y", but
-     * this seems rare enough to be acceptable.
-     */
-    if ((ByteCount == 2) && (ByteData[0] == 0x79))
-    {
-        return (FALSE);
-    }
-
-    /* Check all bytes for ASCII */
-
     for (i = 0; i < (ByteCount - 1); i++)
     {
-        /*
-         * TBD: allow some escapes (non-ascii chars).
+        /* TBD: allow some escapes (non-ascii chars).
          * they will be handled in the string output routine
          */
 
-        /* Not a string if not printable ascii */
-
-        if (!isprint (ByteData[i]))
+        if (!ACPI_IS_PRINT (ByteData[i]))
         {
             return (FALSE);
         }
@@ -668,8 +419,7 @@ AcpiDmIsStringBuffer (
  *
  * PARAMETERS:  Op                  - Buffer Object to be examined
  *
- * RETURN:      TRUE if buffer appears to contain data produced via the
- *              ToPLD macro, FALSE otherwise
+ * RETURN:      TRUE if buffer contains a ASCII string, FALSE otherwise
  *
  * DESCRIPTION: Determine if a buffer Op contains a _PLD structure
  *
@@ -680,67 +430,9 @@ AcpiDmIsPldBuffer (
     ACPI_PARSE_OBJECT       *Op)
 {
     ACPI_NAMESPACE_NODE     *Node;
-    ACPI_PARSE_OBJECT       *SizeOp;
-    ACPI_PARSE_OBJECT       *ByteListOp;
     ACPI_PARSE_OBJECT       *ParentOp;
-    UINT64                  BufferSize;
-    UINT64                  InitializerSize;
 
 
-    if (!Op)
-    {
-        return (FALSE);
-    }
-
-    /*
-     * Get the BufferSize argument - Buffer(BufferSize)
-     * If the buffer was generated by the ToPld macro, it must
-     * be a BYTE constant.
-     */
-    SizeOp = Op->Common.Value.Arg;
-    if (!SizeOp || SizeOp->Common.AmlOpcode != AML_BYTE_OP)
-    {
-        return (FALSE);
-    }
-
-    /* Check the declared BufferSize, two possibilities */
-
-    BufferSize = SizeOp->Common.Value.Integer;
-    if ((BufferSize != ACPI_PLD_REV1_BUFFER_SIZE) &&
-        (BufferSize != ACPI_PLD_REV2_BUFFER_SIZE))
-    {
-        return (FALSE);
-    }
-
-    /*
-     * Check the initializer list length. This is the actual
-     * number of bytes in the buffer as counted by the AML parser.
-     * The declared BufferSize can be larger than the actual length.
-     * However, for the ToPLD macro, the BufferSize will be the same
-     * as the initializer list length.
-     */
-    ByteListOp = SizeOp->Common.Next;
-    if (!ByteListOp)
-    {
-        return (FALSE); /* Zero-length buffer case */
-    }
-
-    InitializerSize = ByteListOp->Common.Value.Integer;
-    if ((InitializerSize != ACPI_PLD_REV1_BUFFER_SIZE) &&
-        (InitializerSize != ACPI_PLD_REV2_BUFFER_SIZE))
-    {
-        return (FALSE);
-    }
-
-    /* Final size check */
-
-    if (BufferSize != InitializerSize)
-    {
-        return (FALSE);
-    }
-
-    /* Now examine the buffer parent */
-
     ParentOp = Op->Common.Parent;
     if (!ParentOp)
     {
@@ -753,28 +445,16 @@ AcpiDmIsPldBuffer (
     {
         Node = ParentOp->Common.Node;
 
-        if (ACPI_COMPARE_NAMESEG (Node->Name.Ascii, METHOD_NAME__PLD))
+        if (ACPI_COMPARE_NAME (Node->Name.Ascii, METHOD_NAME__PLD))
         {
-            /* Ignore the Size argument in the disassembly of this buffer op */
-
-            SizeOp->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
             return (TRUE);
         }
 
         return (FALSE);
     }
 
-    /*
-     * Check for proper form: Name(_PLD, Package() {ToPLD()})
-     *
-     * Note: All other forms such as
-     *      Return (Package() {ToPLD()})
-     *      Local0 = ToPLD()
-     * etc. are not converted back to the ToPLD macro, because
-     * there is really no deterministic way to disassemble the buffer
-     * back to the ToPLD macro, other than trying to find the "_PLD"
-     * name
-     */
+    /* Check for proper form: Name(_PLD, Package() {Buffer() {}}) */
+
     if (ParentOp->Common.AmlOpcode == AML_PACKAGE_OP)
     {
         ParentOp = ParentOp->Common.Parent;
@@ -787,11 +467,8 @@ AcpiDmIsPldBuffer (
         {
             Node = ParentOp->Common.Node;
 
-            if (ACPI_COMPARE_NAMESEG (Node->Name.Ascii, METHOD_NAME__PLD))
+            if (ACPI_COMPARE_NAME (Node->Name.Ascii, METHOD_NAME__PLD))
             {
-                /* Ignore the Size argument in the disassembly of this buffer op */
-
-                SizeOp->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
                 return (TRUE);
             }
         }
@@ -801,51 +478,6 @@ AcpiDmIsPldBuffer (
 }
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmFindNameByIndex
- *
- * PARAMETERS:  Index               - Index of array to check
- *              List                - Array to reference
- *
- * RETURN:      String from List or empty string
- *
- * DESCRIPTION: Finds and returns the char string located at the given index
- *              position in List.
- *
- ******************************************************************************/
-
-static const char *
-AcpiDmFindNameByIndex (
-    UINT64                  Index,
-    const char              **List)
-{
-    const char              *NameString;
-    UINT32                  i;
-
-
-    /* Bounds check */
-
-    NameString = List[0];
-    i = 0;
-
-    while (NameString)
-    {
-        i++;
-        NameString = List[i];
-    }
-
-    if (Index >= i)
-    {
-        /* TBD: Add error msg */
-
-        return ("");
-    }
-
-    return (List[Index]);
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmPldBuffer
@@ -860,12 +492,9 @@ AcpiDmFindNameByIndex (
  *
  ******************************************************************************/
 
-#define ACPI_PLD_OUTPUT08   "%*.s%-22s = 0x%X,\n", ACPI_MUL_4 (Level), " "
-#define ACPI_PLD_OUTPUT08P  "%*.s%-22s = 0x%X)\n", ACPI_MUL_4 (Level), " "
-#define ACPI_PLD_OUTPUT16   "%*.s%-22s = 0x%X,\n", ACPI_MUL_4 (Level), " "
-#define ACPI_PLD_OUTPUT16P  "%*.s%-22s = 0x%X)\n", ACPI_MUL_4 (Level), " "
-#define ACPI_PLD_OUTPUT24   "%*.s%-22s = 0x%X,\n", ACPI_MUL_4 (Level), " "
-#define ACPI_PLD_OUTPUTSTR  "%*.s%-22s = \"%s\",\n", ACPI_MUL_4 (Level), " "
+#define ACPI_PLD_OUTPUT08     "%*.s/* %18s : %-6.2X */\n", ACPI_MUL_4 (Level), " "
+#define ACPI_PLD_OUTPUT16   "%*.s/* %18s : %-6.4X */\n", ACPI_MUL_4 (Level), " "
+#define ACPI_PLD_OUTPUT24   "%*.s/* %18s : %-6.6X */\n", ACPI_MUL_4 (Level), " "
 
 static void
 AcpiDmPldBuffer (
@@ -892,64 +521,47 @@ AcpiDmPldBuffer (
         return;
     }
 
-    AcpiOsPrintf ("\n");
-
     /* First 32-bit dword */
 
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Revision", PldInfo->Revision);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_IgnoreColor", PldInfo->IgnoreColor);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Red", PldInfo->Red);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Green", PldInfo->Green);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Blue", PldInfo->Blue);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Revision", PldInfo->Revision);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "IgnoreColor", PldInfo->IgnoreColor);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT24,"Color", PldInfo->Color);
 
     /* Second 32-bit dword */
 
-    AcpiOsPrintf (ACPI_PLD_OUTPUT16,  "PLD_Width", PldInfo->Width);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT16,  "PLD_Height", PldInfo->Height);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT16,"Width", PldInfo->Width);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT16,"Height", PldInfo->Height);
 
     /* Third 32-bit dword */
 
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_UserVisible", PldInfo->UserVisible);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Dock", PldInfo->Dock);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Lid", PldInfo->Lid);
-    AcpiOsPrintf (ACPI_PLD_OUTPUTSTR, "PLD_Panel",
-        AcpiDmFindNameByIndex(PldInfo->Panel, AcpiGbl_PldPanelList));
-
-    AcpiOsPrintf (ACPI_PLD_OUTPUTSTR, "PLD_VerticalPosition",
-        AcpiDmFindNameByIndex(PldInfo->VerticalPosition, AcpiGbl_PldVerticalPositionList));
-
-    AcpiOsPrintf (ACPI_PLD_OUTPUTSTR, "PLD_HorizontalPosition",
-        AcpiDmFindNameByIndex(PldInfo->HorizontalPosition, AcpiGbl_PldHorizontalPositionList));
-
-    AcpiOsPrintf (ACPI_PLD_OUTPUTSTR, "PLD_Shape",
-        AcpiDmFindNameByIndex(PldInfo->Shape, AcpiGbl_PldShapeList));
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_GroupOrientation", PldInfo->GroupOrientation);
-
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_GroupToken", PldInfo->GroupToken);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_GroupPosition", PldInfo->GroupPosition);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Bay", PldInfo->Bay);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "UserVisible", PldInfo->UserVisible);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Dock", PldInfo->Dock);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Lid", PldInfo->Lid);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Panel", PldInfo->Panel);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "VerticalPosition", PldInfo->VerticalPosition);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "HorizontalPosition", PldInfo->HorizontalPosition);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Shape", PldInfo->Shape);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "GroupOrientation", PldInfo->GroupOrientation);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "GroupToken", PldInfo->GroupToken);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "GroupPosition", PldInfo->GroupPosition);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Bay", PldInfo->Bay);
 
     /* Fourth 32-bit dword */
 
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Ejectable", PldInfo->Ejectable);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_EjectRequired", PldInfo->OspmEjectRequired);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_CabinetNumber", PldInfo->CabinetNumber);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_CardCageNumber", PldInfo->CardCageNumber);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Reference", PldInfo->Reference);
-    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "PLD_Rotation", PldInfo->Rotation);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Ejectable", PldInfo->Ejectable);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "OspmEjectRequired", PldInfo->OspmEjectRequired);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "CabinetNumber", PldInfo->CabinetNumber);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "CardCageNumber", PldInfo->CardCageNumber);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Reference", PldInfo->Reference);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Rotation", PldInfo->Rotation);
+    AcpiOsPrintf (ACPI_PLD_OUTPUT08,  "Order", PldInfo->Order);
 
-    if (ByteCount >= ACPI_PLD_REV2_BUFFER_SIZE)
+    /* Fifth 32-bit dword */
+
+    if (ByteCount >= ACPI_PLD_REV1_BUFFER_SIZE)
     {
-        AcpiOsPrintf (ACPI_PLD_OUTPUT08, "PLD_Order", PldInfo->Order);
-
-        /* Fifth 32-bit dword */
-
-        AcpiOsPrintf (ACPI_PLD_OUTPUT16,  "PLD_VerticalOffset", PldInfo->VerticalOffset);
-        AcpiOsPrintf (ACPI_PLD_OUTPUT16P, "PLD_HorizontalOffset", PldInfo->HorizontalOffset);
-    }
-    else /* Rev 1 buffer */
-    {
-        AcpiOsPrintf (ACPI_PLD_OUTPUT08P, "PLD_Order", PldInfo->Order);
+        AcpiOsPrintf (ACPI_PLD_OUTPUT16,"VerticalOffset", PldInfo->VerticalOffset);
+        AcpiOsPrintf (ACPI_PLD_OUTPUT16,"HorizontalOffset", PldInfo->HorizontalOffset);
     }
 
     ACPI_FREE (PldInfo);
@@ -976,7 +588,6 @@ AcpiDmUnicode (
     UINT16                  *WordData;
     UINT32                  WordCount;
     UINT32                  i;
-    int                     OutputValue;
 
 
     /* Extract the buffer info as a WORD buffer */
@@ -984,28 +595,14 @@ AcpiDmUnicode (
     WordData = ACPI_CAST_PTR (UINT16, Op->Named.Data);
     WordCount = ACPI_DIV_2 (((UINT32) Op->Common.Value.Integer));
 
-    /* Write every other byte as an ASCII character */
 
     AcpiOsPrintf ("\"");
+
+    /* Write every other byte as an ASCII character */
+
     for (i = 0; i < (WordCount - 1); i++)
     {
-        OutputValue = (int) WordData[i];
-
-        /* Handle values that must be escaped */
-
-        if ((OutputValue == '\"') ||
-            (OutputValue == '\\'))
-        {
-            AcpiOsPrintf ("\\%c", OutputValue);
-        }
-        else if (!isprint (OutputValue))
-        {
-            AcpiOsPrintf ("\\x%2.2X", OutputValue);
-        }
-        else
-        {
-            AcpiOsPrintf ("%c", OutputValue);
-        }
+        AcpiOsPrintf ("%c", (int) WordData[i]);
     }
 
     AcpiOsPrintf ("\")");
@@ -1014,20 +611,19 @@ AcpiDmUnicode (
 
 /*******************************************************************************
  *
- * FUNCTION:    AcpiDmGetHardwareIdType
+ * FUNCTION:    AcpiDmIsEisaIdElement
  *
  * PARAMETERS:  Op              - Op to be examined
  *
  * RETURN:      None
  *
- * DESCRIPTION: Determine the type of the argument to a _HID or _CID
- *              1) Strings are allowed
- *              2) If Integer, determine if it is a valid EISAID
+ * DESCRIPTION: Determine if an Op (argument to _HID or _CID) can be converted
+ *              to an EISA ID.
  *
  ******************************************************************************/
 
 static void
-AcpiDmGetHardwareIdType (
+AcpiDmIsEisaIdElement (
     ACPI_PARSE_OBJECT       *Op)
 {
     UINT32                  BigEndianId;
@@ -1035,66 +631,55 @@ AcpiDmGetHardwareIdType (
     UINT32                  i;
 
 
-    switch (Op->Common.AmlOpcode)
+    /* The parameter must be either a word or a dword */
+
+    if ((Op->Common.AmlOpcode != AML_DWORD_OP) &&
+        (Op->Common.AmlOpcode != AML_WORD_OP))
     {
-    case AML_STRING_OP:
-
-        /* Mark this string as an _HID/_CID string */
-
-        Op->Common.DisasmOpcode = ACPI_DASM_HID_STRING;
-        break;
-
-    case AML_WORD_OP:
-    case AML_DWORD_OP:
-
-        /* Determine if a Word/Dword is a valid encoded EISAID */
-
-        /* Swap from little-endian to big-endian to simplify conversion */
-
-        BigEndianId = AcpiUtDwordByteSwap ((UINT32) Op->Common.Value.Integer);
-
-        /* Create the 3 leading ASCII letters */
-
-        Prefix[0] = ((BigEndianId >> 26) & 0x1F) + 0x40;
-        Prefix[1] = ((BigEndianId >> 21) & 0x1F) + 0x40;
-        Prefix[2] = ((BigEndianId >> 16) & 0x1F) + 0x40;
-
-        /* Verify that all 3 are ascii and alpha */
-
-        for (i = 0; i < 3; i++)
-        {
-            if (!ACPI_IS_ASCII (Prefix[i]) ||
-                !isalpha (Prefix[i]))
-            {
-                return;
-            }
-        }
-
-        /* Mark this node as convertible to an EISA ID string */
-
-        Op->Common.DisasmOpcode = ACPI_DASM_EISAID;
-        break;
-
-    default:
-        break;
+        return;
     }
+
+    /* Swap from little-endian to big-endian to simplify conversion */
+
+    BigEndianId = AcpiUtDwordByteSwap ((UINT32) Op->Common.Value.Integer);
+
+    /* Create the 3 leading ASCII letters */
+
+    Prefix[0] = ((BigEndianId >> 26) & 0x1F) + 0x40;
+    Prefix[1] = ((BigEndianId >> 21) & 0x1F) + 0x40;
+    Prefix[2] = ((BigEndianId >> 16) & 0x1F) + 0x40;
+
+    /* Verify that all 3 are ascii and alpha */
+
+    for (i = 0; i < 3; i++)
+    {
+        if (!ACPI_IS_ASCII (Prefix[i]) ||
+            !ACPI_IS_ALPHA (Prefix[i]))
+        {
+            return;
+        }
+    }
+
+    /* OK - mark this node as convertable to an EISA ID */
+
+    Op->Common.DisasmOpcode = ACPI_DASM_EISAID;
 }
 
 
 /*******************************************************************************
  *
- * FUNCTION:    AcpiDmCheckForHardwareId
+ * FUNCTION:    AcpiDmIsEisaId
  *
  * PARAMETERS:  Op              - Op to be examined
  *
  * RETURN:      None
  *
- * DESCRIPTION: Determine if a Name() Op is a _HID/_CID.
+ * DESCRIPTION: Determine if a Name() Op can be converted to an EisaId.
  *
  ******************************************************************************/
 
 void
-AcpiDmCheckForHardwareId (
+AcpiDmIsEisaId (
     ACPI_PARSE_OBJECT       *Op)
 {
     UINT32                  Name;
@@ -1117,15 +702,15 @@ AcpiDmCheckForHardwareId (
 
     /* Check for _HID - has one argument */
 
-    if (ACPI_COMPARE_NAMESEG (&Name, METHOD_NAME__HID))
+    if (ACPI_COMPARE_NAME (&Name, METHOD_NAME__HID))
     {
-        AcpiDmGetHardwareIdType (NextOp);
+        AcpiDmIsEisaIdElement (NextOp);
         return;
     }
 
     /* Exit if not _CID */
 
-    if (!ACPI_COMPARE_NAMESEG (&Name, METHOD_NAME__CID))
+    if (!ACPI_COMPARE_NAME (&Name, METHOD_NAME__CID))
     {
         return;
     }
@@ -1134,24 +719,20 @@ AcpiDmCheckForHardwareId (
 
     if (NextOp->Common.AmlOpcode != AML_PACKAGE_OP)
     {
-        AcpiDmGetHardwareIdType (NextOp);
+        AcpiDmIsEisaIdElement (NextOp);
         return;
     }
 
-    /* _CID with Package: get the package length, check all elements */
+    /* _CID with Package: get the package length */
 
     NextOp = AcpiPsGetDepthNext (NULL, NextOp);
-    if (!NextOp)
-    {
-        return;
-    }
 
     /* Don't need to use the length, just walk the peer list */
 
     NextOp = NextOp->Common.Next;
     while (NextOp)
     {
-        AcpiDmGetHardwareIdType (NextOp);
+        AcpiDmIsEisaIdElement (NextOp);
         NextOp = NextOp->Common.Next;
     }
 }
@@ -1159,36 +740,41 @@ AcpiDmCheckForHardwareId (
 
 /*******************************************************************************
  *
- * FUNCTION:    AcpiDmDecompressEisaId
+ * FUNCTION:    AcpiDmEisaId
  *
  * PARAMETERS:  EncodedId       - Raw encoded EISA ID.
  *
  * RETURN:      None
  *
- * DESCRIPTION: Convert an encoded EISAID back to the original ASCII String
- *              and emit the correct ASL statement. If the ID is known, emit
- *              a description of the ID as a comment.
+ * DESCRIPTION: Convert an encoded EISAID back to the original ASCII String.
  *
  ******************************************************************************/
 
 void
-AcpiDmDecompressEisaId (
+AcpiDmEisaId (
     UINT32                  EncodedId)
 {
-    char                    IdBuffer[ACPI_EISAID_STRING_SIZE];
-    const AH_DEVICE_ID      *Info;
+    UINT32                  BigEndianId;
 
 
-    /* Convert EISAID to a string an emit the statement */
+    /* Swap from little-endian to big-endian to simplify conversion */
 
-    AcpiExEisaIdToString (IdBuffer, EncodedId);
-    AcpiOsPrintf ("EisaId (\"%s\")", IdBuffer);
+    BigEndianId = AcpiUtDwordByteSwap (EncodedId);
 
-    /* If we know about the ID, emit the description */
 
-    Info = AcpiAhMatchHardwareId (IdBuffer);
-    if (Info)
-    {
-        AcpiOsPrintf (" /* %s */", Info->Description);
-    }
+    /* Split to form "AAANNNN" string */
+
+    AcpiOsPrintf ("EisaId (\"%c%c%c%4.4X\")",
+
+        /* Three Alpha characters (AAA), 5 bits each */
+
+        (int) ((BigEndianId >> 26) & 0x1F) + 0x40,
+        (int) ((BigEndianId >> 21) & 0x1F) + 0x40,
+        (int) ((BigEndianId >> 16) & 0x1F) + 0x40,
+
+        /* Numeric part (NNNN) is simply the lower 16 bits */
+
+        (UINT32) (BigEndianId & 0xFFFF));
 }
+
+#endif
