@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -118,15 +118,12 @@
 #include "acparser.h"
 #include "amlcode.h"
 #include "acdisasm.h"
-#include "acinterp.h"
-#include "acnamesp.h"
 
 #ifdef ACPI_DISASSEMBLER
 
 #define _COMPONENT          ACPI_CA_DEBUGGER
         ACPI_MODULE_NAME    ("dmopcode")
 
-
 /* Local prototypes */
 
 static void
@@ -134,159 +131,6 @@ AcpiDmMatchKeyword (
     ACPI_PARSE_OBJECT       *Op);
 
 
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmDisplayTargetPathname
- *
- * PARAMETERS:  Op              - Parse object
- *
- * RETURN:      None
- *
- * DESCRIPTION: For AML opcodes that have a target operand, display the full
- *              pathname for the target, in a comment field. Handles Return()
- *              statements also.
- *
- ******************************************************************************/
-
-void
-AcpiDmDisplayTargetPathname (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    ACPI_PARSE_OBJECT       *NextOp;
-    ACPI_PARSE_OBJECT       *PrevOp = NULL;
-    char                    *Pathname;
-    const ACPI_OPCODE_INFO  *OpInfo;
-
-
-    if (Op->Common.AmlOpcode == AML_RETURN_OP)
-    {
-        PrevOp = Op->Asl.Value.Arg;
-    }
-    else
-    {
-        OpInfo = AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode);
-        if (!(OpInfo->Flags & AML_HAS_TARGET))
-        {
-            return;
-        }
-
-        /* Target is the last Op in the arg list */
-
-        NextOp = Op->Asl.Value.Arg;
-        while (NextOp)
-        {
-            PrevOp = NextOp;
-            NextOp = PrevOp->Asl.Next;
-        }
-    }
-
-    if (!PrevOp)
-    {
-        return;
-    }
-
-    /* We must have a namepath AML opcode */
-
-    if (PrevOp->Asl.AmlOpcode != AML_INT_NAMEPATH_OP)
-    {
-        return;
-    }
-
-    /* A null string is the "no target specified" case */
-
-    if (!PrevOp->Asl.Value.String)
-    {
-        return;
-    }
-
-    /* No node means "unresolved external reference" */
-
-    if (!PrevOp->Asl.Node)
-    {
-        AcpiOsPrintf (" /* External reference */");
-        return;
-    }
-
-    /* Ignore if path is already from the root */
-
-    if (*PrevOp->Asl.Value.String == '\\')
-    {
-        return;
-    }
-
-    /* Now: we can get the full pathname */
-
-    Pathname = AcpiNsGetExternalPathname (PrevOp->Asl.Node);
-    if (!Pathname)
-    {
-        return;
-    }
-
-    AcpiOsPrintf (" /* %s */", Pathname);
-    ACPI_FREE (Pathname);
-}
-
-
-/*******************************************************************************
- *
- * FUNCTION:    AcpiDmNotifyDescription
- *
- * PARAMETERS:  Op              - Name() parse object
- *
- * RETURN:      None
- *
- * DESCRIPTION: Emit a description comment for the value associated with a
- *              Notify() operator.
- *
- ******************************************************************************/
-
-void
-AcpiDmNotifyDescription (
-    ACPI_PARSE_OBJECT       *Op)
-{
-    ACPI_PARSE_OBJECT       *NextOp;
-    ACPI_NAMESPACE_NODE     *Node;
-    UINT8                   NotifyValue;
-    UINT8                   Type = ACPI_TYPE_ANY;
-
-
-    /* The notify value is the second argument */
-
-    NextOp = Op->Asl.Value.Arg;
-    NextOp = NextOp->Asl.Next;
-
-    switch (NextOp->Common.AmlOpcode)
-    {
-    case AML_ZERO_OP:
-    case AML_ONE_OP:
-
-        NotifyValue = (UINT8) NextOp->Common.AmlOpcode;
-        break;
-
-    case AML_BYTE_OP:
-
-        NotifyValue = (UINT8) NextOp->Asl.Value.Integer;
-        break;
-
-    default:
-        return;
-    }
-
-    /*
-     * Attempt to get the namespace node so we can determine the object type.
-     * Some notify values are dependent on the object type (Device, Thermal,
-     * or Processor).
-     */
-    Node = Op->Asl.Node;
-    if (Node)
-    {
-        Type = Node->Type;
-    }
-
-    AcpiOsPrintf (" // %s", AcpiUtGetNotifyName (NotifyValue, Type));
-}
-
-
 /*******************************************************************************
  *
  * FUNCTION:    AcpiDmPredefinedDescription
@@ -411,11 +255,14 @@ AcpiDmPredefinedDescription (
 
     /* Match the name in the info table */
 
-    Info = AcpiAhMatchPredefinedName (NameString);
-    if (Info)
+    for (Info = AslPredefinedInfo; Info->Name; Info++)
     {
-        AcpiOsPrintf ("  // %4.4s: %s",
-            NameString, ACPI_CAST_PTR (char, Info->Description));
+        if (ACPI_COMPARE_NAME (NameString, Info->Name))
+        {
+            AcpiOsPrintf ("  // %4.4s: %s",
+                NameString, ACPI_CAST_PTR (char, Info->Description));
+            return;
+        }
     }
 
 #endif
@@ -492,11 +339,14 @@ AcpiDmFieldPredefinedDescription (
 
     /* Match the name in the info table */
 
-    Info = AcpiAhMatchPredefinedName (Tag);
-    if (Info)
+    for (Info = AslPredefinedInfo; Info->Name; Info++)
     {
-        AcpiOsPrintf ("  // %4.4s: %s", Tag,
-            ACPI_CAST_PTR (char, Info->Description));
+        if (ACPI_COMPARE_NAME (Tag, Info->Name))
+        {
+            AcpiOsPrintf ("  // %4.4s: %s", Tag,
+                ACPI_CAST_PTR (char, Info->Description));
+            return;
+        }
     }
 
 #endif
@@ -640,6 +490,7 @@ AcpiDmRegionFlags (
     ACPI_PARSE_OBJECT       *Op)
 {
 
+
     /* The next Op contains the SpaceId */
 
     Op = AcpiPsGetDepthNext (NULL, Op);
@@ -709,6 +560,7 @@ AcpiDmMatchKeyword (
     ACPI_PARSE_OBJECT       *Op)
 {
 
+
     if (((UINT32) Op->Common.Value.Integer) > ACPI_MAX_MATCH_OPCODE)
     {
         AcpiOsPrintf ("/* Unknown Match Keyword encoding */");
@@ -747,7 +599,6 @@ AcpiDmDisassembleOneOp (
     ACPI_PARSE_OBJECT       *Child;
     ACPI_STATUS             Status;
     UINT8                   *Aml;
-    const AH_DEVICE_ID      *IdInfo;
 
 
     if (!Op)
@@ -765,27 +616,27 @@ AcpiDmDisassembleOneOp (
 
     case ACPI_DASM_LNOT_SUFFIX:
 
-        if (!AcpiGbl_CstyleDisassembly)
+        switch (Op->Common.AmlOpcode)
         {
-            switch (Op->Common.AmlOpcode)
-            {
-            case AML_LEQUAL_OP:
-                AcpiOsPrintf ("LNotEqual");
-                break;
+        case AML_LEQUAL_OP:
 
-            case AML_LGREATER_OP:
-                AcpiOsPrintf ("LLessEqual");
-                break;
+            AcpiOsPrintf ("LNotEqual");
+            break;
 
-            case AML_LLESS_OP:
-                AcpiOsPrintf ("LGreaterEqual");
-                break;
+        case AML_LGREATER_OP:
 
-            default:
-                break;
-            }
+            AcpiOsPrintf ("LLessEqual");
+            break;
+
+        case AML_LLESS_OP:
+
+            AcpiOsPrintf ("LGreaterEqual");
+            break;
+
+        default:
+
+            break;
         }
-
         Op->Common.DisasmOpcode = 0;
         Op->Common.DisasmFlags |= ACPI_PARSEOP_IGNORE;
         return;
@@ -794,6 +645,7 @@ AcpiDmDisassembleOneOp (
         break;
     }
 
+
     OpInfo = AcpiPsGetOpcodeInfo (Op->Common.AmlOpcode);
 
     /* The op and arguments */
@@ -825,7 +677,7 @@ AcpiDmDisassembleOneOp (
 
         if (Op->Common.DisasmOpcode == ACPI_DASM_EISAID)
         {
-            AcpiDmDecompressEisaId ((UINT32) Op->Common.Value.Integer);
+            AcpiDmEisaId ((UINT32) Op->Common.Value.Integer);
         }
         else
         {
@@ -837,7 +689,7 @@ AcpiDmDisassembleOneOp (
 
         if (Op->Common.DisasmOpcode == ACPI_DASM_EISAID)
         {
-            AcpiDmDecompressEisaId ((UINT32) Op->Common.Value.Integer);
+            AcpiDmEisaId ((UINT32) Op->Common.Value.Integer);
         }
         else
         {
@@ -853,20 +705,7 @@ AcpiDmDisassembleOneOp (
 
     case AML_STRING_OP:
 
-        AcpiUtPrintString (Op->Common.Value.String, ACPI_UINT16_MAX);
-
-        /* For _HID/_CID strings, attempt to output a descriptive comment */
-
-        if (Op->Common.DisasmOpcode == ACPI_DASM_HID_STRING)
-        {
-            /* If we know about the ID, emit the description */
-
-            IdInfo = AcpiAhMatchHardwareId (Op->Common.Value.String);
-            if (IdInfo)
-            {
-                AcpiOsPrintf (" /* %s */", IdInfo->Description);
-            }
-        }
+        AcpiUtPrintString (Op->Common.Value.String, ACPI_UINT8_MAX);
         break;
 
     case AML_BUFFER_OP:
@@ -897,12 +736,7 @@ AcpiDmDisassembleOneOp (
             }
         }
 
-        if (AcpiDmIsUuidBuffer (Op))
-        {
-            Op->Common.DisasmOpcode = ACPI_DASM_UUID;
-            AcpiOsPrintf ("ToUUID (");
-        }
-        else if (AcpiDmIsUnicodeBuffer (Op))
+        if (AcpiDmIsUnicodeBuffer (Op))
         {
             Op->Common.DisasmOpcode = ACPI_DASM_UNICODE;
             AcpiOsPrintf ("Unicode (");
@@ -915,7 +749,7 @@ AcpiDmDisassembleOneOp (
         else if (AcpiDmIsPldBuffer (Op))
         {
             Op->Common.DisasmOpcode = ACPI_DASM_PLD_METHOD;
-            AcpiOsPrintf ("ToPLD (");
+            AcpiOsPrintf ("Buffer");
         }
         else
         {
@@ -924,6 +758,18 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
+    case AML_INT_STATICSTRING_OP:
+
+        if (Op->Common.Value.String)
+        {
+            AcpiOsPrintf ("%s", Op->Common.Value.String);
+        }
+        else
+        {
+            AcpiOsPrintf ("\"<NULL STATIC STRING PTR>\"");
+        }
+        break;
+
     case AML_INT_NAMEPATH_OP:
 
         AcpiDmNamestring (Op->Common.Value.Name);
@@ -991,9 +837,7 @@ AcpiDmDisassembleOneOp (
             Length = (UINT32) Child->Common.Value.Integer;
 
             Info->Level += 1;
-            Info->MappingOp = Op;
             Op->Common.DisasmOpcode = ACPI_DASM_RESOURCE;
-
             AcpiDmResourceTemplate (Info, Op->Common.Parent, Aml, Length);
 
             Info->Level -= 1;
