@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -114,6 +114,8 @@
  *
  *****************************************************************************/
 
+#define __NSREPAIR2_C__
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
@@ -548,8 +550,8 @@ AcpiNsRepair_CID (
  * DESCRIPTION: Repair for the _CST object:
  *              1. Sort the list ascending by C state type
  *              2. Ensure type cannot be zero
- *              3. A subpackage count of zero means _CST is meaningless
- *              4. Count must match the number of C state subpackages
+ *              3. A sub-package count of zero means _CST is meaningless
+ *              4. Count must match the number of C state sub-packages
  *
  *****************************************************************************/
 
@@ -571,7 +573,19 @@ AcpiNsRepair_CST (
 
 
     /*
-     * Check if the C-state type values are proportional.
+     * Entries (subpackages) in the _CST Package must be sorted by the
+     * C-state type, in ascending order.
+     */
+    Status = AcpiNsCheckSortedList (Info, ReturnObject, 1, 4, 1,
+                ACPI_SORT_ASCENDING, "C-State Type");
+    if (ACPI_FAILURE (Status))
+    {
+        return (Status);
+    }
+
+    /*
+     * We now know the list is correctly sorted by C-state type. Check if
+     * the C-state type values are proportional.
      */
     OuterElementCount = ReturnObject->Package.Count - 1;
     i = 0;
@@ -585,7 +599,6 @@ AcpiNsRepair_CST (
             ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
                 "SubPackage[%u] - removing entry due to zero count", i));
             Removing = TRUE;
-            goto RemoveElement;
         }
 
         ObjDesc = (*OuterElements)->Package.Elements[1]; /* Index1 = Type */
@@ -596,7 +609,6 @@ AcpiNsRepair_CST (
             Removing = TRUE;
         }
 
-RemoveElement:
         if (Removing)
         {
             AcpiNsRemoveElement (ReturnObject, i + 1);
@@ -612,18 +624,6 @@ RemoveElement:
 
     ObjDesc = ReturnObject->Package.Elements[0];
     ObjDesc->Integer.Value = OuterElementCount;
-
-    /*
-     * Entries (subpackages) in the _CST Package must be sorted by the
-     * C-state type, in ascending order.
-     */
-    Status = AcpiNsCheckSortedList (Info, ReturnObject, 1, 4, 1,
-                ACPI_SORT_ASCENDING, "C-State Type");
-    if (ACPI_FAILURE (Status))
-    {
-        return (Status);
-    }
-
     return (AE_OK);
 }
 
@@ -742,7 +742,6 @@ AcpiNsRepair_PRT (
     ACPI_OPERAND_OBJECT     **TopObjectList;
     ACPI_OPERAND_OBJECT     **SubObjectList;
     ACPI_OPERAND_OBJECT     *ObjDesc;
-    ACPI_OPERAND_OBJECT     *SubPackage;
     UINT32                  ElementCount;
     UINT32                  Index;
 
@@ -752,19 +751,9 @@ AcpiNsRepair_PRT (
     TopObjectList = PackageObject->Package.Elements;
     ElementCount = PackageObject->Package.Count;
 
-    /* Examine each subpackage */
-
-    for (Index = 0; Index < ElementCount; Index++, TopObjectList++)
+    for (Index = 0; Index < ElementCount; Index++)
     {
-        SubPackage = *TopObjectList;
-        SubObjectList = SubPackage->Package.Elements;
-
-        /* Check for minimum required element count */
-
-        if (SubPackage->Package.Count < 4)
-        {
-            continue;
-        }
+        SubObjectList = (*TopObjectList)->Package.Elements;
 
         /*
          * If the BIOS has erroneously reversed the _PRT SourceName (index 2)
@@ -779,11 +768,14 @@ AcpiNsRepair_PRT (
             SubObjectList[2] = ObjDesc;
             Info->ReturnFlags |= ACPI_OBJECT_REPAIRED;
 
-            ACPI_WARN_PREDEFINED ((AE_INFO,
-                Info->FullPathname, Info->NodeFlags,
+            ACPI_WARN_PREDEFINED ((AE_INFO, Info->FullPathname, Info->NodeFlags,
                 "PRT[%X]: Fixed reversed SourceName and SourceIndex",
                 Index));
         }
+
+        /* Point to the next ACPI_OPERAND_OBJECT in the top level package */
+
+        TopObjectList++;
     }
 
     return (AE_OK);
@@ -823,7 +815,7 @@ AcpiNsRepair_PSS (
 
 
     /*
-     * Entries (subpackages) in the _PSS Package must be sorted by power
+     * Entries (sub-packages) in the _PSS Package must be sorted by power
      * dissipation, in descending order. If it appears that the list is
      * incorrectly sorted, sort it. We sort by CpuFrequency, since this
      * should be proportional to the power.
@@ -916,9 +908,9 @@ AcpiNsRepair_TSS (
  *
  * PARAMETERS:  Info                - Method execution information block
  *              ReturnObject        - Pointer to the top-level returned object
- *              StartIndex          - Index of the first subpackage
- *              ExpectedCount       - Minimum length of each subpackage
- *              SortIndex           - Subpackage entry to sort on
+ *              StartIndex          - Index of the first sub-package
+ *              ExpectedCount       - Minimum length of each sub-package
+ *              SortIndex           - Sub-package entry to sort on
  *              SortDirection       - Ascending or descending
  *              SortKeyName         - Name of the SortIndex field
  *
@@ -959,7 +951,7 @@ AcpiNsCheckSortedList (
     }
 
     /*
-     * NOTE: assumes list of subpackages contains no NULL elements.
+     * NOTE: assumes list of sub-packages contains no NULL elements.
      * Any NULL elements should have been removed by earlier call
      * to AcpiNsRemoveNullElements.
      */
@@ -989,7 +981,7 @@ AcpiNsCheckSortedList (
             return (AE_AML_OPERAND_TYPE);
         }
 
-        /* Each subpackage must have the minimum length */
+        /* Each sub-package must have the minimum length */
 
         if ((*OuterElements)->Package.Count < ExpectedCount)
         {
