@@ -9,7 +9,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -112,45 +112,9 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
-#define EXPORT_ACPI_INTERFACES
+#define __NSXFNAME_C__
 
 #include "acpi.h"
 #include "accommon.h"
@@ -234,7 +198,7 @@ AcpiGetHandle (
 
         /* Special case for root-only, since we can't search for it */
 
-        if (!strcmp (Pathname, ACPI_NS_ROOT_PATH))
+        if (!ACPI_STRCMP (Pathname, ACPI_NS_ROOT_PATH))
         {
             *RetHandle = ACPI_CAST_PTR (ACPI_HANDLE, AcpiGbl_RootNode);
             return (AE_OK);
@@ -284,6 +248,7 @@ AcpiGetName (
     ACPI_BUFFER             *Buffer)
 {
     ACPI_STATUS             Status;
+    ACPI_NAMESPACE_NODE     *Node;
 
 
     /* Parameter validation */
@@ -299,6 +264,14 @@ AcpiGetName (
         return (Status);
     }
 
+    if (NameType == ACPI_FULL_PATHNAME)
+    {
+        /* Get the full pathname (From the namespace root) */
+
+        Status = AcpiNsHandleToPathname (Handle, Buffer);
+        return (Status);
+    }
+
     /*
      * Wants the single segment ACPI name.
      * Validate handle and convert to a namespace Node
@@ -309,21 +282,30 @@ AcpiGetName (
         return (Status);
     }
 
-    if (NameType == ACPI_FULL_PATHNAME ||
-        NameType == ACPI_FULL_PATHNAME_NO_TRAILING)
+    Node = AcpiNsValidateHandle (Handle);
+    if (!Node)
     {
-        /* Get the full pathname (From the namespace root) */
-
-        Status = AcpiNsHandleToPathname (Handle, Buffer,
-            NameType == ACPI_FULL_PATHNAME ? FALSE : TRUE);
+        Status = AE_BAD_PARAMETER;
+        goto UnlockAndExit;
     }
-    else
+
+    /* Validate/Allocate/Clear caller buffer */
+
+    Status = AcpiUtInitializeBuffer (Buffer, ACPI_PATH_SEGMENT_LENGTH);
+    if (ACPI_FAILURE (Status))
     {
-        /* Get the single name */
-
-        Status = AcpiNsHandleToName (Handle, Buffer);
+        goto UnlockAndExit;
     }
 
+    /* Just copy the ACPI name from the Node and zero terminate it */
+
+    ACPI_MOVE_NAME (Buffer->Pointer, AcpiUtGetNodeName (Node));
+    ((char *) Buffer->Pointer) [ACPI_NAME_SIZE] = 0;
+    Status = AE_OK;
+
+
+UnlockAndExit:
+
     (void) AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
     return (Status);
 }
@@ -351,6 +333,7 @@ AcpiNsCopyDeviceId (
     ACPI_PNP_DEVICE_ID      *Source,
     char                    *StringArea)
 {
+
     /* Create the destination PNP_DEVICE_ID */
 
     Dest->String = StringArea;
@@ -358,7 +341,7 @@ AcpiNsCopyDeviceId (
 
     /* Copy actual string and return a pointer to the next string area */
 
-    memcpy (StringArea, Source->String, Source->Length);
+    ACPI_MEMCPY (StringArea, Source->String, Source->Length);
     return (StringArea + Source->Length);
 }
 
@@ -376,19 +359,11 @@ AcpiNsCopyDeviceId (
  *              namespace node and possibly by running several standard
  *              control methods (Such as in the case of a device.)
  *
- * For Device and Processor objects, run the Device _HID, _UID, _CID,
- * _CLS, _ADR, _SxW, and _SxD methods.
+ * For Device and Processor objects, run the Device _HID, _UID, _CID, _SUB,
+ * _STA, _ADR, _SxW, and _SxD methods.
  *
  * Note: Allocates the return buffer, must be freed by the caller.
  *
- * Note: This interface is intended to be used during the initial device
- * discovery namespace traversal. Therefore, no complex methods can be
- * executed, especially those that access operation regions. Therefore, do
- * not add any additional methods that could cause problems in this area.
- * Because of this reason support for the following methods has been removed:
- * 1) _SUB method was removed (11/2015)
- * 2) _STA method was removed (02/2018)
- *
  ******************************************************************************/
 
 ACPI_STATUS
@@ -401,12 +376,12 @@ AcpiGetObjectInfo (
     ACPI_PNP_DEVICE_ID_LIST *CidList = NULL;
     ACPI_PNP_DEVICE_ID      *Hid = NULL;
     ACPI_PNP_DEVICE_ID      *Uid = NULL;
-    ACPI_PNP_DEVICE_ID      *Cls = NULL;
+    ACPI_PNP_DEVICE_ID      *Sub = NULL;
     char                    *NextIdString;
     ACPI_OBJECT_TYPE        Type;
     ACPI_NAME               Name;
     UINT8                   ParamCount= 0;
-    UINT16                  Valid = 0;
+    UINT8                   Valid = 0;
     UINT32                  InfoSize;
     UINT32                  i;
     ACPI_STATUS             Status;
@@ -454,7 +429,7 @@ AcpiGetObjectInfo (
     {
         /*
          * Get extra info for ACPI Device/Processor objects only:
-         * Run the Device _HID, _UID, _CLS, and _CID methods.
+         * Run the Device _HID, _UID, _SUB, and _CID methods.
          *
          * Note: none of these methods are required, so they may or may
          * not be present for this device. The Info->Valid bitfield is used
@@ -479,6 +454,15 @@ AcpiGetObjectInfo (
             Valid |= ACPI_VALID_UID;
         }
 
+        /* Execute the Device._SUB method */
+
+        Status = AcpiUtExecute_SUB (Node, &Sub);
+        if (ACPI_SUCCESS (Status))
+        {
+            InfoSize += Sub->Length;
+            Valid |= ACPI_VALID_SUB;
+        }
+
         /* Execute the Device._CID method */
 
         Status = AcpiUtExecute_CID (Node, &CidList);
@@ -489,15 +473,6 @@ AcpiGetObjectInfo (
             InfoSize += (CidList->ListSize - sizeof (ACPI_PNP_DEVICE_ID_LIST));
             Valid |= ACPI_VALID_CID;
         }
-
-        /* Execute the Device._CLS method */
-
-        Status = AcpiUtExecute_CLS (Node, &Cls);
-        if (ACPI_SUCCESS (Status))
-        {
-            InfoSize += Cls->Length;
-            Valid |= ACPI_VALID_CLS;
-        }
     }
 
     /*
@@ -518,17 +493,25 @@ AcpiGetObjectInfo (
     {
         /*
          * Get extra info for ACPI Device/Processor objects only:
-         * Run the _ADR and, SxW, and _SxD methods.
+         * Run the _STA, _ADR and, SxW, and _SxD methods.
          *
-         * Notes: none of these methods are required, so they may or may
+         * Note: none of these methods are required, so they may or may
          * not be present for this device. The Info->Valid bitfield is used
          * to indicate which methods were found and run successfully.
          */
 
+        /* Execute the Device._STA method */
+
+        Status = AcpiUtExecute_STA (Node, &Info->CurrentStatus);
+        if (ACPI_SUCCESS (Status))
+        {
+            Valid |= ACPI_VALID_STA;
+        }
+
         /* Execute the Device._ADR method */
 
         Status = AcpiUtEvaluateNumericObject (METHOD_NAME__ADR, Node,
-            &Info->Address);
+                    &Info->Address);
         if (ACPI_SUCCESS (Status))
         {
             Valid |= ACPI_VALID_ADR;
@@ -537,8 +520,8 @@ AcpiGetObjectInfo (
         /* Execute the Device._SxW methods */
 
         Status = AcpiUtExecutePowerMethods (Node,
-            AcpiGbl_LowestDstateNames, ACPI_NUM_SxW_METHODS,
-            Info->LowestDstates);
+                    AcpiGbl_LowestDstateNames, ACPI_NUM_SxW_METHODS,
+                    Info->LowestDstates);
         if (ACPI_SUCCESS (Status))
         {
             Valid |= ACPI_VALID_SXWS;
@@ -547,8 +530,8 @@ AcpiGetObjectInfo (
         /* Execute the Device._SxD methods */
 
         Status = AcpiUtExecutePowerMethods (Node,
-            AcpiGbl_HighestDstateNames, ACPI_NUM_SxD_METHODS,
-            Info->HighestDstates);
+                    AcpiGbl_HighestDstateNames, ACPI_NUM_SxD_METHODS,
+                    Info->HighestDstates);
         if (ACPI_SUCCESS (Status))
         {
             Valid |= ACPI_VALID_SXDS;
@@ -568,8 +551,9 @@ AcpiGetObjectInfo (
     }
 
     /*
-     * Copy the HID, UID, and CIDs to the return buffer. The variable-length
-     * strings are copied to the reserved area at the end of the buffer.
+     * Copy the HID, UID, SUB, and CIDs to the return buffer.
+     * The variable-length strings are copied to the reserved area
+     * at the end of the buffer.
      *
      * For HID and CID, check if the ID is a PCI Root Bridge.
      */
@@ -590,6 +574,12 @@ AcpiGetObjectInfo (
             Uid, NextIdString);
     }
 
+    if (Sub)
+    {
+        NextIdString = AcpiNsCopyDeviceId (&Info->SubsystemId,
+            Sub, NextIdString);
+    }
+
     if (CidList)
     {
         Info->CompatibleIdList.Count = CidList->Count;
@@ -609,12 +599,6 @@ AcpiGetObjectInfo (
         }
     }
 
-    if (Cls)
-    {
-        NextIdString = AcpiNsCopyDeviceId (&Info->ClassCode,
-            Cls, NextIdString);
-    }
-
     /* Copy the fixed-length data */
 
     Info->InfoSize = InfoSize;
@@ -636,14 +620,14 @@ Cleanup:
     {
         ACPI_FREE (Uid);
     }
+    if (Sub)
+    {
+        ACPI_FREE (Sub);
+    }
     if (CidList)
     {
         ACPI_FREE (CidList);
     }
-    if (Cls)
-    {
-        ACPI_FREE (Cls);
-    }
     return (Status);
 }
 
@@ -691,8 +675,8 @@ AcpiInstallMethod (
 
     /* Table must be a DSDT or SSDT */
 
-    if (!ACPI_COMPARE_NAMESEG (Table->Signature, ACPI_SIG_DSDT) &&
-        !ACPI_COMPARE_NAMESEG (Table->Signature, ACPI_SIG_SSDT))
+    if (!ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_DSDT) &&
+        !ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_SSDT))
     {
         return (AE_BAD_HEADER);
     }
@@ -711,7 +695,6 @@ AcpiInstallMethod (
     ParserState.Aml += AcpiPsGetOpcodeSize (Opcode);
     ParserState.PkgEnd = AcpiPsGetNextPackageEnd (&ParserState);
     Path = AcpiPsGetNextNamestring (&ParserState);
-
     MethodFlags = *ParserState.Aml++;
     AmlStart = ParserState.Aml;
     AmlLength = ACPI_PTR_DIFF (ParserState.PkgEnd, AmlStart);
@@ -744,7 +727,7 @@ AcpiInstallMethod (
     /* The lookup either returns an existing node or creates a new one */
 
     Status = AcpiNsLookup (NULL, Path, ACPI_TYPE_METHOD, ACPI_IMODE_LOAD_PASS1,
-        ACPI_NS_DONT_OPEN_SCOPE | ACPI_NS_ERROR_IF_FOUND, NULL, &Node);
+                ACPI_NS_DONT_OPEN_SCOPE | ACPI_NS_ERROR_IF_FOUND, NULL, &Node);
 
     (void) AcpiUtReleaseMutex (ACPI_MTX_NAMESPACE);
 
@@ -766,7 +749,7 @@ AcpiInstallMethod (
 
     /* Copy the method AML to the local buffer */
 
-    memcpy (AmlBuffer, AmlStart, AmlLength);
+    ACPI_MEMCPY (AmlBuffer, AmlStart, AmlLength);
 
     /* Initialize the method object with the new method's information */
 
