@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,19 +113,6 @@
  *
  *****************************************************************************/
 
-
-/*
- * Global variables. Defined in main.c only, externed in all other files
- */
-#ifdef _DECLARE_GLOBALS
-#define EXTERN
-#define INIT_GLOBAL(a,b)        a=b
-#define DEFINE_ACPI_GLOBALS     1
-#else
-#define EXTERN                  extern
-#define INIT_GLOBAL(a,b)        a
-#endif
-
 #include "acpi.h"
 #include "accommon.h"
 #include "actables.h"
@@ -135,22 +122,34 @@
 #include <errno.h>
 #include <sys/stat.h>
 
+/*
+ * Global variables. Defined in main.c only, externed in all other files
+ */
+#ifdef _DECLARE_GLOBALS
+#define EXTERN
+#define INIT_GLOBAL(a,b)        a=b
+#else
+#define EXTERN                  extern
+#define INIT_GLOBAL(a,b)        a
+#endif
+
 
 /* Globals */
 
 EXTERN BOOLEAN              INIT_GLOBAL (Gbl_SummaryMode, FALSE);
 EXTERN BOOLEAN              INIT_GLOBAL (Gbl_VerboseMode, FALSE);
 EXTERN BOOLEAN              INIT_GLOBAL (Gbl_BinaryMode, FALSE);
-EXTERN BOOLEAN              INIT_GLOBAL (Gbl_DumpCustomizedTables, FALSE);
-EXTERN BOOLEAN              INIT_GLOBAL (Gbl_DoNotDumpXsdt, FALSE);
+EXTERN UINT32               INIT_GLOBAL (Gbl_SsdtCount, 0);
 EXTERN FILE                 INIT_GLOBAL (*Gbl_OutputFile, NULL);
 EXTERN char                 INIT_GLOBAL (*Gbl_OutputFilename, NULL);
-EXTERN UINT64               INIT_GLOBAL (Gbl_RsdpBase, 0);
 
 /* Globals required for use with ACPICA modules */
 
 #ifdef _DECLARE_GLOBALS
+UINT8                       AcpiGbl_EnableInterpreterSlack = FALSE;
 UINT8                       AcpiGbl_IntegerByteWidth = 8;
+UINT32                      AcpiDbgLevel = 0;
+UINT32                      AcpiDbgLayer = 0;
 #endif
 
 /* Action table used to defer requested options */
@@ -171,14 +170,6 @@ typedef struct ap_dump_action
 
 #define AP_MAX_ACPI_FILES           256 /* Prevent infinite loops */
 
-/* Minimum FADT sizes for various table addresses */
-
-#define MIN_FADT_FOR_DSDT           (ACPI_FADT_OFFSET (Dsdt) + sizeof (UINT32))
-#define MIN_FADT_FOR_FACS           (ACPI_FADT_OFFSET (Facs) + sizeof (UINT32))
-#define MIN_FADT_FOR_XDSDT          (ACPI_FADT_OFFSET (XDsdt) + sizeof (UINT64))
-#define MIN_FADT_FOR_XFACS          (ACPI_FADT_OFFSET (XFacs) + sizeof (UINT64))
-
-
 /*
  * apdump - Table get/dump routines
  */
@@ -198,30 +189,21 @@ int
 ApDumpAllTables (
     void);
 
-BOOLEAN
-ApIsValidHeader (
-    ACPI_TABLE_HEADER       *Table);
-
-BOOLEAN
-ApIsValidChecksum (
-    ACPI_TABLE_HEADER       *Table);
-
-UINT32
-ApGetTableLength (
-    ACPI_TABLE_HEADER       *Table);
-
 
 /*
  * apfiles - File I/O utilities
  */
+UINT32
+ApGetFileSize (
+    FILE                    *File);
+
 int
 ApOpenOutputFile (
     char                    *Pathname);
 
 int
 ApWriteToBinaryFile (
-    ACPI_TABLE_HEADER       *Table,
-    UINT32                  Instance);
+    ACPI_TABLE_HEADER       *Table);
 
 ACPI_TABLE_HEADER *
 ApGetTableFromFile (
