@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -118,10 +118,13 @@
 
 /* Local prototypes */
 
+static BOOLEAN
+ApIsValidHeader (
+    ACPI_TABLE_HEADER       *Table);
+
 static int
 ApDumpTableBuffer (
     ACPI_TABLE_HEADER       *Table,
-    UINT32                  Instance,
     ACPI_PHYSICAL_ADDRESS   Address);
 
 
@@ -137,124 +140,38 @@ ApDumpTableBuffer (
  *
  ******************************************************************************/
 
-BOOLEAN
+static BOOLEAN
 ApIsValidHeader (
     ACPI_TABLE_HEADER       *Table)
 {
 
-    if (!ACPI_VALIDATE_RSDP_SIG (Table->Signature))
+    /* Make sure signature is all ASCII and a valid ACPI name */
+
+    if (!AcpiUtValidAcpiName (Table->Signature))
     {
-        /* Make sure signature is all ASCII and a valid ACPI name */
+        fprintf (stderr, "Table signature (0x%X) is invalid\n",
+            *(UINT32 *) Table->Signature);
+        return (FALSE);
+    }
 
-        if (!AcpiUtValidAcpiName (Table->Signature))
-        {
-            AcpiLogError ("Table signature (0x%8.8X) is invalid\n",
-                *(UINT32 *) Table->Signature);
-            return (FALSE);
-        }
+    /* Check for minimum table length */
 
-        /* Check for minimum table length */
-
-        if (Table->Length < sizeof (ACPI_TABLE_HEADER))
-        {
-            AcpiLogError ("Table length (0x%8.8X) is invalid\n",
-                Table->Length);
-            return (FALSE);
-        }
+    if (Table->Length <= sizeof (ACPI_TABLE_HEADER))
+    {
+        fprintf (stderr, "Table length (0x%X) is invalid\n",
+            Table->Length);
+        return (FALSE);
     }
 
     return (TRUE);
 }
 
 
-/******************************************************************************
- *
- * FUNCTION:    ApIsValidChecksum
- *
- * PARAMETERS:  Table               - Pointer to table to be validated
- *
- * RETURN:      TRUE if the checksum appears to be valid. FALSE otherwise.
- *
- * DESCRIPTION: Check for a valid ACPI table checksum.
- *
- ******************************************************************************/
-
-BOOLEAN
-ApIsValidChecksum (
-    ACPI_TABLE_HEADER       *Table)
-{
-    ACPI_STATUS             Status;
-    ACPI_TABLE_RSDP         *Rsdp;
-
-
-    if (ACPI_VALIDATE_RSDP_SIG (Table->Signature))
-    {
-        /*
-         * Checksum for RSDP.
-         * Note: Other checksums are computed during the table dump.
-         */
-        Rsdp = ACPI_CAST_PTR (ACPI_TABLE_RSDP, Table);
-        Status = AcpiTbValidateRsdp (Rsdp);
-    }
-    else
-    {
-        Status = AcpiTbVerifyChecksum (Table, Table->Length);
-    }
-
-    if (ACPI_FAILURE (Status))
-    {
-        AcpiLogError ("%4.4s: Warning: wrong checksum in table\n",
-            Table->Signature);
-    }
-
-    return (AE_OK);
-}
-
-
-/******************************************************************************
- *
- * FUNCTION:    ApGetTableLength
- *
- * PARAMETERS:  Table               - Pointer to the table
- *
- * RETURN:      Table length
- *
- * DESCRIPTION: Obtain table length according to table signature.
- *
- ******************************************************************************/
-
-UINT32
-ApGetTableLength (
-    ACPI_TABLE_HEADER       *Table)
-{
-    ACPI_TABLE_RSDP         *Rsdp;
-
-
-    /* Check if table is valid */
-
-    if (!ApIsValidHeader (Table))
-    {
-        return (0);
-    }
-
-    if (ACPI_VALIDATE_RSDP_SIG (Table->Signature))
-    {
-        Rsdp = ACPI_CAST_PTR (ACPI_TABLE_RSDP, Table);
-        return (AcpiTbGetRsdpLength (Rsdp));
-    }
-
-    /* Normal ACPI table */
-
-    return (Table->Length);
-}
-
-
 /******************************************************************************
  *
  * FUNCTION:    ApDumpTableBuffer
  *
  * PARAMETERS:  Table               - ACPI table to be dumped
- *              Instance            - ACPI table instance no. to be dumped
  *              Address             - Physical address of the table
  *
  * RETURN:      None
@@ -267,13 +184,22 @@ ApGetTableLength (
 static int
 ApDumpTableBuffer (
     ACPI_TABLE_HEADER       *Table,
-    UINT32                  Instance,
     ACPI_PHYSICAL_ADDRESS   Address)
 {
-    UINT32                  TableLength;
 
+    /* Check if the table header appears to be valid */
 
-    TableLength = ApGetTableLength (Table);
+    if (!ApIsValidHeader (Table))
+    {
+        return (-1);
+    }
+
+     /* Validate the table checksum (except FACS - has no checksum) */
+
+    if (!ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_FACS))
+    {
+        (void) AcpiTbVerifyChecksum (Table, Table->Length);
+    }
 
     /* Print only the header if requested */
 
@@ -287,21 +213,20 @@ ApDumpTableBuffer (
 
     if (Gbl_BinaryMode)
     {
-        return (ApWriteToBinaryFile (Table, Instance));
+        return (ApWriteToBinaryFile (Table));
     }
 
     /*
-     * Dump the table with header for use with acpixtract utility.
+     * Dump the table with header for use with acpixtract utility
      * Note: simplest to just always emit a 64-bit address. AcpiXtract
      * utility can handle this.
      */
-    AcpiUtFilePrintf (Gbl_OutputFile, "%4.4s @ 0x%8.8X%8.8X\n",
-        Table->Signature, ACPI_FORMAT_UINT64 (Address));
+    printf ("%4.4s @ 0x%8.8X%8.8X\n", Table->Signature,
+        ACPI_FORMAT_UINT64 (Address));
 
-    AcpiUtDumpBufferToFile (Gbl_OutputFile,
-        ACPI_CAST_PTR (UINT8, Table), TableLength,
+    AcpiUtDumpBuffer (ACPI_CAST_PTR (UINT8, Table), Table->Length,
         DB_BYTE_DISPLAY, 0);
-    AcpiUtFilePrintf (Gbl_OutputFile, "\n");
+    printf ("\n");
     return (0);
 }
 
@@ -324,10 +249,8 @@ ApDumpAllTables (
     void)
 {
     ACPI_TABLE_HEADER       *Table;
-    UINT32                  Instance = 0;
     ACPI_PHYSICAL_ADDRESS   Address;
     ACPI_STATUS             Status;
-    int                     TableStatus;
     UINT32                  i;
 
 
@@ -335,7 +258,7 @@ ApDumpAllTables (
 
     for (i = 0; i < AP_MAX_ACPI_FILES; i++)
     {
-        Status = AcpiOsGetTableByIndex (i, &Table, &Instance, &Address);
+        Status = AcpiOsGetTableByIndex (i, &Table, &Address);
         if (ACPI_FAILURE (Status))
         {
             /* AE_LIMIT means that no more tables are available */
@@ -346,25 +269,23 @@ ApDumpAllTables (
             }
             else if (i == 0)
             {
-                AcpiLogError ("Could not get ACPI tables, %s\n",
+                fprintf (stderr, "Could not get ACPI tables, %s\n",
                     AcpiFormatException (Status));
                 return (-1);
             }
             else
             {
-                AcpiLogError ("Could not get ACPI table at index %u, %s\n",
+                fprintf (stderr, "Could not get ACPI table at index %u, %s\n",
                     i, AcpiFormatException (Status));
                 continue;
             }
         }
 
-        TableStatus = ApDumpTableBuffer (Table, Instance, Address);
-        ACPI_FREE (Table);
-
-        if (TableStatus)
+        if (ApDumpTableBuffer (Table, Address))
         {
-            break;
+            return (-1);
         }
+        free (Table);
     }
 
     /* Something seriously bad happened if the loop terminates here */
@@ -401,7 +322,7 @@ ApDumpTableByAddress (
     Status = AcpiUtStrtoul64 (AsciiAddress, 0, &LongAddress);
     if (ACPI_FAILURE (Status))
     {
-        AcpiLogError ("%s: Could not convert to a physical address\n",
+        fprintf (stderr, "%s: Could not convert to a physical address\n",
             AsciiAddress);
         return (-1);
     }
@@ -410,14 +331,14 @@ ApDumpTableByAddress (
     Status = AcpiOsGetTableByAddress (Address, &Table);
     if (ACPI_FAILURE (Status))
     {
-        AcpiLogError ("Could not get table at 0x%8.8X%8.8X, %s\n",
+        fprintf (stderr, "Could not get table at 0x%8.8X%8.8X, %s\n",
             ACPI_FORMAT_UINT64 (Address),
             AcpiFormatException (Status));
         return (-1);
     }
 
-    TableStatus = ApDumpTableBuffer (Table, 0, Address);
-    ACPI_FREE (Table);
+    TableStatus = ApDumpTableBuffer (Table, Address);
+    free (Table);
     return (TableStatus);
 }
 
@@ -444,33 +365,21 @@ ApDumpTableByName (
     ACPI_TABLE_HEADER       *Table;
     ACPI_PHYSICAL_ADDRESS   Address;
     ACPI_STATUS             Status;
-    int                     TableStatus;
 
 
-    if (ACPI_STRLEN (Signature) != ACPI_NAME_SIZE)
+    if (strlen (Signature) > ACPI_NAME_SIZE)
     {
-        AcpiLogError (
-            "Invalid table signature [%s]: must be exactly 4 characters\n",
+        fprintf (stderr,
+            "Invalid table signature [%s]: too long (4 chars max)\n",
             Signature);
         return (-1);
     }
 
     /* Table signatures are expected to be uppercase */
 
-    ACPI_STRCPY (LocalSignature, Signature);
+    strcpy (LocalSignature, Signature);
     AcpiUtStrupr (LocalSignature);
 
-    /* To be friendly, handle tables whose signatures do not match the name */
-
-    if (ACPI_COMPARE_NAME (LocalSignature, "FADT"))
-    {
-        ACPI_STRCPY (LocalSignature, ACPI_SIG_FADT);
-    }
-    else if (ACPI_COMPARE_NAME (LocalSignature, "MADT"))
-    {
-        ACPI_STRCPY (LocalSignature, ACPI_SIG_MADT);
-    }
-
     /* Dump all instances of this signature (to handle multiple SSDTs) */
 
     for (Instance = 0; Instance < AP_MAX_ACPI_FILES; Instance++)
@@ -486,19 +395,17 @@ ApDumpTableByName (
                 return (0);
             }
 
-            AcpiLogError (
+            fprintf (stderr,
                 "Could not get ACPI table with signature [%s], %s\n",
                 LocalSignature, AcpiFormatException (Status));
             return (-1);
         }
 
-        TableStatus = ApDumpTableBuffer (Table, Instance, Address);
-        ACPI_FREE (Table);
-
-        if (TableStatus)
+        if (ApDumpTableBuffer (Table, Address))
         {
-            break;
+            return (-1);
         }
+        free (Table);
     }
 
     /* Something seriously bad happened if the loop terminates here */
@@ -525,7 +432,7 @@ ApDumpTableFromFile (
 {
     ACPI_TABLE_HEADER       *Table;
     UINT32                  FileSize = 0;
-    int                     TableStatus = -1;
+    int                     TableStatus;
 
 
     /* Get the entire ACPI table from the file */
@@ -540,22 +447,49 @@ ApDumpTableFromFile (
 
     if (Table->Length > FileSize)
     {
-        AcpiLogError (
+        fprintf (stderr,
             "Table length (0x%X) is too large for input file (0x%X) %s\n",
             Table->Length, FileSize, Pathname);
-        goto Exit;
+        return (-1);
     }
 
     if (Gbl_VerboseMode)
     {
-        AcpiLogError (
+        fprintf (stderr,
             "Input file:  %s contains table [%4.4s], 0x%X (%u) bytes\n",
             Pathname, Table->Signature, FileSize, FileSize);
     }
 
-    TableStatus = ApDumpTableBuffer (Table, 0, 0);
-
-Exit:
-    ACPI_FREE (Table);
+    TableStatus = ApDumpTableBuffer (Table, 0);
+    free (Table);
     return (TableStatus);
 }
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AcpiOs* print functions
+ *
+ * DESCRIPTION: Used for linkage with ACPICA modules
+ *
+ ******************************************************************************/
+
+void ACPI_INTERNAL_VAR_XFACE
+AcpiOsPrintf (
+    const char              *Fmt,
+    ...)
+{
+    va_list                 Args;
+
+    va_start (Args, Fmt);
+    vfprintf (stdout, Fmt, Args);
+    va_end (Args);
+}
+
+void
+AcpiOsVprintf (
+    const char              *Fmt,
+    va_list                 Args)
+{
+    vfprintf (stdout, Fmt, Args);
+}
