@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,42 +111,6 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
- *****************************************************************************
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * following license:
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions, and the following disclaimer,
- *    without modification.
- * 2. Redistributions in binary form must reproduce at minimum a disclaimer
- *    substantially similar to the "NO WARRANTY" disclaimer below
- *    ("Disclaimer") and any redistribution must be conditioned upon
- *    including a substantially similar Disclaimer requirement for further
- *    binary redistribution.
- * 3. Neither the names of the above-listed copyright holders nor the names
- *    of any contributors may be used to endorse or promote products derived
- *    from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * Alternatively, you may choose to be licensed under the terms of the
- * GNU General Public License ("GPL") version 2 as published by the Free
- * Software Foundation.
- *
  *****************************************************************************/
 
 #include "aecommon.h"
@@ -155,18 +119,6 @@
         ACPI_MODULE_NAME    ("aemain")
 
 
-/*
- * Main routine for the ACPI user-space execution utility.
- *
- * Portability note: The utility depends upon the host for command-line
- * wildcard support - it is not implemented locally. For example:
- *
- * Linux/Unix systems: Shell expands wildcards automatically.
- *
- * Windows: The setargv.obj module must be linked in to automatically
- * expand wildcards.
- */
-
 /* Local prototypes */
 
 static int
@@ -174,6 +126,19 @@ AeDoOptions (
     int                     argc,
     char                    **argv);
 
+static ACPI_STATUS
+AcpiDbRunBatchMode (
+    void);
+
+static char *
+FlStrdup (
+    char                    *String);
+
+static char **
+AsDoWildcard (
+    char                    *DirectoryPathname,
+    char                    *FileSpecifier);
+
 
 #define AE_BUFFER_SIZE              1024
 #define ASL_MAX_FILES               256
@@ -187,41 +152,18 @@ AeDoOptions (
 
 /* Globals */
 
-BOOLEAN                     AcpiGbl_UseLocalFaultHandler = TRUE;
 UINT8                       AcpiGbl_RegionFillValue = 0;
 BOOLEAN                     AcpiGbl_IgnoreErrors = FALSE;
-BOOLEAN                     AcpiGbl_AbortLoopOnTimeout = FALSE;
 BOOLEAN                     AcpiGbl_DbOpt_NoRegionSupport = FALSE;
+BOOLEAN                     AcpiGbl_DebugTimeout = FALSE;
 UINT8                       AcpiGbl_UseHwReducedFadt = FALSE;
 BOOLEAN                     AcpiGbl_DoInterfaceTests = FALSE;
-BOOLEAN                     AcpiGbl_LoadTestTables = FALSE;
-BOOLEAN                     AcpiGbl_AeLoadOnly = FALSE;
 static UINT8                AcpiGbl_ExecutionMode = AE_MODE_COMMAND_LOOP;
 static char                 BatchBuffer[AE_BUFFER_SIZE];    /* Batch command buffer */
+static char                 *FileList[ASL_MAX_FILES];
+static AE_TABLE_DESC        *AeTableListHead = NULL;
 
-#define ACPIEXEC_NAME               "AML Execution/Debug Utility"
-#define AE_SUPPORTED_OPTIONS        "?b:d:e:f^ghlm^rt^v^:x:"
-
-
-/* Stubs for the disassembler */
-
-void
-MpSaveGpioInfo (
-    ACPI_PARSE_OBJECT       *Op,
-    AML_RESOURCE            *Resource,
-    UINT32                  PinCount,
-    UINT16                  *PinList,
-    char                    *DeviceName)
-{
-}
-
-void
-MpSaveSerialInfo (
-    ACPI_PARSE_OBJECT       *Op,
-    AML_RESOURCE            *Resource,
-    char                    *DeviceName)
-{
-}
+#define AE_SUPPORTED_OPTIONS        "?b:d:e:f:ghm^orv:x:"
 
 
 /******************************************************************************
@@ -249,42 +191,24 @@ usage (
     printf ("\n");
 
     ACPI_OPTION ("-da",                 "Disable method abort on error");
-    ACPI_OPTION ("-df",                 "Disable Local fault handler");
     ACPI_OPTION ("-di",                 "Disable execution of STA/INI methods during init");
     ACPI_OPTION ("-do",                 "Disable Operation Region address simulation");
-    ACPI_OPTION ("-dp",                 "Disable TermList parsing for scope objects");
     ACPI_OPTION ("-dr",                 "Disable repair of method return values");
-    ACPI_OPTION ("-ds",                 "Disable method auto-serialization");
     ACPI_OPTION ("-dt",                 "Disable allocation tracking (performance)");
     printf ("\n");
 
-    ACPI_OPTION ("-ed",                 "Enable timer output for Debug Object");
     ACPI_OPTION ("-ef",                 "Enable display of final memory statistics");
     ACPI_OPTION ("-ei",                 "Enable additional tests for ACPICA interfaces");
-    ACPI_OPTION ("-el",                 "Enable loading of additional test tables");
-    ACPI_OPTION ("-em",                 "Enable (legacy) grouping of module-level code");
+    ACPI_OPTION ("-em",                 "Enable Interpreter Serialized Mode");
     ACPI_OPTION ("-es",                 "Enable Interpreter Slack Mode");
     ACPI_OPTION ("-et",                 "Enable debug semaphore timeout");
     printf ("\n");
 
-    ACPI_OPTION ("-fi <File>",          "Specify namespace initialization file");
-    ACPI_OPTION ("-fv <Value>",         "Operation Region initialization fill value");
-    printf ("\n");
-
-    ACPI_OPTION ("-l",                  "Load tables and namespace only");
+    ACPI_OPTION ("-f <Value>",          "Operation Region initialization fill value");
     ACPI_OPTION ("-r",                  "Use hardware-reduced FADT V5");
-    ACPI_OPTION ("-te",                 "Exit loop on timeout instead of aborting method");
-    ACPI_OPTION ("-to <Seconds>",       "Set timeout period for AML while loops");
-    printf ("\n");
-
-    ACPI_OPTION ("-v",                  "Display version information");
-    ACPI_OPTION ("-vd",                 "Display build date and time");
     ACPI_OPTION ("-vi",                 "Verbose initialization output");
     ACPI_OPTION ("-vr",                 "Verbose region handler output");
     ACPI_OPTION ("-x <DebugLevel>",     "Debug output level");
-
-    printf ("\n  From within the interactive mode, use '?' or \"help\" to see\n"
-        "  a list of available AML Debugger commands\n");
 }
 
 
@@ -306,10 +230,9 @@ AeDoOptions (
     char                    **argv)
 {
     int                     j;
-    UINT32                  Temp;
 
 
-    while ((j = AcpiGetopt (argc, argv, AE_SUPPORTED_OPTIONS)) != ACPI_OPT_END) switch (j)
+    while ((j = AcpiGetopt (argc, argv, AE_SUPPORTED_OPTIONS)) != EOF) switch (j)
     {
     case 'b':
 
@@ -332,14 +255,9 @@ AeDoOptions (
             AcpiGbl_IgnoreErrors = TRUE;
             break;
 
-        case 'f':
-
-            AcpiGbl_UseLocalFaultHandler = FALSE;
-            break;
-
         case 'i':
 
-            AcpiGbl_DbOpt_NoIniMethods = TRUE;
+            AcpiGbl_DbOpt_ini_methods = FALSE;
             break;
 
         case 'o':
@@ -347,30 +265,20 @@ AeDoOptions (
             AcpiGbl_DbOpt_NoRegionSupport = TRUE;
             break;
 
-        case 'p':
-
-            AcpiGbl_ExecuteTablesAsMethods = FALSE;
-            break;
-
         case 'r':
-
+            
             AcpiGbl_DisableAutoRepair = TRUE;
             break;
 
-        case 's':
-
-            AcpiGbl_AutoSerializeMethods = FALSE;
-            break;
-
         case 't':
-
+            
             #ifdef ACPI_DBG_TRACK_ALLOCATIONS
                 AcpiGbl_DisableMemTracking = TRUE;
             #endif
             break;
 
         default:
-
+            
             printf ("Unknown option: -d%s\n", AcpiGbl_Optarg);
             return (-1);
         }
@@ -380,11 +288,6 @@ AeDoOptions (
 
         switch (AcpiGbl_Optarg[0])
         {
-        case 'd':
-
-            AcpiGbl_DisplayDebugTimer = TRUE;
-            break;
-
         case 'f':
 
             #ifdef ACPI_DBG_TRACK_ALLOCATIONS
@@ -397,14 +300,10 @@ AeDoOptions (
             AcpiGbl_DoInterfaceTests = TRUE;
             break;
 
-        case 'l':
-
-            AcpiGbl_LoadTestTables = TRUE;
-            break;
-
         case 'm':
 
-            AcpiGbl_GroupModuleLevelCode = TRUE;
+            AcpiGbl_AllMethodsSerialized = TRUE;
+            printf ("Enabling AML Interpreter serialized mode\n");
             break;
 
         case 's':
@@ -427,40 +326,12 @@ AeDoOptions (
 
     case 'f':
 
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'v':   /* -fv: region fill value */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            AcpiGbl_RegionFillValue = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
-            break;
-
-        case 'i':   /* -fi: specify initialization file */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            if (AeOpenInitializationFile (AcpiGbl_Optarg))
-            {
-                return (-1);
-            }
-            break;
-
-        default:
-
-            printf ("Unknown option: -f%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
+        AcpiGbl_RegionFillValue = (UINT8) strtoul (AcpiGbl_Optarg, NULL, 0);
         break;
 
     case 'g':
 
+        AcpiGbl_DbOpt_tables = TRUE;
         AcpiGbl_DbFilename = NULL;
         break;
 
@@ -468,12 +339,7 @@ AeDoOptions (
     case '?':
 
         usage();
-        return (1);
-
-    case 'l':
-
-        AcpiGbl_AeLoadOnly = TRUE;
-        break;
+        return (0);
 
     case 'm':
 
@@ -492,61 +358,22 @@ AeDoOptions (
         }
         break;
 
+    case 'o':
+
+        AcpiGbl_DbOpt_disasm = TRUE;
+        AcpiGbl_DbOpt_stats = TRUE;
+        break;
+
     case 'r':
 
         AcpiGbl_UseHwReducedFadt = TRUE;
         printf ("Using ACPI 5.0 Hardware Reduced Mode via version 5 FADT\n");
         break;
 
-    case 't':
-
-        switch (AcpiGbl_Optarg[0])
-        {
-        case 'o':  /* -to: Set loop timeout in seconds */
-
-            if (AcpiGetoptArgument (argc, argv))
-            {
-                return (-1);
-            }
-
-            Temp = strtoul (AcpiGbl_Optarg, NULL, 0);
-            if (!Temp || (Temp > ACPI_UINT16_MAX))
-            {
-                printf ("%s: Invalid loop timeout value\n",
-                    AcpiGbl_Optarg);
-                return (-1);
-            }
-
-            AcpiGbl_MaxLoopIterations = (UINT16) Temp;
-            printf ("Automatic loop timeout after %u seconds\n",
-                AcpiGbl_MaxLoopIterations);
-            break;
-
-        case 'e':
-
-            AcpiGbl_AbortLoopOnTimeout = TRUE;
-            break;
-
-        default:
-
-            printf ("Unknown option: -t%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-        break;
-
     case 'v':
 
         switch (AcpiGbl_Optarg[0])
         {
-        case '^':  /* -v: (Version): signon already emitted, just exit */
-
-            return (1);
-
-        case 'd':
-
-            printf (ACPI_COMMON_BUILD_TIME);
-            return (1);
-
         case 'i':
 
             AcpiDbgLevel |= ACPI_LV_INIT_NAMES;
@@ -572,7 +399,7 @@ AeDoOptions (
         break;
 
     default:
-
+        
         usage();
         return (-1);
     }
@@ -598,211 +425,199 @@ main (
     int                     argc,
     char                    **argv)
 {
-    ACPI_NEW_TABLE_DESC     *ListHead = NULL;
     ACPI_STATUS             Status;
     UINT32                  InitFlags;
-    int                     ExitCode = 0;
+    ACPI_TABLE_HEADER       *Table = NULL;
+    UINT32                  TableCount;
+    AE_TABLE_DESC           *TableDesc;
+    char                    **WildcardList;
+    char                    *Filename;
+    char                    *Directory;
+    char                    *FullPathname;
 
 
     ACPI_DEBUG_INITIALIZE (); /* For debug version only */
 
-    signal (SIGINT, AeSignalHandler);
-    if (AcpiGbl_UseLocalFaultHandler)
+    printf (ACPI_COMMON_SIGNON ("AML Execution/Debug Utility"));
+    if (argc < 2)
     {
-        signal (SIGSEGV, AeSignalHandler);
+        usage ();
+        return (0);
     }
 
-    /* Init debug globals */
+    signal (SIGINT, AeCtrlCHandler);
+
+    /* Init globals */
 
     AcpiDbgLevel = ACPI_NORMAL_DEFAULT;
     AcpiDbgLayer = 0xFFFFFFFF;
 
-    /* Module-level code. Use new architecture */
+    /* Init ACPI and start debugger thread */
 
-    AcpiGbl_ExecuteTablesAsMethods = TRUE;
-    AcpiGbl_GroupModuleLevelCode = FALSE;
-
-    /*
-     * Initialize ACPICA and start debugger thread.
-     *
-     * NOTE: After ACPICA initialization, AcpiTerminate MUST be called
-     * before this procedure exits -- otherwise, the console may be
-     * left in an incorrect state.
-     */
     Status = AcpiInitializeSubsystem ();
-    ACPI_CHECK_OK (AcpiInitializeSubsystem, Status);
+    AE_CHECK_OK (AcpiInitializeSubsystem, Status);
     if (ACPI_FAILURE (Status))
     {
-        goto ErrorExit;
-    }
-
-    /* Use a shorter timeout value for acpiexec */
-
-    AcpiGbl_MaxLoopIterations = 1;
-
-    /* Initialize the AML debugger */
-
-    Status = AcpiInitializeDebugger ();
-    ACPI_CHECK_OK (AcpiInitializeDebugger, Status);
-    if (ACPI_FAILURE (Status))
-    {
-        goto ErrorExit;
-    }
-
-    printf (ACPI_COMMON_SIGNON (ACPIEXEC_NAME));
-    if (argc < 2)
-    {
-        usage ();
-        goto NormalExit;
+        return (-1);
     }
 
     /* Get the command line options */
 
-    ExitCode = AeDoOptions (argc, argv);
-    if (ExitCode)
+    if (AeDoOptions (argc, argv))
     {
-        if (ExitCode > 0)
-        {
-            ExitCode = 0;
-        }
-
-        goto ErrorExit;
+        return (-1);
     }
 
     /* The remaining arguments are filenames for ACPI tables */
 
-    if (!argv[AcpiGbl_Optind])
+    if (argv[AcpiGbl_Optind])
     {
-        goto EnterDebugger;
-    }
+        AcpiGbl_DbOpt_tables = TRUE;
+        TableCount = 0;
 
-    AcpiGbl_CstyleDisassembly = FALSE; /* Not supported for AcpiExec */
+        /* Get each of the ACPI table files on the command line */
 
-    /* Get each of the ACPI table files on the command line */
-
-    while (argv[AcpiGbl_Optind])
-    {
-        /* Get all ACPI AML tables in this file */
-
-        Status = AcGetAllTablesFromFile (argv[AcpiGbl_Optind],
-            ACPI_GET_ALL_TABLES, &ListHead);
-        if (ACPI_FAILURE (Status))
+        while (argv[AcpiGbl_Optind])
         {
-            ExitCode = -1;
-            goto ErrorExit;
+            /* Split incoming path into a directory/filename combo */
+
+            Status = FlSplitInputPathname (argv[AcpiGbl_Optind],
+                &Directory, &Filename);
+            if (ACPI_FAILURE (Status))
+            {
+                return (-1);
+            }
+
+            /* Expand wildcards (Windows only) */
+
+            WildcardList = AsDoWildcard (Directory, Filename);
+            if (!WildcardList)
+            {
+                return (-1);
+            }
+
+            while (*WildcardList)
+            {
+                FullPathname = AcpiOsAllocate (
+                    strlen (Directory) + strlen (*WildcardList) + 1);
+
+                /* Construct a full path to the file */
+
+                strcpy (FullPathname, Directory);
+                strcat (FullPathname, *WildcardList);
+
+                /* Get one table */
+
+                Status = AcpiDbReadTableFromFile (FullPathname, &Table);
+                if (ACPI_FAILURE (Status))
+                {
+                    printf ("**** Could not get input table %s, %s\n",
+                        FullPathname, AcpiFormatException (Status));
+                    goto EnterDebugger;
+                }
+
+                AcpiOsFree (FullPathname);
+                AcpiOsFree (*WildcardList);
+                *WildcardList = NULL;
+                WildcardList++;
+
+                /* Ignore non-AML tables, we can't use them. Except for an FADT */
+
+                if (!ACPI_COMPARE_NAME (Table->Signature, ACPI_SIG_FADT) &&
+                    !AcpiUtIsAmlTable (Table))
+                {
+                    ACPI_WARNING ((AE_INFO,
+                        "Table %4.4s is not an AML table, ignoring",
+                        Table->Signature));
+                    AcpiOsFree (Table);
+                    continue;
+                }
+
+                /* Allocate and link a table descriptor */
+
+                TableDesc = AcpiOsAllocate (sizeof (AE_TABLE_DESC));
+                TableDesc->Table = Table;
+                TableDesc->Next = AeTableListHead;
+                AeTableListHead = TableDesc;
+
+                TableCount++;
+            }
+
+            AcpiGbl_Optind++;
         }
 
-        AcpiGbl_Optind++;
+        /* Build a local RSDT with all tables and let ACPICA process the RSDT */
+
+        Status = AeBuildLocalTables (TableCount, AeTableListHead);
+        if (ACPI_FAILURE (Status))
+        {
+            return (-1);
+        }
+
+        Status = AeInstallTables ();
+        if (ACPI_FAILURE (Status))
+        {
+            printf ("**** Could not load ACPI tables, %s\n",
+                AcpiFormatException (Status));
+            goto EnterDebugger;
+        }
+
+        /*
+         * Install most of the handlers.
+         * Override some default region handlers, especially SystemMemory
+         */
+        Status = AeInstallEarlyHandlers ();
+        if (ACPI_FAILURE (Status))
+        {
+            goto EnterDebugger;
+        }
+
+        /* Setup initialization flags for ACPICA */
+
+        InitFlags = (ACPI_NO_HANDLER_INIT | ACPI_NO_ACPI_ENABLE);
+        if (!AcpiGbl_DbOpt_ini_methods)
+        {
+            InitFlags |= (ACPI_NO_DEVICE_INIT | ACPI_NO_OBJECT_INIT);
+        }
+
+        /*
+         * Main initialization for ACPICA subsystem
+         * TBD: Need a way to call this after the ACPI table "LOAD" command
+         */
+        Status = AcpiEnableSubsystem (InitFlags);
+        if (ACPI_FAILURE (Status))
+        {
+            printf ("**** Could not EnableSubsystem, %s\n",
+                AcpiFormatException (Status));
+            goto EnterDebugger;
+        }
+
+        /*
+         * Install handlers for "device driver" space IDs (EC,SMBus, etc.)
+         * and fixed event handlers
+         */
+        AeInstallLateHandlers ();
+
+        /* Finish the ACPICA initialization */
+
+        Status = AcpiInitializeObjects (InitFlags);
+        if (ACPI_FAILURE (Status))
+        {
+            printf ("**** Could not InitializeObjects, %s\n",
+                AcpiFormatException (Status));
+            goto EnterDebugger;
+        }
+
+        AeMiscellaneousTests ();
     }
 
-    printf ("\n");
-
-    /* Build a local RSDT with all tables and let ACPICA process the RSDT */
-
-    Status = AeBuildLocalTables (ListHead);
-    if (ACPI_FAILURE (Status))
-    {
-        goto ErrorExit;
-    }
-
-    /* Install all of the ACPI tables */
-
-    Status = AeInstallTables ();
-    if (ACPI_FAILURE (Status))
-    {
-        printf ("**** Could not install ACPI tables, %s\n",
-            AcpiFormatException (Status));
-        goto EnterDebugger;
-    }
-
-    /*
-     * Install most of the handlers (Regions, Notify, Table, etc.)
-     * Override the default region handlers, especially SystemMemory,
-     * which is simulated in this utility.
-     */
-    Status = AeInstallEarlyHandlers ();
-    if (ACPI_FAILURE (Status))
-    {
-        goto EnterDebugger;
-    }
-
-    Status = AeLoadTables ();
-
-    /*
-     * Exit namespace initialization for the "load namespace only" option.
-     * No control methods will be executed. However, still enter the
-     * the debugger.
-     */
-    if (AcpiGbl_AeLoadOnly)
-    {
-        goto EnterDebugger;
-    }
-
-    if (ACPI_FAILURE (Status))
-    {
-        printf ("**** Could not load ACPI tables, %s\n",
-            AcpiFormatException (Status));
-        goto EnterDebugger;
-    }
-
-    /* Setup initialization flags for ACPICA */
-
-    InitFlags = (ACPI_NO_HANDLER_INIT | ACPI_NO_ACPI_ENABLE);
-    if (AcpiGbl_DbOpt_NoIniMethods)
-    {
-        InitFlags |= (ACPI_NO_DEVICE_INIT | ACPI_NO_OBJECT_INIT);
-    }
-
-    /*
-     * Main initialization for ACPICA subsystem
-     * TBD: Need a way to call this after the ACPI table "LOAD" command?
-     *
-     * NOTE: This initialization does not match the _Lxx and _Exx methods
-     * to individual GPEs, as there are no real GPEs when the hardware
-     * is simulated - because there is no namespace until AeLoadTables is
-     * executed. This may have to change if AcpiExec is ever run natively
-     * on actual hardware (such as under UEFI).
-     */
-    Status = AcpiEnableSubsystem (InitFlags);
-    if (ACPI_FAILURE (Status))
-    {
-        printf ("**** Could not EnableSubsystem, %s\n",
-            AcpiFormatException (Status));
-        goto EnterDebugger;
-    }
-
-    /*
-     * Install handlers for "device driver" space IDs (EC,SMBus, etc.)
-     * and fixed event handlers
-     */
-    AeInstallLateHandlers ();
-
-    /*
-     * This call implements the "initialization file" option for AcpiExec.
-     * This is the precise point that we want to perform the overrides.
-     */
-    AeDoObjectOverrides ();
-
-    /* Finish the ACPICA initialization */
-
-    Status = AcpiInitializeObjects (InitFlags);
-    if (ACPI_FAILURE (Status))
-    {
-        printf ("**** Could not InitializeObjects, %s\n",
-            AcpiFormatException (Status));
-        goto EnterDebugger;
-    }
-
-    AeMiscellaneousTests ();
-
-
 EnterDebugger:
 
     /* Exit if error above and we are in one of the batch modes */
 
     if (ACPI_FAILURE (Status) && (AcpiGbl_ExecutionMode > 0))
     {
-        goto ErrorExit;
+        return (-1);
     }
 
     /* Run a batch command or enter the command loop */
@@ -812,12 +627,12 @@ EnterDebugger:
     default:
     case AE_MODE_COMMAND_LOOP:
 
-        AcpiRunDebugger (NULL);
+        AcpiDbUserCommands (ACPI_DEBUGGER_COMMAND_PROMPT, NULL);
         break;
 
     case AE_MODE_BATCH_MULTIPLE:
 
-        AcpiRunDebugger (BatchBuffer);
+        AcpiDbRunBatchMode ();
         break;
 
     case AE_MODE_BATCH_SINGLE:
@@ -826,19 +641,251 @@ EnterDebugger:
         break;
     }
 
-    /* Shut down the debugger and ACPICA */
+    return (0);
+}
 
-    AcpiTerminateDebugger ();
 
-    /* re-enable debug output for AcpiTerminate output */
+/******************************************************************************
+ *
+ * FUNCTION:    AcpiDbRunBatchMode
+ *
+ * PARAMETERS:  BatchCommandLine    - A semicolon separated list of commands
+ *                                    to be executed.
+ *                                    Use only commas to separate elements of
+ *                                    particular command.
+ * RETURN:      Status
+ *
+ * DESCRIPTION: For each command of list separated by ';' prepare the command
+ *              buffer and pass it to AcpiDbCommandDispatch.
+ *
+ *****************************************************************************/
 
-    AcpiGbl_DbOutputFlags = ACPI_DB_CONSOLE_OUTPUT;
+static ACPI_STATUS
+AcpiDbRunBatchMode (
+    void)
+{
+    ACPI_STATUS             Status;
+    char                    *Ptr = BatchBuffer;
+    char                    *Cmd = Ptr;
+    UINT8                   Run = 0;
 
-NormalExit:
-    ExitCode = 0;
 
-ErrorExit:
-    (void) AcpiTerminate ();
-    AcDeleteTableList (ListHead);
-    return (ExitCode);
+    AcpiGbl_MethodExecuting = FALSE;
+    AcpiGbl_StepToNextCall = FALSE;
+
+    while (*Ptr)
+    {
+        if (*Ptr == ',')
+        {
+            /* Convert commas to spaces */
+            *Ptr = ' ';
+        }
+        else if (*Ptr == ';')
+        {
+            *Ptr = '\0';
+            Run = 1;
+        }
+
+        Ptr++;
+
+        if (Run || (*Ptr == '\0'))
+        {
+            (void) AcpiDbCommandDispatch (Cmd, NULL, NULL);
+            Run = 0;
+            Cmd = Ptr;
+        }
+    }
+
+    Status = AcpiTerminate ();
+    return (Status);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    FlStrdup
+ *
+ * DESCRIPTION: Local strdup function
+ *
+ *****************************************************************************/
+
+static char *
+FlStrdup (
+    char                    *String)
+{
+    char                    *NewString;
+
+
+    NewString = AcpiOsAllocate (strlen (String) + 1);
+    if (!NewString)
+    {
+        return (NULL);
+    }
+
+    strcpy (NewString, String);
+    return (NewString);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    FlSplitInputPathname
+ *
+ * PARAMETERS:  InputFilename       - The user-specified ASL source file to be
+ *                                    compiled
+ *              OutDirectoryPath    - Where the directory path prefix is
+ *                                    returned
+ *              OutFilename         - Where the filename part is returned
+ *
+ * RETURN:      Status
+ *
+ * DESCRIPTION: Split the input path into a directory and filename part
+ *              1) Directory part used to open include files
+ *              2) Filename part used to generate output filenames
+ *
+ *****************************************************************************/
+
+ACPI_STATUS
+FlSplitInputPathname (
+    char                    *InputPath,
+    char                    **OutDirectoryPath,
+    char                    **OutFilename)
+{
+    char                    *Substring;
+    char                    *DirectoryPath;
+    char                    *Filename;
+
+
+    *OutDirectoryPath = NULL;
+    *OutFilename = NULL;
+
+    if (!InputPath)
+    {
+        return (AE_OK);
+    }
+
+    /* Get the path to the input filename's directory */
+
+    DirectoryPath = FlStrdup (InputPath);
+    if (!DirectoryPath)
+    {
+        return (AE_NO_MEMORY);
+    }
+
+    /* Convert backslashes to slashes in the entire path */
+
+    UtConvertBackslashes (DirectoryPath);
+
+    /* Backup to last slash or colon */
+
+    Substring = strrchr (DirectoryPath, '/');
+    if (!Substring)
+    {
+        Substring = strrchr (DirectoryPath, ':');
+    }
+
+    /* Extract the simple filename */
+
+    if (!Substring)
+    {
+        DirectoryPath[0] = 0;
+        Filename = FlStrdup (InputPath);
+    }
+    else
+    {
+        Filename = FlStrdup (Substring + 1);
+        *(Substring + 1) = 0;
+    }
+
+    if (!Filename)
+    {
+        return (AE_NO_MEMORY);
+    }
+
+    *OutDirectoryPath = DirectoryPath;
+    *OutFilename = Filename;
+    return (AE_OK);
+}
+
+
+/******************************************************************************
+ *
+ * FUNCTION:    AsDoWildcard
+ *
+ * PARAMETERS:  DirectoryPathname   - Path to parent directory
+ *              FileSpecifier       - the wildcard specification (*.c, etc.)
+ *
+ * RETURN:      Pointer to a list of filenames
+ *
+ * DESCRIPTION: Process files via wildcards. This function is for the Windows
+ *              case only.
+ *
+ *****************************************************************************/
+
+static char **
+AsDoWildcard (
+    char                    *DirectoryPathname,
+    char                    *FileSpecifier)
+{
+#ifdef WIN32
+    void                    *DirInfo;
+    char                    *Filename;
+    int                     FileCount;
+
+
+    FileCount = 0;
+
+    /* Open parent directory */
+
+    DirInfo = AcpiOsOpenDirectory (DirectoryPathname, FileSpecifier,
+        REQUEST_FILE_ONLY);
+    if (!DirInfo)
+    {
+        /* Either the directory or file does not exist */
+
+        printf ("File or directory \"%s%s\" does not exist\n",
+            DirectoryPathname, FileSpecifier);
+        return (NULL);
+    }
+
+    /* Process each file that matches the wildcard specification */
+
+    while ((Filename = AcpiOsGetNextFilename (DirInfo)))
+    {
+        /* Add the filename to the file list */
+
+        FileList[FileCount] = AcpiOsAllocate (strlen (Filename) + 1);
+        strcpy (FileList[FileCount], Filename);
+        FileCount++;
+
+        if (FileCount >= ASL_MAX_FILES)
+        {
+            printf ("Max files reached\n");
+            FileList[0] = NULL;
+            return (FileList);
+        }
+    }
+
+    /* Cleanup */
+
+    AcpiOsCloseDirectory (DirInfo);
+    FileList[FileCount] = NULL;
+    return (FileList);
+
+#else
+    if (!FileSpecifier)
+    {
+        return (NULL);
+    }
+
+    /*
+     * Linux/Unix cases - Wildcards are expanded by the shell automatically.
+     * Just return the filename in a null terminated list
+     */
+    FileList[0] = AcpiOsAllocate (strlen (FileSpecifier) + 1);
+    strcpy (FileList[0], FileSpecifier);
+    FileList[1] = NULL;
+
+    return (FileList);
+#endif
 }
