@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -122,9 +122,6 @@ static void
 AhDisplayUsage (
     void);
 
-#define AH_UTILITY_NAME             "ACPI Help Utility"
-#define AH_SUPPORTED_OPTIONS        "aehikmopsv"
-
 
 /******************************************************************************
  *
@@ -139,29 +136,23 @@ AhDisplayUsage (
     void)
 {
 
-    ACPI_USAGE_HEADER ("acpihelp <options> [Name/Prefix | HexValue]");
+    ACPI_USAGE_HEADER ("acpihelp <options> [NamePrefix | HexValue]");
     ACPI_OPTION ("-h",                      "Display help");
-    ACPI_OPTION ("-v",                      "Display version information");
 
-    printf ("\nAML (ACPI Machine Language) Names and Encodings:\n");
-    ACPI_OPTION ("-a [Name/Prefix]",        "Find/Display both ASL operator and AML opcode name(s)");
-    ACPI_OPTION ("-m [Name/Prefix]",        "Find/Display AML opcode name(s)");
-
-    printf ("\nASL (ACPI Source Language) Names and Symbols:\n");
-    ACPI_OPTION ("-k [Name/Prefix]",        "Find/Display ASL non-operator keyword(s)");
-    ACPI_OPTION ("-p [Name/Prefix]",        "Find/Display ASL predefined method name(s)");
-    ACPI_OPTION ("-s [Name/Prefix]",        "Find/Display ASL operator name(s)");
-
-    printf ("\nOther ACPI Names:\n");
-    ACPI_OPTION ("-i [Name/Prefix]",        "Find/Display ACPI/PNP Hardware ID(s)");
+    printf ("\nACPI Names and Symbols:\n");
+    ACPI_OPTION ("-k [NamePrefix]",         "Find/Display ASL non-operator keyword(s)");
+    ACPI_OPTION ("-m [NamePrefix]",         "Find/Display AML opcode name(s)");
+    ACPI_OPTION ("-p [NamePrefix]",         "Find/Display ASL predefined method name(s)");
+    ACPI_OPTION ("-s [NamePrefix]",         "Find/Display ASL operator name(s)");
 
     printf ("\nACPI Values:\n");
     ACPI_OPTION ("-e [HexValue]",           "Decode ACPICA exception code");
+    ACPI_OPTION ("-i",                      "Display known ACPI Device IDs (_HID)");
     ACPI_OPTION ("-o [HexValue]",           "Decode hex AML opcode");
 
-    printf ("\nName/Prefix or HexValue not specified means \"Display All\"\n");
-    printf ("\nDefault search with valid Name/Prefix and no options:\n");
-    printf ("    Find ASL/AML operator names - if NamePrefix does not start with underscore\n");
+    printf ("\nNamePrefix/HexValue not specified means \"Display All\"\n");
+    printf ("\nDefault search with NamePrefix and no options:\n");
+    printf ("    Find ASL operator names - if NamePrefix does not start with underscore\n");
     printf ("    Find ASL predefined method names - if NamePrefix starts with underscore\n");
 }
 
@@ -185,7 +176,7 @@ main (
 
 
     ACPI_DEBUG_INITIALIZE (); /* For debug version only */
-    printf (ACPI_COMMON_SIGNON (AH_UTILITY_NAME));
+    printf (ACPI_COMMON_SIGNON ("ACPI Help Utility"));
     DecodeType = AH_DECODE_DEFAULT;
 
     if (argc < 2)
@@ -196,13 +187,8 @@ main (
 
     /* Command line options */
 
-    while ((j = AcpiGetopt (argc, argv, AH_SUPPORTED_OPTIONS)) != EOF) switch (j)
+    while ((j = AcpiGetopt (argc, argv, "ehikmops")) != EOF) switch (j)
     {
-    case 'a':
-
-        DecodeType = AH_DECODE_ASL_AML;
-        break;
-
     case 'e':
 
         DecodeType = AH_DECODE_EXCEPTION;
@@ -234,14 +220,10 @@ main (
         break;
 
     case 's':
-
+        
         DecodeType = AH_DECODE_ASL;
         break;
 
-    case 'v': /* -v: (Version): signon already emitted, just exit */
-
-        return (0);
-
     case 'h':
     default:
 
@@ -255,18 +237,13 @@ main (
 
     switch (DecodeType)
     {
-    case AH_DECODE_ASL_AML:
-
-        AhFindAslAndAmlOperators (Name);
-        break;
-
     case AH_DECODE_AML:
 
         AhFindAmlOpcode (Name);
         break;
 
     case AH_DECODE_AML_OPCODE:
-
+        
         AhDecodeAmlOpcode (Name);
         break;
 
@@ -287,7 +264,7 @@ main (
 
     case AH_DISPLAY_DEVICE_IDS:
 
-        AhDisplayDeviceIds (Name);
+        AhDisplayDeviceIds ();
         break;
 
     case AH_DECODE_EXCEPTION:
@@ -309,7 +286,7 @@ main (
         }
         else
         {
-            AhFindAslAndAmlOperators (Name);
+            AhFindAslOperators (Name);
         }
         break;
     }
