@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2014, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -114,7 +114,6 @@
  *****************************************************************************/
 
 #include "acpisrc.h"
-#include "acapps.h"
 
 /* Local prototypes */
 
@@ -380,20 +379,18 @@ AsConvertFile (
     ACPI_IDENTIFIER_TABLE   *LineTable;
     ACPI_IDENTIFIER_TABLE   *MacroTable;
     ACPI_TYPED_IDENTIFIER_TABLE *StructTable;
-    ACPI_IDENTIFIER_TABLE   *SpecialMacroTable;
 
 
     switch (FileType)
     {
     case FILE_TYPE_SOURCE:
-
+        
         Functions           = ConversionTable->SourceFunctions;
         StringTable         = ConversionTable->SourceStringTable;
         LineTable           = ConversionTable->SourceLineTable;
         ConditionalTable    = ConversionTable->SourceConditionalTable;
         MacroTable          = ConversionTable->SourceMacroTable;
         StructTable         = ConversionTable->SourceStructTable;
-        SpecialMacroTable   = ConversionTable->SourceSpecialMacroTable;
        break;
 
     case FILE_TYPE_HEADER:
@@ -404,18 +401,6 @@ AsConvertFile (
         ConditionalTable    = ConversionTable->HeaderConditionalTable;
         MacroTable          = ConversionTable->HeaderMacroTable;
         StructTable         = ConversionTable->HeaderStructTable;
-        SpecialMacroTable   = ConversionTable->HeaderSpecialMacroTable;
-        break;
-
-    case FILE_TYPE_PATCH:
-
-        Functions           = ConversionTable->PatchFunctions;
-        StringTable         = ConversionTable->PatchStringTable;
-        LineTable           = ConversionTable->PatchLineTable;
-        ConditionalTable    = ConversionTable->PatchConditionalTable;
-        MacroTable          = ConversionTable->PatchMacroTable;
-        StructTable         = ConversionTable->PatchStructTable;
-        SpecialMacroTable   = ConversionTable->PatchSpecialMacroTable;
         break;
 
     default:
@@ -488,14 +473,6 @@ AsConvertFile (
         }
     }
 
-    if (SpecialMacroTable)
-    {
-        for (i = 0; SpecialMacroTable[i].Identifier; i++)
-        {
-            AsCleanupSpecialMacro (FileBuffer, SpecialMacroTable[i].Identifier);
-        }
-    }
-
     /* Process the function table */
 
     for (i = 0; i < 32; i++)
@@ -787,6 +764,8 @@ AsGetFile (
     FILE                    *File;
     UINT32                  Size;
     char                    *Buffer;
+    int                     Seek1;
+    int                     Seek2;
     size_t                  Actual;
 
 
@@ -801,8 +780,11 @@ AsGetFile (
 
     /* Need file size to allocate a buffer */
 
-    Size = CmGetFileSize (File);
-    if (Size == ACPI_UINT32_MAX)
+    Seek1 = fseek (File, 0L, SEEK_END);
+    Size = ftell (File);
+    Seek2 = fseek (File, 0L, SEEK_SET);
+
+    if (Seek1 || Seek2 || (Size == -1))
     {
         printf ("Could not get file size for %s\n", Filename);
         goto ErrorExit;
