@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2015, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -113,6 +113,7 @@
  *
  *****************************************************************************/
 
+
 #include "acpisrc.h"
 #include "acapps.h"
 
@@ -168,10 +169,6 @@ BOOLEAN                 Gbl_WidenDeclarations = FALSE;
 BOOLEAN                 Gbl_IgnoreLoneLineFeeds = FALSE;
 BOOLEAN                 Gbl_HasLoneLineFeeds = FALSE;
 BOOLEAN                 Gbl_Cleanup = FALSE;
-BOOLEAN                 Gbl_IgnoreTranslationEscapes = FALSE;
-
-#define AS_UTILITY_NAME             "ACPI Source Code Conversion Utility"
-#define AS_SUPPORTED_OPTIONS        "cdhilqsuv^y"
 
 
 /******************************************************************************
@@ -313,8 +310,8 @@ AsDisplayStats (
     printf ("%8u Total bytes (%.1fK/file)\n",
         Gbl_TotalSize, ((double) Gbl_TotalSize/Gbl_Files)/1024);
     printf ("%8u Tabs found\n", Gbl_Tabs);
-    printf ("%8u Missing if/else/while braces\n", Gbl_MissingBraces);
-    printf ("%8u Non-ANSI // comments found\n", Gbl_NonAnsiComments);
+    printf ("%8u Missing if/else braces\n", Gbl_MissingBraces);
+    printf ("%8u Non-ANSI comments found\n", Gbl_NonAnsiComments);
     printf ("%8u Total Lines\n", Gbl_TotalLines);
     printf ("%8u Lines of code\n", Gbl_SourceLines);
     printf ("%8u Lines of non-comment whitespace\n", Gbl_WhiteLines);
@@ -364,15 +361,13 @@ AsDisplayUsage (
 
     ACPI_OPTION ("-c",          "Generate cleaned version of the source");
     ACPI_OPTION ("-h",          "Insert dual-license header into all modules");
-    ACPI_OPTION ("-i",          "Cleanup macro indentation");
     ACPI_OPTION ("-l",          "Generate Linux version of the source");
     ACPI_OPTION ("-u",          "Generate Custom source translation");
 
-    ACPI_USAGE_TEXT ("\n");
+    printf ("\n");
     ACPI_OPTION ("-d",          "Leave debug statements in code");
     ACPI_OPTION ("-s",          "Generate source statistics only");
-    ACPI_OPTION ("-v",          "Display version information");
-    ACPI_OPTION ("-vb",         "Verbose mode");
+    ACPI_OPTION ("-v",          "Verbose mode");
     ACPI_OPTION ("-y",          "Suppress file overwrite prompts");
 }
 
@@ -398,8 +393,7 @@ main (
 
 
     ACPI_DEBUG_INITIALIZE (); /* For debug version only */
-    AcpiOsInitialize ();
-    printf (ACPI_COMMON_SIGNON (AS_UTILITY_NAME));
+    printf (ACPI_COMMON_SIGNON ("ACPI Source Code Conversion Utility"));
 
     if (argc < 2)
     {
@@ -409,10 +403,10 @@ main (
 
     /* Command line options */
 
-    while ((j = AcpiGetopt (argc, argv, AS_SUPPORTED_OPTIONS)) != ACPI_OPT_END) switch(j)
+    while ((j = AcpiGetopt (argc, argv, "cdhlqsuvy")) != EOF) switch(j)
     {
     case 'l':
-
+        
         /* Linux code generation */
 
         printf ("Creating Linux source code\n");
@@ -422,7 +416,7 @@ main (
         break;
 
     case 'c':
-
+        
         /* Cleanup code */
 
         printf ("Code cleanup\n");
@@ -438,16 +432,6 @@ main (
         ConversionTable = &LicenseConversionTable;
         break;
 
-    case 'i':
-
-        /* Cleanup wrong indent result */
-
-        printf ("Cleaning up macro indentation\n");
-        ConversionTable = &IndentConversionTable;
-        Gbl_IgnoreLoneLineFeeds = TRUE;
-        Gbl_IgnoreTranslationEscapes = TRUE;
-        break;
-
     case 's':
 
         /* Statistics only */
@@ -463,26 +447,10 @@ main (
         break;
 
     case 'v':
+        
+        /* Verbose mode */
 
-        switch (AcpiGbl_Optarg[0])
-        {
-        case '^':  /* -v: (Version): signon already emitted, just exit */
-
-            exit (0);
-
-        case 'b':
-
-            /* Verbose mode */
-
-            Gbl_VerboseMode = TRUE;
-            break;
-
-        default:
-
-            printf ("Unknown option: -v%s\n", AcpiGbl_Optarg);
-            return (-1);
-        }
-
+        Gbl_VerboseMode = TRUE;
         break;
 
     case 'y':
@@ -507,7 +475,7 @@ main (
         break;
 
     default:
-
+        
         AsDisplayUsage ();
         return (-1);
     }
@@ -567,17 +535,9 @@ main (
         {
             AsProcessOneFile (ConversionTable, NULL, TargetPath, 0, SourcePath, FILE_TYPE_HEADER);
         }
-        else if (strstr (SourcePath, ".c"))
-        {
-            AsProcessOneFile (ConversionTable, NULL, TargetPath, 0, SourcePath, FILE_TYPE_SOURCE);
-        }
-        else if (strstr (SourcePath, ".patch"))
-        {
-            AsProcessOneFile (ConversionTable, NULL, TargetPath, 0, SourcePath, FILE_TYPE_PATCH);
-        }
         else
         {
-            printf ("Unknown file type - %s\n", SourcePath);
+            AsProcessOneFile (ConversionTable, NULL, TargetPath, 0, SourcePath, FILE_TYPE_SOURCE);
         }
     }
 
